<?php

$LANG = array(
    'organization' => 'Организација',
    'name' => 'Име',
    'website' => 'Веб Страна',
    'work_phone' => 'Телефон',
    'address' => 'Адреса',
    'address1' => 'Улица',
    'address2' => 'Број',
    'city' => 'Град',
    'state' => 'Општина',
    'postal_code' => 'Поштенски број',
    'country_id' => 'Држава',
    'contacts' => 'Контакти',
    'first_name' => 'Име',
    'last_name' => 'Презиме',
    'phone' => 'Телефон',
    'email' => 'Е-пошта',
    'additional_info' => 'Дополнителни информации',
    'payment_terms' => 'Услови на плаќање',
    'currency_id' => 'Валута',
    'size_id' => 'Големина на компанија',
    'industry_id' => 'Индустрија',
    'private_notes' => 'Забелешки',
    'invoice' => 'Фактура',
    'client' => 'Клиент',
    'invoice_date' => 'Датаум на фактура',
    'due_date' => 'Датум на доспевање',
    'invoice_number' => 'Број на фактура',
    'invoice_number_short' => 'Фактура #',
    'po_number' => 'Број на нарачка',
    'po_number_short' => 'Нарачка #',
    'frequency_id' => 'Колку често',
    'discount' => 'Попуст',
    'taxes' => 'Даноци',
    'tax' => 'Данок',
    'item' => 'Ставка',
    'description' => 'Опис',
    'unit_cost' => 'Цена на единица',
    'quantity' => 'Количина',
    'line_total' => 'Вкупно',
    'subtotal' => 'Вкупно без данок',
    'paid_to_date' => 'Платено до денес',
    'balance_due' => 'Вкупно за плаќање',
    'invoice_design_id' => 'Дизајн',
    'terms' => 'Услови',
    'your_invoice' => 'Ваша фактура',
    'remove_contact' => 'Избриши контакт',
    'add_contact' => 'Додади контакт',
    'create_new_client' => 'Креирај нов клиент',
    'edit_client_details' => 'Измени податоци за клиент',
    'enable' => 'Вклучи',
    'learn_more' => 'Повеќе',
    'manage_rates' => 'Управување со стапки ',
    'note_to_client' => 'Забелешка за клиентот',
    'invoice_terms' => 'Услови по фактура',
    'save_as_default_terms' => 'Зачувај како стандардни услови',
    'download_pdf' => 'Превземи во PDF',
    'pay_now' => 'Плати сега',
    'save_invoice' => 'Зачувај Фактура',
    'clone_invoice' => 'Клонирај во фактура',
    'archive_invoice' => 'Архивирај Фактура',
    'delete_invoice' => 'Избриши Фактура',
    'email_invoice' => 'Прати Фактура по е-пошта',
    'enter_payment' => 'Внеси уплата',
    'tax_rates' => 'Даночни стапки',
    'rate' => 'Стапка',
    'settings' => 'Подесувања',
    'enable_invoice_tax' => 'Овозможи изразување<b> данок на фактура </b>',
    'enable_line_item_tax' => 'Овозможи изразување<b> даночни ставки </b>',
    'dashboard' => 'Контролна табла',
    'dashboard_totals_in_all_currencies_help' => 'Забелешка: додади :link named ":name"  да се прикажуваат вкупно сумите  кога се 
употребува единствена основна валута.',
    'clients' => 'Клиенти',
    'invoices' => 'Фактури',
    'payments' => 'Плаќања',
    'credits' => 'Кредити',
    'history' => 'Историја',
    'search' => 'Пребарување',
    'sign_up' => 'Најавување',
    'guest' => 'Гостин',
    'company_details' => 'Податоци за компанијата',
    'online_payments' => 'Онлајн плаќања',
    'notifications' => 'Известувања',
    'import_export' => 'Увоз | Извоз',
    'done' => 'Завршено',
    'save' => 'Зачувај',
    'create' => 'Креирај',
    'upload' => 'Прикачи',
    'import' => 'Внеси',
    'download' => 'Преземи',
    'cancel' => 'Откажи',
    'close' => 'Затвори',
    'provide_email' => 'Ве молам внесете валидна адреса на е-пошта',
    'powered_by' => 'Поддржано од',
    'no_items' => 'Нема ставки',
    'recurring_invoices' => 'Фактури што се повторуваат',
    'recurring_help' => '<p> Автоматски пратете им ги на клиентите истите фактури неделно, двомесечно, месечно, квартално или годишно. </p>
<p> Користи :MONTH, :QUARTER или :YEAR за динамични дати. Може да се водите и по основна математика, на пример: :MONTH-1. </p>
<p> Примери за динамични варијабли на фактура: </p>
<ul>
<li> "Членство во теретана за месец :MONTH" >> "Членство во теретана за месец Јули" </li>
<li> ":YEAR+1 годишна претплата" >> "2015 Годишна Претплата" </li>
<li> "Задржано плаќање за :QUARTER+1" >> "Задржано плаќање за К2" </li>
</ul>',
    'recurring_quotes' => 'Повторувачки понуди',
    'in_total_revenue' => 'Вкупен приход',
    'billed_client' => 'Фактуриран Клиент',
    'billed_clients' => 'Фактурирани Клиенти',
    'active_client' => 'Активен Клиент',
    'active_clients' => 'Активни Клиенти',
    'invoices_past_due' => 'Доспеани Фактури',
    'upcoming_invoices' => 'Недоспеани Фактури',
    'average_invoice' => 'Просечна Фактура',
    'archive' => 'Архивирај',
    'delete' => 'Избриши',
    'archive_client' => 'Архивирај Клиент',
    'delete_client' => 'Избриши Клиент',
    'archive_payment' => 'Архивирај Плаќање',
    'delete_payment' => 'Избриши Плаќање',
    'archive_credit' => 'Архивирај Кредит',
    'delete_credit' => 'Избриши Кредит',
    'show_archived_deleted' => 'Прикажи архивирано/избришано',
    'filter' => 'Филтер',
    'new_client' => 'Нов Клиент',
    'new_invoice' => 'Нова Фактура',
    'new_payment' => 'Внеси Плаќање',
    'new_credit' => 'Внеси Кредит',
    'contact' => 'Контакт',
    'date_created' => 'Дата на Креирање',
    'last_login' => 'Последна Најава',
    'balance' => 'Состојба',
    'action' => 'Активност',
    'status' => 'Статус',
    'invoice_total' => 'Вкупно по фактура',
    'frequency' => 'Фреквентност',
    'range' => 'Опсег',
    'start_date' => 'Почетен датум',
    'end_date' => 'Краен датум',
    'transaction_reference' => 'Трансакциска референца',
    'method' => 'Метод',
    'payment_amount' => 'Износ на плаќање',
    'payment_date' => 'Датум на плаќање',
    'credit_amount' => 'Износ на кредит',
    'credit_balance' => 'Состојба на кредит',
    'credit_date' => 'Датум на кредит',
    'empty_table' => 'Нема податоци во табелата',
    'select' => 'Избери',
    'edit_client' => 'Измени клиент',
    'edit_invoice' => 'Измени Фактура',
    'create_invoice' => 'Креирај Фактура',
    'enter_credit' => 'Внеси кредит',
    'last_logged_in' => 'Последна најава',
    'details' => 'Детали',
    'standing' => 'Постојано',
    'credit' => 'Кредит',
    'activity' => 'Активност',
    'date' => 'Датум',
    'message' => 'Порака',
    'adjustment' => 'Прилагодување',
    'are_you_sure' => 'Дали сте сигурни?',
    'payment_type_id' => 'Начин на плаќање',
    'amount' => 'Количина',
    'work_email' => 'Е-пошта',
    'language_id' => 'Јазик',
    'timezone_id' => 'Временска зона',
    'date_format_id' => 'Формат на датум',
    'datetime_format_id' => 'Формат на датум/време',
    'users' => 'Корисници',
    'localization' => 'Локализација',
    'remove_logo' => 'Отстрани лого',
    'logo_help' => 'Поддржува: JPG, GIF и PNG',
    'payment_gateway' => 'Портал на плаќање',
    'gateway_id' => 'Платен портал',
    'email_notifications' => 'Известувања по е-пошта',
    'email_sent' => 'Прати ми е-пошта кога фактурата е <b> пратена </b>',
    'email_viewed' => 'Прати ми е-пошта кога фактурата е <b> видена </b>',
    'email_paid' => 'Прати ми е-пошта кога фактурата е <b> платена </b>',
    'site_updates' => 'Ажурирања на страната',
    'custom_messages' => 'Прилагодени пораки',
    'default_email_footer' => 'Постави стандарден <b> потпис на е-пошта </b> ',
    'select_file' => 'Ве молиме изберете датотека',
    'first_row_headers' => 'Користи го првиот ред како заглавија',
    'column' => 'Колона',
    'sample' => 'Примерок',
    'import_to' => 'Внеси во',
    'client_will_create' => 'клиентот ќе биде креиран ',
    'clients_will_create' => 'клиентите ќе бидат креирани',
    'email_settings' => 'Поставки за е-пошта',
    'client_view_styling' => 'Стилизирање на прегледот на клиент',
    'pdf_email_attachment' => 'Прикачи PDF',
    'custom_css' => 'Прилагоден CSS',
    'import_clients' => 'Внеси податоци за клиентот',
    'csv_file' => 'CSV датотека',
    'export_clients' => 'Експортирај податоци за клиент',
    'created_client' => 'Успешно креирање на клиент',
    'created_clients' => 'Успешно креирани :count клиент(и)',
    'updated_settings' => 'Успешно ажурирани подесувања',
    'removed_logo' => 'Успешно отстранување на лого',
    'sent_message' => 'Успешно пратена порака',
    'invoice_error' => 'Ве молиме одберете клиент и поправете можни грешки',
    'limit_clients' => 'Извинете, ова ќе го надмине лимитот на :count клиенти',
    'payment_error' => 'Има грешка при процесирањето на плаќањето. Ве молиме обидете се повторно подоцна.',
    'registration_required' => 'Ве молиме најавете се за да пратите фактура по е-пошта',
    'confirmation_required' => 'Ве молиме потврдете ја Вашата адреса за е-пошта, :link за повторно испраќање на е-пошта за потврда.',
    'updated_client' => 'Успешно ажурирање на клиент',
    'archived_client' => 'Успешно архивирање на клиент',
    'archived_clients' => 'Успешно архивирање на :count клиенти',
    'deleted_client' => 'Успешно бришење на клиент',
    'deleted_clients' => 'Успешно бришење на :count клиенти',
    'updated_invoice' => 'Успешно ажурирана фактура',
    'created_invoice' => 'Успешно креирана фактура',
    'cloned_invoice' => 'Успешно клонирана фактура',
    'emailed_invoice' => 'Успешно пратена фактура по е-пошта',
    'and_created_client' => 'и креирање клиент',
    'archived_invoice' => 'Успешно архивирана фактура',
    'archived_invoices' => 'Успешно архивирани :count  Фактури',
    'deleted_invoice' => 'Успешно избришана Фактура',
    'deleted_invoices' => 'Успешно избришани :count фактури',
    'created_payment' => 'Успешно креирано плаќање',
    'created_payments' => 'Успешно креирани :count плаќања(ње)',
    'archived_payment' => 'Успешно архивирано плаќање',
    'archived_payments' => 'Успешно архивирани :count плаќања',
    'deleted_payment' => 'Успешно бришење на плаќање',
    'deleted_payments' => 'Успешно бришење на :count плаќања',
    'applied_payment' => 'Успешно поднесено плаќање',
    'created_credit' => 'Успешно креирање на кредит',
    'archived_credit' => 'Успешно архивирање на кредит',
    'archived_credits' => 'Успешно архивирање на :count кредити',
    'deleted_credit' => 'Успешно бришење на кредит',
    'deleted_credits' => 'Успешно бришење на :count кредити',
    'imported_file' => 'Успешно внесување на датотека',
    'updated_vendor' => 'Успешно ажурирање на продавач',
    'created_vendor' => 'Успешно креирање на продавач',
    'archived_vendor' => 'Успешно архивирање на продавач',
    'archived_vendors' => 'Успешно архивирање на :count продавачи',
    'deleted_vendor' => 'Успешно бришење на продавач',
    'deleted_vendors' => 'Успешно бришење на :count продавачи',
    'confirmation_subject' => 'Потврдување на Invoice Ninja сметка',
    'confirmation_header' => 'Потврдување на сметка',
    'confirmation_message' => 'Ве молиме пристапете до линкот подолу за да ја потврдите вашата сметка.',
    'invoice_subject' => 'Нова фактура :number од :account',
    'invoice_message' => 'За преглед на вашата фактура за :amount, кликнете на линкот подоле. ',
    'payment_subject' => 'Плаќањето е примено',
    'payment_message' => 'Ви благодариме за вашето плаќање од :amount',
    'email_salutation' => 'Почитуван :name,',
    'email_signature' => 'Со почит,',
    'email_from' => 'Тимот на Invoice Ninja',
    'invoice_link_message' => 'За преглед на фактурата кликнете на линкот подоле:',
    'notification_invoice_paid_subject' => 'Фактурата :invoice е платена од :client',
    'notification_invoice_sent_subject' => 'Фактурата :invoice е пратена на :client',
    'notification_invoice_viewed_subject' => 'Фактурата :invoice е прегледана од :client',
    'notification_invoice_paid' => 'Плаќање од :amount е направено од клиентот :client кон фактурата :invoice.',
    'notification_invoice_sent' => 'На клиентот :client е испратена фактура :invoice од :amount по е-пошта.',
    'notification_invoice_viewed' => 'Клиентот :client ја прегледа фактурата :invoice за :amount.',
    'reset_password' => 'Можете да ја ресетирате лозинката за вашата сметка со кликнување на следното копче:',
    'secure_payment' => 'Безбедно плаќање',
    'card_number' => 'Број на картичка',
    'expiration_month' => 'Месец на истекување',
    'expiration_year' => 'Година на истекување',
    'cvv' => 'CVV',
    'logout' => 'Одјава',
    'sign_up_to_save' => 'Пријавете се за да ја зачувате вашата работа',
    'agree_to_terms' => 'Се согласувам со :terms',
    'terms_of_service' => 'Услови на користење',
    'email_taken' => 'Емаил адресата е веќе регистрирана',
    'working' => 'Работи',
    'success' => 'Успех',
    'success_message' => 'Успешно се регистриравте! Ве молиме кликнете на линкот во мејлот за потврда на сметката за да ја потврдите вашата е-адреса.',
    'erase_data' => 'Вашата сметка не е регистрирана, ова трајно ќе ги избрише вашите податоци.',
    'password' => 'Лозинка',
    'pro_plan_product' => 'Про План',
    'pro_plan_success' => 'Ви благодариме што го избравте Про планот на Invoice Ninja! <p/> &nbsp; <br/>
 <b> Следни чекори </b> <p/> Фактура што може да се плати е испратена на електорнската
 адреса поврзана со вашата сметка. За да ги отклучите сите одлични
 Про функции, ве молиме следете ги инструкциите на фактурата за да платите
 за една година Pro-level фактурирање. <p/>
 Не можете да ја пронајдете фактурата? Ви треба понатамошна асистенција? Ќе ви помогнеме со задоволство
 --пратете ни е-пошта на contact@invoiceninja.com',
    'unsaved_changes' => 'Имате незачувани промени',
    'custom_fields' => 'Прилагодливи полиња',
    'company_fields' => 'Полиња за компанијата',
    'client_fields' => 'Полиња за клиентот',
    'field_label' => 'Ознака на поле',
    'field_value' => 'Вредност на поле',
    'edit' => 'Измени',
    'set_name' => 'Постави име на компанијата',
    'view_as_recipient' => 'Прегледај како примач',
    'product_library' => 'Датабаза на продукти',
    'product' => 'Продукт',
    'products' => 'Продукти',
    'fill_products' => 'Автоматско пополнување на продукти',
    'fill_products_help' => 'Избирањето на продукт автоматски ќе ги <b> исполни полињата за опис и цена</b>',
    'update_products' => 'Автоматско ажурирање на продукти',
    'update_products_help' => 'Ажурирањето на факура автоматски ќе ја <b> ажурира библиотеката на продукти </b> ',
    'create_product' => 'Додај продукт',
    'edit_product' => 'Измени продукт',
    'archive_product' => 'Архивирај продукт',
    'updated_product' => 'Успешно ажурирање на продукт',
    'created_product' => 'Успешно креирање на продукт',
    'archived_product' => 'Успешно архивирање на продукт',
    'pro_plan_custom_fields' => ':link за да се овозможат прилагодливи полиња преку активирање на Про План',
    'advanced_settings' => 'Напредни подесувања',
    'pro_plan_advanced_settings' => ':link за да се овозможат напредните подесувања преку активирање на Про План',
    'invoice_design' => 'Дизајн на фактура',
    'specify_colors' => 'Одреди бои',
    'specify_colors_label' => 'Избери ги боите кои се користени на фактурата',
    'chart_builder' => 'Изградувач на графикон',
    'ninja_email_footer' => 'Креирано преку :site | Create. Send. Get Paid.',
    'go_pro' => 'Премини на Про',
    'quote' => 'Понуда',
    'quotes' => 'Понуди',
    'quote_number' => 'Број на понуда',
    'quote_number_short' => 'Понуда #',
    'quote_date' => 'Датум на понуда',
    'quote_total' => 'Вкупно понуди',
    'your_quote' => 'Твојата понуда',
    'total' => 'Вкупно',
    'clone' => 'Клонирај',
    'new_quote' => 'Нова понуда',
    'create_quote' => 'Креирај понуда',
    'edit_quote' => 'Измени понуда',
    'archive_quote' => 'Архивирај понуда',
    'delete_quote' => 'Избриши понуда',
    'save_quote' => 'Зачувај понуда',
    'email_quote' => 'Прати понуда по ел. пошта',
    'clone_quote' => 'Клонирај понуда',
    'convert_to_invoice' => 'Конвертирај во фактура',
    'view_invoice' => 'Преглед на фактура',
    'view_client' => 'Преглед на клиент',
    'view_quote' => 'Преглед на понуда',
    'updated_quote' => 'Успешно ажурирана понуда',
    'created_quote' => 'Успешно креирана понуда',
    'cloned_quote' => 'Успешно клонирана понуда',
    'emailed_quote' => 'Успешно пратена понуда по ел. пошта',
    'archived_quote' => 'Успешно архивирана понуда',
    'archived_quotes' => 'Успешно архивирани :count понуди',
    'deleted_quote' => 'Успешно избришана понуда',
    'deleted_quotes' => 'Успешно избришани :count понуди',
    'converted_to_invoice' => 'Успешно конвертирана понуда во фактура',
    'quote_subject' => 'Нова понуда :number од :account',
    'quote_message' => 'За да ја видите вашата понуда за :amount, кликнете на линкот подоле. ',
    'quote_link_message' => 'За преглед на понудата на клиентот кликни на линкот подоле:',
    'notification_quote_sent_subject' => 'Понудата :invoice беше пратена на :client',
    'notification_quote_viewed_subject' => 'Понудата :invoice беше прегледана од :client',
    'notification_quote_sent' => 'На клиентот :client е пратена по е-пошта Понуда :invoice за :amount.',
    'notification_quote_viewed' => 'Клиентот :client ја прегледа понудата :invoice за :amount.',
    'session_expired' => 'Вашата сесија е истечена',
    'invoice_fields' => 'Полиња за фактура',
    'invoice_options' => 'Поставки за фактура',
    'hide_paid_to_date' => 'Сокриј Платено до датум',
    'hide_paid_to_date_help' => 'Прикажи "Платено до датум" на фактурите откако ќе биде примено плаќањето.',
    'charge_taxes' => 'Наплати даноци',
    'user_management' => 'Управување со корисник',
    'add_user' => 'Додај корисник',
    'send_invite' => 'Испрати покана',
    'sent_invite' => 'Успешно испраќање на покана',
    'updated_user' => 'Успешно ажурирање на корисник',
    'invitation_message' => 'Бевте поканети од страна на :invitor.',
    'register_to_add_user' => 'Ве молиме регистрирајте се за да додадете корисник',
    'user_state' => 'Состојба',
    'edit_user' => 'Измени корисник',
    'delete_user' => 'Избриши корисник',
    'active' => 'Активен',
    'pending' => 'Во тек',
    'deleted_user' => 'Успешно бришење на корисник',
    'confirm_email_invoice' => 'Дали сте сигурни дека сакате да ја пратите фактурата по мејл?',
    'confirm_email_quote' => 'Дали сте сигурни дека сакате да ја пратите понудата по мејл?',
    'confirm_recurring_email_invoice' => 'Дали сте сигурни дека сакате оваа фактура да биде пратена по мејл?',
    'confirm_recurring_email_invoice_not_sent' => 'Дали сте сигурни дека сакате да започнете со повторување?',
    'cancel_account' => 'Избриши сметка',
    'cancel_account_message' => 'Предупредување: Ова трајно ќе ја избрише вашата сметка, нема враќање.',
    'go_back' => 'Врати се назад',
    'data_visualizations' => 'Визуализација на податоци',
    'sample_data' => 'Прикажан пример за податоци',
    'hide' => 'Сокриј',
    'new_version_available' => 'Нова верзија на :releases_link е достапна. Вие работите на v:user_version, најновата верзија е v:latest_version',
    'invoice_settings' => 'Поставки за фактура',
    'invoice_number_prefix' => 'Префикс на број на фактура',
    'invoice_number_counter' => 'Бројач на фактури',
    'quote_number_prefix' => 'Префикс на број на понуда',
    'quote_number_counter' => 'Бројач на понуди',
    'share_invoice_counter' => 'Сподели го бројачот на фактури',
    'invoice_issued_to' => 'Фактура издадена на',
    'invalid_counter' => 'За да се спречи можен конфликт ве молиме поставете префикс на бројот на фактурата или на понудата',
    'mark_sent' => 'Белегот е пратен',
    'gateway_help_1' => ':link за регистрирање на Authorize.net.',
    'gateway_help_2' => ':link за регистрирање на Authorize.net.',
    'gateway_help_17' => ':link за да го добиете вашиот PayPay API потпис.',
    'gateway_help_27' => ':link за регистрирање на 2Checkout.com. За да се осигурате дека плаќањата се следат поставете го :complete_link како URL за пренасочување под Account > Site Management во порталот на 2Checkout.com. ',
    'gateway_help_60' => ':link за креирање на WePay сметка.',
    'more_designs' => 'Повеќе дизајни',
    'more_designs_title' => 'Додатни дизајни на фактура',
    'more_designs_cloud_header' => 'Станете Pro за повеќе дизајни на фактура',
    'more_designs_cloud_text' => '',
    'more_designs_self_host_text' => '',
    'buy' => 'Купи',
    'bought_designs' => 'Успешно додавање на дополнителни дизајни на фактура',
    'sent' => 'Испратено',
    'vat_number' => 'ДДВ број',
    'timesheets' => 'Извештаи за време',
    'payment_title' => 'Внеси ја твојата адреса за фактурирање и информации за кредитна картичка',
    'payment_cvv' => '*Ова е 3-4 цифрен број на задната страна од вашата картичка',
    'payment_footer1' => '*Адресата за фактурирање мора да се совпаѓа со адресата поврзана со кредитната картичка.',
    'payment_footer2' => '*Ве молиме кликнете "ПЛАТИ СЕГА" само еднаш - трансакцијата може да се процесира до 1 минута.',
    'id_number' => 'Идентификациски број',
    'white_label_link' => 'Брендирање',
    'white_label_header' => 'Брендирање',
    'bought_white_label' => 'Успешно овозможена лиценца за брендирање',
    'white_labeled' => 'Брендирано',
    'restore' => 'Поврати',
    'restore_invoice' => 'Поврати фактура',
    'restore_quote' => 'Поврати понуда',
    'restore_client' => 'Поврати клиент',
    'restore_credit' => 'Поврати кредит',
    'restore_payment' => 'Поврати плаќање',
    'restored_invoice' => 'Успешно повратување на фактура',
    'restored_quote' => 'Успешно повратување на понуда',
    'restored_client' => 'Успешно повратување на клиент',
    'restored_payment' => 'Успешно повратување на плаќање',
    'restored_credit' => 'Успешно повратување на кредит',
    'reason_for_canceling' => 'Помогнете ни да го подобриме нашиот сајт со тоа што ќе ни кажете зошто го напуштате.',
    'discount_percent' => 'Процент',
    'discount_amount' => 'Количина',
    'invoice_history' => 'Историја на фактура',
    'quote_history' => 'Историја на понуда',
    'current_version' => 'Сегашна верзија',
    'select_version' => 'Одбери верзија',
    'view_history' => 'Види историја',
    'edit_payment' => 'Измени плаќање',
    'updated_payment' => 'Успешно ажурирано плаќање',
    'deleted' => 'Избришано',
    'restore_user' => 'Поврати корисник',
    'restored_user' => 'Успешно повратување на корисник',
    'show_deleted_users' => 'Покажи избришани корисници',
    'email_templates' => 'Емаил шаблони',
    'invoice_email' => 'Мејл за фактура',
    'payment_email' => 'Мејл за плаќање',
    'quote_email' => 'Мејл за понуда',
    'reset_all' => 'Ресетирај се\'',
    'approve' => 'Одобри',
    'token_billing_type_id' => 'Фактурирање со токен',
    'token_billing_help' => 'Зачувај ги деталите за плаќањето со WePay, Stripe, Braintree или GoCardless.',
    'token_billing_1' => 'Оневозможено',
    'token_billing_2' => 'Полето за внесување е прикажано но не е избрано',
    'token_billing_3' => 'Полето за откажување е прикажано и избрано',
    'token_billing_4' => 'Секогаш',
    'token_billing_checkbox' => 'Зачувај детали за кредитна картичка',
    'view_in_gateway' => 'Прегледај во :gateway',
    'use_card_on_file' => 'Користи картичка на датотека',
    'edit_payment_details' => 'Измени детали на плаќање',
    'token_billing' => 'Зачувај детали на картичка',
    'token_billing_secure' => 'Податоците се сигурно зачувани од :link',
    'support' => 'Поддршка',
    'contact_information' => 'Информации за контакт',
    '256_encryption' => '256-Bit Енкрипција',
    'amount_due' => 'Износот што е должен',
    'billing_address' => 'Адреса на фактурирање',
    'billing_method' => 'Метод на фактурирање',
    'order_overview' => 'Преглед на нарачка',
    'match_address' => '*Адресата мора да се совпаѓа со адресата поврзана со кредитната картичка',
    'click_once' => '*Ве молиме кликнете "ПЛАТИ СЕГА" само еднаш - трансакцијата може да се процесира до 1 минута.',
    'invoice_footer' => 'Футер на фактура',
    'save_as_default_footer' => 'Зачувај како стандарден футер',
    'token_management' => 'Менаџирање на токен',
    'tokens' => 'Токени',
    'add_token' => 'Додај токен',
    'show_deleted_tokens' => 'Прикажи избришани токени',
    'deleted_token' => 'Успешно бришење на токен',
    'created_token' => 'Успешно креирање на токен',
    'updated_token' => 'Успешно ажурирање на токен',
    'edit_token' => 'Измени токен',
    'delete_token' => 'Избриши токен',
    'token' => 'Токен',
    'add_gateway' => 'Додади Платен портал',
    'delete_gateway' => 'Избриши Платен портал',
    'edit_gateway' => 'Уреди Платен портал',
    'updated_gateway' => 'Успешно ажурирање на платен портал',
    'created_gateway' => 'Успешно креиран платен портал',
    'deleted_gateway' => 'Успешно избришан платен портал',
    'pay_with_paypal' => 'PayPal',
    'pay_with_card' => 'Кредитна картичка',
    'change_password' => 'Промени лозинка',
    'current_password' => 'Сегашна лозинка',
    'new_password' => 'Нова лозинка',
    'confirm_password' => 'Потврди лозинка',
    'password_error_incorrect' => 'Сегашната лозинка е неточна.',
    'password_error_invalid' => 'Новата лозинка е невалидна.',
    'updated_password' => 'Успешно ажурирање на лозинка',
    'api_tokens' => 'API токени',
    'users_and_tokens' => 'Корисници и токени',
    'account_login' => 'Најавување на сметка',
    'recover_password' => 'Поврати ја твојата лозинка',
    'forgot_password' => 'Ја заборави лозинката?',
    'email_address' => 'Емаил адреса',
    'lets_go' => 'Да одиме',
    'password_recovery' => 'Поврат на лозинка',
    'send_email' => 'Испрати емаил',
    'set_password' => 'Сетирај лозинка',
    'converted' => 'Конвертирано',
    'email_approved' => 'Испрати ми е-пошта кога понудата е <b> одобрена </b>',
    'notification_quote_approved_subject' => 'Понудата :invoice беше одобрена од :client ',
    'notification_quote_approved' => 'Клиентот :client ја одобри понудата :invoice за :amount.',
    'resend_confirmation' => 'Испрати повторно мејл за потврда',
    'confirmation_resent' => 'Мејлот за потврда беше повторно испратен',
    'gateway_help_42' => ':link за регистрација на BitPay. <br/> Забелешка: користете Legacy API клуч, не API токен.',
    'payment_type_credit_card' => 'Кредитна картичка',
    'payment_type_paypal' => 'PayPal',
    'payment_type_bitcoin' => 'Bitcoin',
    'payment_type_gocardless' => 'GoCardless',
    'knowledge_base' => 'База на знаења',
    'partial' => 'Делумно/Депозит',
    'partial_remaining' => ':partial на :balance',
    'more_fields' => 'Повеќе полиња',
    'less_fields' => 'Помалку полиња',
    'client_name' => 'Име на клиент',
    'pdf_settings' => 'Поставки за PDF',
    'product_settings' => 'Поставки за продукт',
    'auto_wrap' => 'Автоматско завршување на линија',
    'duplicate_post' => 'Предупредување: претходната страна беше поднесена два пати. Второто поднесување е игнорирано.',
    'view_documentation' => 'Види документација',
    'app_title' => 'Бесплатно Open-Source онлајн фактурирање',
    'app_description' => 'Invoice Ninja е бесплатно, отворено решение за фактурирање и наплата на клиенти. Со Invoice Ninja, можете лесно да создадете и да пратите прекрасни фактури од било кој уред кој има пристап до веб. Вашите клиенти можат да ја испечатат фактурата, да ја преземат како pdf датотека и дури да платат онлајн во системот.',
    'rows' => 'Редови',
    'www' => 'www',
    'logo' => 'Лого',
    'subdomain' => 'Поддомен',
    'provide_name_or_email' => 'Ве молиме наведете име или е-пошта',
    'charts_and_reports' => 'Графикони и Извештаи',
    'chart' => 'Графикон',
    'report' => 'Извештај',
    'group_by' => 'Групирај по',
    'paid' => 'Платено',
    'enable_report' => 'Извештај',
    'enable_chart' => 'Графикон',
    'totals' => 'Вкупно',
    'run' => 'Почни',
    'export' => 'Експортирај',
    'documentation' => 'Документација',
    'zapier' => 'Zapier',
    'recurring' => 'Повторувачки',
    'last_invoice_sent' => 'Последна фактура испратена на :date',
    'processed_updates' => 'Успешно завршено ажурирање',
    'tasks' => 'Задачи',
    'new_task' => 'Нова задача',
    'start_time' => 'Време за почеток',
    'created_task' => 'Успешно креирана задача',
    'updated_task' => 'Успешно ажурирана задача',
    'edit_task' => 'Измени задача',
    'clone_task' => 'Клонирај задача',
    'archive_task' => 'Архивирај задача',
    'restore_task' => 'Поврати задача',
    'delete_task' => 'Избриши задача',
    'stop_task' => 'Стопирај задача',
    'time' => 'Време',
    'start' => 'Почеток',
    'stop' => 'Сопри',
    'now' => 'Сега',
    'timer' => 'Тајмер',
    'manual' => 'Упатство',
    'date_and_time' => 'Датум и време',
    'second' => 'Секунда',
    'seconds' => 'Секунди',
    'minute' => 'Минута',
    'minutes' => 'Минути',
    'hour' => 'Час',
    'hours' => 'Часови',
    'task_details' => 'Детали на задача',
    'duration' => 'Времетраење',
    'time_log' => 'Time Log',
    'end_time' => 'Измени време',
    'end' => 'Крај',
    'invoiced' => 'Фактурирано',
    'logged' => 'Најавено',
    'running' => 'Во тек',
    'task_error_multiple_clients' => 'Задачите не можат да припаѓаат на различни клиенти',
    'task_error_running' => 'Ве молиме прво сопрете ги задачите во тек',
    'task_error_invoiced' => 'Задачите се веќе фактурирани',
    'restored_task' => 'Успешно повратување на задача',
    'archived_task' => 'Успешно архивирање на задача',
    'archived_tasks' => 'Успешно архивирани :count задачи',
    'deleted_task' => 'Успешно бришење на задача',
    'deleted_tasks' => 'Успешно избришани :count задачи',
    'create_task' => 'Креирај задача',
    'stopped_task' => 'Успешно сопирање на задача',
    'invoice_task' => 'Задача на фактура',
    'invoice_labels' => 'Назнаки на фактура',
    'prefix' => 'Префикс',
    'counter' => 'Бројач',
    'payment_type_dwolla' => 'Dwolla',
    'gateway_help_43' => ':link за регистрирање на Dwolla',
    'partial_value' => 'Мора да биде поголемо од нула а помало од вкупно',
    'more_actions' => 'Повеќе акции',
    'pro_plan_title' => 'NINJA PRO',
    'pro_plan_call_to_action' => 'Надгради сега!',
    'pro_plan_feature1' => 'Креирај неограничен број на клиенти',
    'pro_plan_feature2' => 'Добиј пристап до 10 прекрасни дизајни за фактура',
    'pro_plan_feature3' => 'Прилагодени URL - "YourBrand.InvoiceNinja.com"',
    'pro_plan_feature4' => 'Отстрани "Креирано со Invoice Ninja"',
    'pro_plan_feature5' => 'Пристап на повеќе корисници и следење на активностите',
    'pro_plan_feature6' => 'Креирај понуди и Про-форма фактури',
    'pro_plan_feature7' => 'Прилагоди ги насловите и нумерирањето на полињата на фактурата',
    'pro_plan_feature8' => 'Опција за прикачување на PDF документи на е-пошта на клиентите',
    'resume' => 'Продолжи',
    'break_duration' => 'Прекин',
    'edit_details' => 'Измени детали',
    'work' => 'Работа',
    'timezone_unset' => 'Ве молиме :link за подесување на вашата временска зона',
    'click_here' => 'кликни тука',
    'email_receipt' => 'Прати потврда за плаќање на е-пошта до клиентот',
    'created_payment_emailed_client' => 'Успешно креирано плаќање и испратено по е-пошта на клиентот',
    'add_company' => 'Додај компанија',
    'untitled' => 'Без наслов',
    'new_company' => 'Нова компанија',
    'associated_accounts' => 'Успешно поврзани сметки',
    'unlinked_account' => 'Успешно прекината врска на сметки',
    'login' => 'Најава',
    'or' => 'или',
    'email_error' => 'Имаше проблем при испраќањето на е-пошта',
    'confirm_recurring_timing' => 'Забелешка: е-поштата е пратена на почетокот на часот.',
    'confirm_recurring_timing_not_sent' => 'Забелешка: фактурите се креирани на почетокот на часот.',
    'payment_terms_help' => 'Го поставува стандардниот <b> датум на достасување на фактура </b>',
    'unlink_account' => 'Прекини врска со сметка',
    'unlink' => 'Прекини врска',
    'show_address' => 'Прикажи адреса',
    'show_address_help' => 'Побарај од клиентот да обезбеди платежна адреса',
    'update_address' => 'Ажурирај адреса',
    'update_address_help' => 'Ажурирај ја адресата на клиентот со обезбедените детали',
    'times' => 'Последователност',
    'set_now' => 'Намести на сега',
    'dark_mode' => 'Темен режим',
    'dark_mode_help' => 'Користи темна позадина за страничните ленти',
    'add_to_invoice' => 'Додади на фактура :invoice',
    'create_new_invoice' => 'Креирај нова фактура',
    'task_errors' => 'Ве молиме корегирајте времињата што се преклопуваат',
    'from' => 'Од',
    'to' => 'До',
    'font_size' => 'Големина на фонт',
    'primary_color' => 'Примарна боја',
    'secondary_color' => 'Секундарна боја',
    'customize_design' => 'Прилагоди дизајн',
    'content' => 'Содржина',
    'styles' => 'Стилови',
    'defaults' => 'Стандарди',
    'margins' => 'Маргини',
    'header' => 'Заглавје',
    'footer' => 'Футер',
    'custom' => 'Прилагодено',
    'invoice_to' => 'Фактурирај на',
    'invoice_no' => 'Фактура број',
    'quote_no' => 'Понуда број',
    'recent_payments' => 'Неодамнешни плаќања',
    'outstanding' => 'Ненаплатено',
    'manage_companies' => 'Менаџирај компании',
    'total_revenue' => 'Вкупен приход',
    'current_user' => 'Сегашен корисник',
    'new_recurring_invoice' => 'Нова повторувачка фактура',
    'recurring_invoice' => 'Повторувачка фактура',
    'new_recurring_quote' => 'Нова Повторувачка Понуда',
    'recurring_quote' => 'Повторувачка понуда',
    'recurring_too_soon' => 'Многу е рано за да се креира следната повторувачка фактура, закажано е на :date',
    'created_by_invoice' => 'Креирано од :invoice',
    'primary_user' => 'Примарен корисник',
    'help' => 'Помош',
    'customize_help' => '<p> Користиме :pdfmake_link за да ги дефинираме декларативно дизајните на фактурата. dfmake :playground_link обезбедува гледање на библиотеката во акција на прекрасен начин. </p> 
 <p> Ако ви треба помош околу нешто објавете прашање на нашиот :forum_link со дизајнот кој го користите. </p>',
    'playground' => 'игралиште',
    'support_forum' => 'Форум за поддршка',
    'invoice_due_date' => 'Датум на достасување ',
    'quote_due_date' => 'Валидно до',
    'valid_until' => 'Валидно до',
    'reset_terms' => 'Ресетирај термини',
    'reset_footer' => 'Ресетирај футер',
    'invoice_sent' => ':count испратена фактура',
    'invoices_sent' => ':count испратени фактури',
    'status_draft' => 'Нацрт',
    'status_sent' => 'Испратено',
    'status_viewed' => 'Видено',
    'status_partial' => 'Делумно',
    'status_paid' => 'Платено',
    'status_unpaid' => 'Неплатено',
    'status_all' => 'Се\'',
    'show_line_item_tax' => 'Прикажи <b> линирани даночни ставки во линија </b>',
    'iframe_url' => 'Веб страна',
    'iframe_url_help1' => 'Копирај го следниот код на страна од твојот веб сајт.',
    'iframe_url_help2' => 'Можете да ја тестирате функцијата преку кликање на \'Види како примател\' за фактура',
    'auto_bill' => 'Автоматска наплата',
    'military_time' => 'Време од 24 часа',
    'last_sent' => 'Последно испратено',
    'reminder_emails' => 'Е-пошта за потсетување',
    'quote_reminder_emails' => 'Потсетувачки е-пораки за Понуда',
    'templates_and_reminders' => 'Шаблони и потсетници',
    'subject' => 'Предмет',
    'body' => 'Конструкција',
    'first_reminder' => 'Прв потсетник',
    'second_reminder' => 'Втор потсетник',
    'third_reminder' => 'Трет потсетник',
    'num_days_reminder' => 'Денови по датумот на достасување',
    'reminder_subject' => 'Потсетник: Фактурата :invoice од :account',
    'reset' => 'Ресетирај',
    'invoice_not_found' => 'Бараната фактура не е достапна',
    'referral_program' => 'Програма за упатување',
    'referral_code' => 'Препратен URL',
    'last_sent_on' => 'Последно испратено: :date ',
    'page_expire' => 'Оваа страница ќе истече наскоро, :click_here за да продолжите да работите',
    'upcoming_quotes' => 'Претстојни понуди',
    'expired_quotes' => 'Истечени понуди ',
    'sign_up_using' => 'Регистрирај се преку',
    'invalid_credentials' => 'Овие креденцијали не се совпаѓаат со нашите записи',
    'show_all_options' => 'Покажи ги сите опции',
    'user_details' => 'Детали за корисникот',
    'oneclick_login' => 'Поврзана сметка',
    'disable' => 'Оневозможи',
    'invoice_quote_number' => 'Број на фактура и барање ',
    'invoice_charges' => 'Надоместоци за фактура',
    'notification_invoice_bounced' => 'Не можевме да ја доставиме фактурата :invoice на :contact',
    'notification_invoice_bounced_subject' => 'Не успеавме да ја доставиме фактурата :invoice',
    'notification_quote_bounced' => 'Не можевме да ја доставиме понудата :invoice на :contact',
    'notification_quote_bounced_subject' => 'Не успеавме да ја доставиме понудата :invoice',
    'custom_invoice_link' => 'Прилагоден линк на фактура',
    'total_invoiced' => 'Вкупно фактурирано',
    'open_balance' => 'Состојба на побарувања',
    'verify_email' => 'Ве молиме кликнете на линкот во мејлот за потврда на сметката за да ја потврдите вашата е-адреса.',
    'basic_settings' => 'Основни поставки',
    'pro' => 'Про',
    'gateways' => 'Платен портал',
    'next_send_on' => 'Следно прати на: :date',
    'no_longer_running' => 'Оваа фактура не е закажана за почнување',
    'general_settings' => 'Општи поставки',
    'customize' => 'Прилагоди',
    'oneclick_login_help' => 'Поврзи сметка за најавување без лозинка',
    'referral_code_help' => 'Заработи пари преку споделување на нашата апликација онлајн',
    'enable_with_stripe' => 'Овозможи | Бара Stripe',
    'tax_settings' => 'Поставки за данок',
    'create_tax_rate' => 'Додај стапка на данок',
    'updated_tax_rate' => 'Успешно ажурирана стапка на данок',
    'created_tax_rate' => 'Успешно креирана стапка на данок',
    'edit_tax_rate' => 'Измени стапка на данок',
    'archive_tax_rate' => 'Архивирај стапка на данок',
    'archived_tax_rate' => 'Успешно архивирана стапка на данок ',
    'default_tax_rate_id' => 'Стандардна даночна стапка',
    'tax_rate' => 'Даночна стапка',
    'recurring_hour' => 'Повторувачки час',
    'pattern' => 'Шема',
    'pattern_help_title' => 'Помош за шема',
    'pattern_help_1' => 'Креирај прилагодени броецви преку одредување на шема',
    'pattern_help_2' => 'Достапни варијабли:',
    'pattern_help_3' => 'На пример, :example би се конвертирало во :value',
    'see_options' => 'Види опции',
    'invoice_counter' => 'Бројач на фактури',
    'quote_counter' => 'Бројач на понуди ',
    'type' => 'Тип',
    'activity_1' => ':user го креираше клиентот :client',
    'activity_2' => ':user го архивираше клиентот :client',
    'activity_3' => ':user го избриша клиентот :client',
    'activity_4' => ':user ја креираше фактурата :invoice',
    'activity_5' => ':user ја ажурираше фактурата :invoice',
    'activity_6' => ':user emailed invoice :invoice for :client to :contact',
    'activity_7' => ':contact viewed invoice :invoice for :client',
    'activity_8' => ':user ја архивира фактурата :invoice',
    'activity_9' => ':user ја избриша фактурата :invoice',
    'activity_10' => ':contact entered payment :payment for :payment_amount on invoice :invoice for :client',
    'activity_11' => ':user го ажурира плаќањето :payment',
    'activity_12' => ':user го архивира плаќањето :payment',
    'activity_13' => ':user го избриша плаќањето :payment',
    'activity_14' => ':user внесе :credit кредит',
    'activity_15' => ':user ажурира :credit кредит',
    'activity_16' => ':user архивира :credit кредит',
    'activity_17' => ':user избриша :credit кредит',
    'activity_18' => ':user ја креира понудата :quote',
    'activity_19' => ':user ја ажурира понудата :quote',
    'activity_20' => ':user emailed quote :quote for :client to :contact',
    'activity_21' => ':contact ја виде понудата :quote',
    'activity_22' => ':user ја архивира понудата :quote',
    'activity_23' => ':user ја избриша понудата :quote',
    'activity_24' => ':user ја поврати понудата :quote',
    'activity_25' => ':user ја поврати фактурата :invoice',
    'activity_26' => ':user го поврати клиентот :client',
    'activity_27' => ':user го поврати плаќањето :payment',
    'activity_28' => ':user го поврати :credit кредитот',
    'activity_29' => ':contact approved quote :quote for :client',
    'activity_30' => ':user го креира продавачот :vendor',
    'activity_31' => ':user го архивира продавачот :vendor',
    'activity_32' => ':user го избриша продавачот :vendor',
    'activity_33' => ':user го поврати продавачот :vendor',
    'activity_34' => ':user го креира трошокот :expense',
    'activity_35' => ':user го архивира трошокот :expense',
    'activity_36' => ':user го избриша трошокот :expense',
    'activity_37' => ':user го поврати трошокот :expense',
    'activity_42' => ':user ја креира задачата :task',
    'activity_43' => ':user ажурира задачата :task',
    'activity_44' => ':user ја архивира задачата :task',
    'activity_45' => ':user ја избриша задачата :task',
    'activity_46' => ':user ја поврати задачата :task',
    'activity_47' => ':user го ажурира трошокот :expense',
    'activity_48' => ':user updated ticket :ticket',
    'activity_49' => ':user closed ticket :ticket',
    'activity_50' => ':user merged ticket :ticket',
    'activity_51' => ':user split ticket :ticket',
    'activity_52' => ':contact opened ticket :ticket',
    'activity_53' => ':contact reopened ticket :ticket',
    'activity_54' => ':user reopened ticket :ticket',
    'activity_55' => ':contact replied ticket :ticket',
    'activity_56' => ':user viewed ticket :ticket',

    'payment' => 'Плаќање',
    'system' => 'Систем',
    'signature' => 'Потпис на е-пошта',
    'default_messages' => 'Стандардни пораки',
    'quote_terms' => 'Услови на понуда',
    'default_quote_terms' => 'Стандардни услови на понуда',
    'default_invoice_terms' => 'Стандардни услови на фактура',
    'default_invoice_footer' => 'Стандарден футер на фактура',
    'quote_footer' => 'Футер на понуда',
    'free' => 'Бесплатно',
    'quote_is_approved' => 'Успешно одобрување',
    'apply_credit' => 'Примени кредит',
    'system_settings' => 'Поставки на системот',
    'archive_token' => 'Архивирај токен',
    'archived_token' => 'Успешно архивирање на токен',
    'archive_user' => 'Архивирај корисник',
    'archived_user' => 'Успешно архивирање на корисник',
    'archive_account_gateway' => 'Delete Gateway',
    'archived_account_gateway' => 'Успешно архивирање на платен портал',
    'archive_recurring_invoice' => 'Архивирај повторувачка фактура',
    'archived_recurring_invoice' => 'Успешно архивирање на повторувачка фактура',
    'delete_recurring_invoice' => 'Избриши повторувачка фактура',
    'deleted_recurring_invoice' => 'Успешно бришење на повторувачка фактура',
    'restore_recurring_invoice' => 'Поврати повторувачка фактура',
    'restored_recurring_invoice' => 'Успешно повратена повторувачка фактура',
    'archive_recurring_quote' => 'Архивирај повторувачка понуда',
    'archived_recurring_quote' => 'Успешно архивирана повторувачка понуда',
    'delete_recurring_quote' => 'Избриши повторувачка понуда',
    'deleted_recurring_quote' => 'Успешно избришана повторувачка понуда',
    'restore_recurring_quote' => 'Поврати повторувачка понуда',
    'restored_recurring_quote' => 'Успешно повратена повторувачка понуда',
    'archived' => 'Архивирано',
    'untitled_account' => 'Ненасловена компанија',
    'before' => 'Пред',
    'after' => 'Потоа',
    'reset_terms_help' => 'Ресетирај на стандардни услови на сметката',
    'reset_footer_help' => 'Ресетирај на стандарден футер на сметка',
    'export_data' => 'Експортирај податоци',
    'user' => 'Корисник',
    'country' => 'Држава',
    'include' => 'Вклучува',
    'logo_too_large' => 'Вашето лого е :size, за подобар PDF перформанс ви препорачуваме прикачување на слика помала од 200КБ ',
    'import_freshbooks' => 'Внесување од FreshBooks',
    'import_data' => 'Внеси податоци',
    'source' => 'Извор',
    'csv' => 'CSV',
    'client_file' => 'Датотека на клиент',
    'invoice_file' => 'Датотека на фактура',
    'task_file' => 'Датотека на задача',
    'no_mapper' => 'Нема валидно мапирање за датотека',
    'invalid_csv_header' => 'Невалидно CSV заглавие',
    'client_portal' => 'Портал на клиент',
    'admin' => 'Админ',
    'disabled' => 'Оневозможено',
    'show_archived_users' => 'Прикажи архивирани корисници',
    'notes' => 'Забелешки',
    'invoice_will_create' => 'Фактурата ќе биде креирана ',
    'invoices_will_create' => 'Фактурите ќе бидат креирани ',
    'failed_to_import' => 'Неуспешно внесување на следните записи, тие или претходно постоеле или им недостасуваат некои задолжителни полиња.',
    'publishable_key' => 'Клуч којшто може да се објавува',
    'secret_key' => 'Таен клуч',
    'missing_publishable_key' => 'Поставете го вашиот Stripe клуч којшто може да се објавува за подобар процес на проверка',
    'email_design' => 'Дизајн на е-пошта',
    'due_by' => 'Достасува на :date',
    'enable_email_markup' => 'Овозможи обележување',
    'enable_email_markup_help' => 'Направете го полесно плаќањето за вашите клиенти со додавање на schema.org обележје на вашите е-пошти',
    'template_help_title' => 'Помош за шаблони',
    'template_help_1' => 'Достапни варијабли:',
    'email_design_id' => 'Стил на е-пошта',
    'email_design_help' => 'Направи го изгледот на твојата е-пошта попрофесионален со HTML изглед.',
    'plain' => 'Обично',
    'light' => 'Светло',
    'dark' => 'Темно',
    'industry_help' => 'Користено за да се обезбеди споредба на просекот на компаниите од слична големина и индустријата.',
    'subdomain_help' => 'Поставете го поддоменот или прикажете ја фактурата на вашата веб страна.',
    'website_help' => 'Display the invoice in an iFrame on your own website',
    'invoice_number_help' => 'Одредете префикс или користете прилагодена шема за динамично поставување на бројот на фактура.',
    'quote_number_help' => 'Одредете префикс или користете прилагодена шема за динамично поставување на бројот на понуда.',
    'custom_client_fields_helps' => 'Додадете поле при креирање на клиент и опционално прикажете ја назнаката и вредноста на PDF.',
    'custom_account_fields_helps' => 'Додадете ознака и вредност во секцијата за детали за компанијата во PDF',
    'custom_invoice_fields_helps' => 'Додадете поле при креирање на фактура и опционално прикажете ја назнаката и вредноста на PDF.',
    'custom_invoice_charges_helps' => 'Додадете поле при креирање на фактурата и вклучете го наплатеното во посебните делови за вкупно на фактурата.',
    'token_expired' => 'Токенот за валидација е истечен. Ве молиме обидете се повторно.',
    'invoice_link' => 'Линк на фактура',
    'button_confirmation_message' => 'Кликнете за да ја потврдите вашата адреса на е-пошта',
    'confirm' => 'Потврди',
    'email_preferences' => 'Преференци за е-пошта',
    'created_invoices' => 'Успешно креирани :count invoice(s)',
    'next_invoice_number' => 'Следниот број на фактура е :number.',
    'next_quote_number' => 'Следниот број на понуда е :number.',
    'days_before' => 'дена пред',
    'days_after' => 'дена по',
    'field_due_date' => 'Датум на достасување',
    'field_invoice_date' => 'Датум на фактура',
    'schedule' => 'Распоред',
    'email_designs' => 'Дизајн на е-пошта',
    'assigned_when_sent' => 'Назначено кога е испратено',
    'white_label_purchase_link' => 'Купете лиценца за брендирање',
    'expense' => 'Трошок',
    'expenses' => 'Трошоци',
    'new_expense' => 'Внеси трошок',
    'enter_expense' => 'Внеси трошок',
    'vendors' => 'Продавачи',
    'new_vendor' => 'Нов продавач',
    'payment_terms_net' => 'Мрежа',
    'vendor' => 'Продавач',
    'edit_vendor' => 'Измени продавач',
    'archive_vendor' => 'Архивирај продавач',
    'delete_vendor' => 'Избриши продавач',
    'view_vendor' => 'Прегледај продавач',
    'deleted_expense' => 'Успешно бришење на трошок',
    'archived_expense' => 'Успешно архивирање на трошок',
    'deleted_expenses' => 'Успешно бришење на трошоци',
    'archived_expenses' => 'Успешно архивирање на трошоци',
    'expense_amount' => 'Износ на трошок',
    'expense_balance' => 'Состојба на трошоци',
    'expense_date' => 'Датум на трошок',
    'expense_should_be_invoiced' => 'Дали овој трошок да биде фактуриран?',
    'public_notes' => 'Јавни забелешки',
    'invoice_amount' => 'Износ на фактура',
    'exchange_rate' => 'Девизен курс',
    'yes' => 'Да',
    'no' => 'Не',
    'should_be_invoiced' => 'Треба  да биде фактурирано',
    'view_expense' => 'Преглед на трошок # :expense',
    'edit_expense' => 'Измени трошок',
    'archive_expense' => 'Архивирај трошок',
    'delete_expense' => 'Избриши трошок',
    'view_expense_num' => 'Трошок # :expense',
    'updated_expense' => 'Успешно ажурирање на трошок',
    'created_expense' => 'Успешно креирање на трошок',
    'enter_expense' => 'Внеси трошок',
    'view' => 'Преглед',
    'restore_expense' => 'Поврати трошок',
    'invoice_expense' => 'Фактурирај трошок',
    'expense_error_multiple_clients' => 'Трошоците не можат да припаѓаат на различни клиенти',
    'expense_error_invoiced' => 'Трошокот е веќе фактуриран',
    'convert_currency' => 'Конвертирај валута',
    'num_days' => 'Број на денови',
    'create_payment_term' => 'Креирај термин на плаќање ',
    'edit_payment_terms' => 'Измени термин на плаќање',
    'edit_payment_term' => 'Измени термин на плаќање',
    'archive_payment_term' => 'Архивирај термин на плаќање ',
    'recurring_due_dates' => 'Датуми на достасување на повторувачка фактура',
    'recurring_due_date_help' => '<p> Датумот на достасување на фактурата е автоматски подесен. </p> 
 <p> Датумот на достасување на фактурите кои што се на месечен или годишен циклус е подесен на или еден ден пред датумот на кој што се креирани за наредниот месец. Датумот на достасување на фактурите е подесен на 29ти или 30ти ден од месецот а за месеци кои немаат толку денови е подесен на последниот ден од месецот. </p> 
 <p>  Фактурите со неделен циклус се подесени со датум на достасување на денот на кој се креирани наредната недела. </p> 
 <p> На пример: </p> 
 <ul> 
 <li> Денес е 15ти ден од месецот, датумот на достасување е првиот ден од месецот. Логично датумот на достасување би бил првиот ден од наредниот месец. </li> 
 <li> Денес е 15ти ден од месецот,  датумот на достасување е последниот ден од месецот. Датумот на достасување би бил последниот ден од тековниот месец. 
</li> 
 <li> Денес е 15ти, датумот на достасување е 15ти ден од месецот. Датумот на достасување би бил 15ти ден од <strong> наредниот </strong> месец. 
 </li> 
 <li> Денес е петок, датумот на достасување е првиот петок потоа. Датумот на достасување би бил наредниот петок, не денес. 
 </li> 
 </ul>',
    'due' => 'До',
    'next_due_on' => 'Следно достасување :date',
    'use_client_terms' => 'Користи услови на клиент',
    'day_of_month' => ':ordinal ден од месецот',
    'last_day_of_month' => 'Последен ден од месецот',
    'day_of_week_after' => ':ordinal :day потоа',
    'sunday' => 'Недела',
    'monday' => 'Понеделник',
    'tuesday' => 'Вторник',
    'wednesday' => 'Среда',
    'thursday' => 'Четврток',
    'friday' => 'Петок',
    'saturday' => 'Сабота',
    'header_font_id' => 'Фонт на заглавје',
    'body_font_id' => 'Фонт на конструкција',
    'color_font_help' => 'Забелешка: примарната боја и фонтови се исто така користени во порталот на клиентот и во посебните дизајни на е-пошта.',
    'live_preview' => 'Преглед во живо',
    'invalid_mail_config' => 'Е-поштата не може да се испрати, ве молиме проверете дали поставките за е-пошта се точни.',
    'invoice_message_button' => 'За преглед на фактурата за :amount, кликнете на копчето подоле.',
    'quote_message_button' => 'За преглед на понудата за :amount, кликнете на копчето подоле.',
    'payment_message_button' => 'Ви благодариме за вашето плаќање од :amount.',
    'payment_type_direct_debit' => 'Директно задолжување',
    'bank_accounts' => 'Кредитни картички и банки',
    'add_bank_account' => 'Додај банкарска сметка',
    'setup_account' => 'Постави сметка',
    'import_expenses' => 'Внеси трошоци',
    'bank_id' => 'Банка',
    'integration_type' => 'Тип на интеграција',
    'updated_bank_account' => 'Успешно ажурирана банкарска сметка',
    'edit_bank_account' => 'Измени банкарска сметка',
    'archive_bank_account' => 'Архивирај банкарска сметка',
    'archived_bank_account' => 'Успешно архивирање на банкарска сметка',
    'created_bank_account' => 'Успешно креирање на банкарска сметка',
    'validate_bank_account' => 'Валидирај банкарска сметка',
    'bank_password_help' => 'Забелешка: вашата лозинка е безбедно пренесена и никогаш нема да е зачувана на нашите сервери.',
    'bank_password_warning' => 'Предупредување: вашата лозинка може да биде пренесена во обичен текст, имајте во предвид вклучување на HTTPS.',
    'username' => 'Корисничко име',
    'account_number' => 'Број на сметка',
    'account_name' => 'Име на сметка',
    'bank_account_error' => 'Неуспешен поврат на деталите за сметката, ве молиме да ги проверите вашите креденцијали.',
    'status_approved' => 'Одобрено',
    'quote_settings' => 'Поставки за понуда',
    'auto_convert_quote' => 'Автоматско конвертирање',
    'auto_convert_quote_help' => 'Автоматски конвертирај понуда во фактура кога истата ќе биде одобрена од клиентот.',
    'validate' => 'Валидирај',
    'info' => 'Инфо',
    'imported_expenses' => 'Успешно креирани :count_vendors продавачи и :count_expense(s) трошоци',
    'iframe_url_help3' => 'Забелешка: ако планирате да ги прифатите деталите за кредитни картички препорачуваме да овозможите HTTPS на вашиот сајт.',
    'expense_error_multiple_currencies' => 'Трошоците не можат да имаат различни валути.',
    'expense_error_mismatch_currencies' => 'Валутата на клиентот не се совпаѓа со валутата на трошокот.',
    'trello_roadmap' => 'Trello мапа',
    'header_footer' => 'Заглавје/Футер',
    'first_page' => 'Прва страна',
    'all_pages' => 'Сите страни',
    'last_page' => 'Последна страна',
    'all_pages_header' => 'Прикажи заглавје на',
    'all_pages_footer' => 'Прикажи футер на',
    'invoice_currency' => 'Валута на фактура',
    'enable_https' => 'Препорачуваме користење на HTTPS за прифаќање на детали од кредитна картичка онлајн.',
    'quote_issued_to' => 'Понуда издадена на',
    'show_currency_code' => 'Код на валута',
    'free_year_message' => 'Вашата сметка е ажурирана на pro план за една година без никакви трошоци.',
    'trial_message' => 'Вашата сметка ќе добие бесплатен пробен период на нашиот Pro план во траење од две недели.',
    'trial_footer' => 'Вашиот бесплатен пробен период на Pro план трае уште :count дена :link за ажурирање.',
    'trial_footer_last_day' => 'Ова е последниот ден од вашиот бесплатен пробен период на Pro план, :link за ажурирање.',
    'trial_call_to_action' => 'Започни бесплатен пробен период',
    'trial_success' => 'Успешно овозможен и две недели за бесплатен пробен период на Pro план',
    'overdue' => 'Задоцнето',


    'white_label_text' => 'Купете ЕДНОГОДИШЕН ПЛАН за брендирана лиценца за $:price за да го отстраните брендирањето на Invoice Ninja од клиентскиот портал.',
    'user_email_footer' => 'За прилагодување на вашите поставки за известувања преку е-пошта ве молиме посетете :link',
    'reset_password_footer' => 'Ако не поднесовте барање за ресетирање на лозинка ве молиме пратете е-пошта на нашата поддршка :email',
    'limit_users' => 'Извинете, ова ќе го надмине лимитот од :limit корисници',
    'more_designs_self_host_header' => 'Добијте 6 додатни дизајни за фактура за само $:price ',
    'old_browser' => 'Ве молиме користете :link',
    'newer_browser' => 'понов пребарувач',
    'white_label_custom_css' => ':link за $:price за овозможување пристап до прилагодено стилизирање и поддршка за нашиот проект.',
    'bank_accounts_help' => 'Поврзете банкарска сметка за автоматско внесување на трошоците и креирање на продавачи. Поддржува American Express и :link.',
    'us_banks' => '400+ Американски банки',

    'pro_plan_remove_logo' => ':link за отстранување на Invoice Ninja логото со приклучување на Pro планот',
    'pro_plan_remove_logo_link' => 'Кликни тука',
    'invitation_status_sent' => 'Испратено',
    'invitation_status_opened' => 'Отворено',
    'invitation_status_viewed' => 'Видено',
    'email_error_inactive_client' => 'Е-пошта не може да биде пратена на неактивни клиенти',
    'email_error_inactive_contact' => 'Е-пошта не може да биде пратена на неактивни контакти',
    'email_error_inactive_invoice' => 'Е-пошта не може да биде пратена на неактивни фактури',
    'email_error_inactive_proposal' => 'Е-пошта не може да биде пратена на неактивни предлози',
    'email_error_user_unregistered' => 'Ве молиме регистрирајте се на вашата сметка за да испратите е-пошта',
    'email_error_user_unconfirmed' => 'Ве молиме потврдете ја вашата сметка за да испратите е-пошта',
    'email_error_invalid_contact_email' => 'Невалидна контакт е-пошта',

    'navigation' => 'Навигација',
    'list_invoices' => 'Листа на фактури',
    'list_clients' => 'Листа на клиенти',
    'list_quotes' => 'Листа на понуди',
    'list_tasks' => 'Листа на задачи',
    'list_expenses' => 'Листа на трошоци',
    'list_recurring_invoices' => 'Листа на повторувачки фактури',
    'list_payments' => 'Листа на плаќања',
    'list_credits' => 'Листа на кредити',
    'tax_name' => 'Име на данок',
    'report_settings' => 'Поставки за извештај',
    'search_hotkey' => 'кратенка е /',

    'new_user' => 'Нов корисник',
    'new_product' => 'Нов продукт',
    'new_tax_rate' => 'Нова стапка на данок',
    'invoiced_amount' => 'Фактуриран износ',
    'invoice_item_fields' => 'Поле за ставка на фактура',
    'custom_invoice_item_fields_help' => 'Додади поле при креирање на ставка за фактура и прикажи обележје и вреднос на PDF.',
    'recurring_invoice_number' => 'Повторувачки број',
    'recurring_invoice_number_prefix_help' => 'Одреди префикс кој ќе биде додаден на бројот на фактура за повторувачки фактури.',

    // Client Passwords
    'enable_portal_password' => 'Фактури заштитени со лозинка',
    'enable_portal_password_help' => 'Ви дозволува поставување на лозинка за секој контакт. Ако поставите лозинка. контактот ќе мора да ја внесе лозинката пред да ги прегледа фактурите.',
    'send_portal_password' => 'Генерирај автоматски',
    'send_portal_password_help' => 'Ако не е поставена лозинка, ќе се изгенерира и ќе се прати заедно со првата фактура.',

    'expired' => 'Истечено',
    'invalid_card_number' => 'Бројот на кредитната картичка е невалиден.',
    'invalid_expiry' => 'Датумот на истекување не е валиден.',
    'invalid_cvv' => 'CVV не е валидно',
    'cost' => 'Цена',
    'create_invoice_for_sample' => 'Забелешка: креирајте ја вашата прва фактура за да можете да ја прегледате тука.',

    // User Permissions
    'owner' => 'Сопственик',
    'administrator' => 'Администратор',
    'administrator_help' => 'Дозвола за корисникот да менаџира со корисниците, да ги менува поставките и да ги модифицира сите записи',
    'user_create_all' => 'Креирај клиенти, фактури, итн.',
    'user_view_all' => 'Прегледај ги сите клиенти, фактури, итн.',
    'user_edit_all' => 'Измени ги сите клиенти, фактури, итн.',
    'gateway_help_20' => ':link за регистрација на Sage Pay.',
    'gateway_help_21' => ':link за регистрација на Sage Pay.',
    'partial_due' => 'Делумен долг',
    'restore_vendor' => 'Поврати продавач',
    'restored_vendor' => 'Успешно повраќање на продавач',
    'restored_expense' => 'Успешно повраќање на трошок',
    'permissions' => 'Дозволи',
    'create_all_help' => 'Дозволи на корисник да креира и модифицира записи',
    'view_all_help' => 'Дозволи на корисник да има преглед врз записи кој што не ги креирал',
    'edit_all_help' => 'Дозволи на корисник да модифицира записи кои не ги креирал',
    'view_payment' => 'Прегледај плаќање',

    'january' => 'Јануари',
    'february' => 'Февруари',
    'march' => 'Март',
    'april' => 'Април',
    'may' => 'Мај',
    'june' => 'Јуни',
    'july' => 'Јули',
    'august' => 'Август',
    'september' => 'Септември',
    'october' => 'Октомври',
    'november' => 'Ноември',
    'december' => 'Декември',

    // Documents
    'documents_header' => 'Документи:',
    'email_documents_header' => 'Документи:',
    'email_documents_example_1' => 'Widgets Receipt.pdf',
    'email_documents_example_2' => 'Final Deliverable.zip',
    'quote_documents' => 'Документи на понуда',
    'invoice_documents' => 'Документи на фактура',
    'expense_documents' => 'Документи на трошоци',
    'invoice_embed_documents' => 'Вметни документи',
    'invoice_embed_documents_help' => 'Вклучи ги прикачените слики во фактурата.',
    'document_email_attachment' => 'Прикачи документи',
    'ubl_email_attachment' => 'Прикачи UBL',
    'download_documents' => 'Преземи документи (:size)',
    'documents_from_expenses' => 'Од Трошоци:',
    'dropzone_default_message' => 'Спушти ги датотеките или кликни за да прикачување',
    'dropzone_default_message_disabled' => 'Uploads disabled',
    'dropzone_fallback_message' => 'Вашиот пребарувач не ја поддржува опцијата drag\'n\'drop за прикачување на датотеки',
    'dropzone_fallback_text' => 'Ве молиме користете ја резервната форма подоле за да ги прикачите вашите датотеки како во старите денови.',
    'dropzone_file_too_big' => 'Датотеката е преголема ({{filesize}}MiB). Max filesize: {{maxFilesize}}MiB.',
    'dropzone_invalid_file_type' => 'Не можете да прикачите датотеки од овој тип.',
    'dropzone_response_error' => 'Серверот одговори со {{statusCode}} код. ',
    'dropzone_cancel_upload' => 'Откажи прикачување',
    'dropzone_cancel_upload_confirmation' => 'Дали сте сигурни дека сакате да го откажете ова прикачување?',
    'dropzone_remove_file' => 'Отстрани датотека',
    'documents' => 'Документи',
    'document_date' => 'Датум на документ',
    'document_size' => 'Големина',

    'enable_client_portal' => 'Портал на клиентот',
    'enable_client_portal_help' => 'Прикажи/сокриј го порталот на клиентот.',
    'enable_client_portal_dashboard' => 'Контролна табла',
    'enable_client_portal_dashboard_help' => 'Прикажи/сокриј ја страната со контролната табла на порталот на клиентот.',

    // Plans
    'account_management' => 'Менаџирање на сметка',
    'plan_status' => 'Статус на план',

    'plan_upgrade' => 'Ажурирање',
    'plan_change' => 'Промени план',
    'pending_change_to' => 'Промени до',
    'plan_changes_to' => ':plan на :date',
    'plan_term_changes_to' => ':plan (:term) на :date',
    'cancel_plan_change' => 'Откажи промена',
    'plan' => 'План',
    'expires' => 'Истекува',
    'renews' => 'Обнови',
    'plan_expired' => ':plan планот истече',
    'trial_expired' => ':plan пробниот период за планот заврши ',
    'never' => 'Никогаш',
    'plan_free' => 'Бесплатно',
    'plan_pro' => 'Pro',
    'plan_enterprise' => 'Претпријатие',
    'plan_white_label' => 'Самохостирано (брендирано)',
    'plan_free_self_hosted' => 'Самохостирано (бесплатно)',
    'plan_trial' => 'Пробен период',
    'plan_term' => 'Термин',
    'plan_term_monthly' => 'Месечно',
    'plan_term_yearly' => 'Годишно',
    'plan_term_month' => 'Месец',
    'plan_term_year' => 'Година',
    'plan_price_monthly' => '$:price/Месец',
    'plan_price_yearly' => '$:price/Година',
    'updated_plan' => 'Ажурирани поставки на план',
    'plan_paid' => 'Терминот започна',
    'plan_started' => 'Планот започна',
    'plan_expires' => 'Планот истекува',

    'white_label_button' => 'Брендирање',

    'pro_plan_year_description' => 'Една година запишување на Invoice Ninja Pro планот.',
    'pro_plan_month_description' => 'Еден месец запишување на Invoice Ninja Pro планот.',
    'enterprise_plan_product' => 'План за претпријатие',
    'enterprise_plan_year_description' => 'Една година запишување на Invoice Ninja Pro планот за претпријатие.',
    'enterprise_plan_month_description' => 'Еден месец запишување на Invoice Ninja Pro планот за претпријатие.',
    'plan_credit_product' => 'Кредит',
    'plan_credit_description' => 'Кредит за неискористено време',
    'plan_pending_monthly' => 'Ќе се смени на месечно на :date',
    'plan_refunded' => 'Издадено е рефундирање.',

    'live_preview' => 'Преглед во живо',
    'page_size' => 'Големина на страна',
    'live_preview_disabled' => 'Прегледот во живо е оневозможен за поддршка на избраниот фонт',
    'invoice_number_padding' => 'Внатрешна маргина',
    'preview' => 'Преглед',
    'list_vendors' => 'Листа на продавачи',
    'add_users_not_supported' => 'Надоградете на план за претпријатија за да можете да додадете повеќе корисници на вашата сметка ',
    'enterprise_plan_features' => 'Планот за претпријатија дава поддршка за повеќе корисници и прикачувања на документи, :link за да ја видите целата листа на придобивки ',
    'return_to_app' => 'Врати се на апликација',


    // Payment updates
    'refund_payment' => 'Рефундирај плаќање',
    'refund_max' => 'Максимално:',
    'refund' => 'Рефундирај',
    'are_you_sure_refund' => 'Рефундирај ги избраните плаќања?',
    'status_pending' => 'Во тек',
    'status_completed' => 'Завршено',
    'status_failed' => 'Неуспешно',
    'status_partially_refunded' => 'Делумно рефундирано',
    'status_partially_refunded_amount' => ':amount рефундирано',
    'status_refunded' => 'Рефундирано',
    'status_voided' => 'Откажано',
    'refunded_payment' => 'Рефундирано плаќање',
    'activity_39' => ':user го откажа :payment_amount плаќањето :payment',
    'activity_40' => ':user го рефундира :adjustment на :payment_amount плаќање :payment',
    'card_expiration' => 'Истек:&nbsp:expires',

    'card_creditcardother' => 'Непознато',
    'card_americanexpress' => 'American Express',
    'card_carteblanche' => 'Carte Blanche',
    'card_unionpay' => 'UnionPay',
    'card_diners' => 'Diners Club',
    'card_discover' => 'Discover',
    'card_jcb' => 'JCB',
    'card_laser' => 'Laser',
    'card_maestro' => 'Maestro',
    'card_mastercard' => 'MasterCard',
    'card_solo' => 'Solo',
    'card_switch' => 'Switch',
    'card_visacard' => 'Visa',
    'card_ach' => 'ACH',

    'payment_type_stripe' => 'Stripe',
    'ach' => 'ACH',
    'enable_ach' => 'Прифати трансфер од американска банка',
    'stripe_ach_help' => 'ACH поддршката мора исто така да е овозможена во :link.',
    'ach_disabled' => 'Друг портал на плаќање е веќе конфигуриран за директно задолжување.',

    'plaid' => 'Plaid',
    'client_id' => 'Идентификација на клиент',
    'secret' => 'Тајно',
    'public_key' => 'Јавен клуч',
    'plaid_optional' => '(опционално)',
    'plaid_environment_help' => 'Кога е даден Stripe тест клуч, ќе биде користена развивачката средина на Plaid (тартан).',
    'other_providers' => 'Други провајдери',
    'country_not_supported' => 'Таа држава не е поддржана.',
    'invalid_routing_number' => 'Бројот на рутирање не е валиден.',
    'invalid_account_number' => 'Бројот на сметката не е валиден.',
    'account_number_mismatch' => 'Броевите на сметките не се совпаѓаат',
    'missing_account_holder_type' => 'Ве молиме одберете индивидуална или сметка на компанија.',
    'missing_account_holder_name' => 'Ве молиме внесете го името на сопственикот на сметката.',
    'routing_number' => 'Број за рутирање',
    'confirm_account_number' => 'Потврди го бројот на сметката',
    'individual_account' => 'Индивидуална сметка',
    'company_account' => 'Сметка на компанија',
    'account_holder_name' => 'Име на сопственик на сметка',
    'add_account' => 'Додај сметка',
    'payment_methods' => 'Начини на плаќање',
    'complete_verification' => 'Целосна верификација',
    'verification_amount1' => 'Износ 1',
    'verification_amount2' => 'Износ 2',
    'payment_method_verified' => 'Успешно завршена верификација',
    'verification_failed' => 'Неуспешна верификација',
    'remove_payment_method' => 'Отстрани го начинот на плаќање',
    'confirm_remove_payment_method' => 'Дали сте сигурни дека сакате да го отстраните начинот на плаќање?',
    'remove' => 'Отстрани',
    'payment_method_removed' => 'Отстранет начин на плаќање',
    'bank_account_verification_help' => 'Направивме два депозити на вашата сметка со опис "ВЕРИФИКАЦИЈА". За да се прикажат овие депозити на вашиот статус ќе бидат потребни 1-2 работни дена. Ве молиме внесете ги износите подоле. ',
    'bank_account_verification_next_steps' => 'Направивме два депозити на вашата сметка со опис "ВЕРИФИКАЦИЈА". За да се прикажат овие депозити на вашиот статус ќе бидат потребни 1-2 работни дена.
Откако ќе ги добиете износите, вратете се на оваа страница за начин на плаќање и кликнете "Заврши Верификација" до сметката.',
    'unknown_bank' => 'Непозната банка',
    'ach_verification_delay_help' => 'Ќе можете да ја користите сметката по завршувањето на верификацијата. Верификацијата обично трае 1-2 работни дена.',
    'add_credit_card' => 'Додај кредитна картичка',
    'payment_method_added' => 'Додаден начин на плаќање.',
    'use_for_auto_bill' => 'Користи за автоматска наплата',
    'used_for_auto_bill' => 'Начин на плаќање автоматска наплата',
    'payment_method_set_as_default' => 'Постави начин на плаќање автоматска наплата.',
    'activity_41' => ':payment_amount плаќање (:payment) е неуспешно',
    'webhook_url' => 'Webhook URL',
    'stripe_webhook_help' => 'Морате да :link.',
    'stripe_webhook_help_link_text' => 'додади го овој URL како крајна точка на Stripe',
    'gocardless_webhook_help_link_text' => 'додади го овој URL како крајна точка на GoCardless',
    'payment_method_error' => 'Имаше грешка при додавањето на вашиот начин на плаќање. Ве молиме обидете се повторно подоцна.',
    'notification_invoice_payment_failed_subject' => 'Плаќањето е неуспешно за фактура :invoice',
    'notification_invoice_payment_failed' => 'Плаќање направено од страна на клиентот :client на фактурата :invoice е неуспешно. Плаќањето ќе биде обележано како неуспешно и :amount ќе се додаде на балансот на клиентот.',
    'link_with_plaid' => 'Поврзете ја сметката веднаш со Plaid',
    'link_manually' => 'Поврзете рачно',
    'secured_by_plaid' => 'Осигурано од Plaid',
    'plaid_linked_status' => 'Вашата банкарска сметка во :bank',
    'add_payment_method' => 'Додади начин на плаќање',
    'account_holder_type' => 'Тип на сопственик на сметка',
    'ach_authorization' => 'Одобрувам :company да ја користи мојата банкарска сметка за идни плаќања и, ако е потребно, електронски да ја кредитира мојата сметка за да ги поправи погрешните дебити. Разбирам дека можам да ја откажам оваа дозвола во било кое време со отстранување на начинот на плаќање или преку контактирање на :email.',
    'ach_authorization_required' => 'Мора да се согласите на ACH трансакции.',
    'off' => 'Исклучено',
    'opt_in' => 'Влез',
    'opt_out' => 'Излез',
    'always' => 'Секогаш',
    'opted_out' => 'Излезено',
    'opted_in' => 'Влезено',
    'manage_auto_bill' => 'Менаџирај автоматска наплата',
    'enabled' => 'Овозможено',
    'paypal' => 'PayPal',
    'braintree_enable_paypal' => 'Овозможи PayPal плаќања преку BrainTree',
    'braintree_paypal_disabled_help' => 'PayPal платниот портал процесира PayPal плаќања',
    'braintree_paypal_help' => 'Исто така мора да :link',
    'braintree_paypal_help_link_text' => 'Поврзете го PayPal за вашата BrainTree сметка ',
    'token_billing_braintree_paypal' => 'Зачувај детали за плаќање',
    'add_paypal_account' => 'Додај PayPal сметка',


    'no_payment_method_specified' => 'Нема одредено начин на плаќање',
    'chart_type' => 'Тип на графикон',
    'format' => 'Формат',
    'import_ofx' => 'Внеси OFX',
    'ofx_file' => 'OFX датотека',
    'ofx_parse_failed' => 'Неуспешно парсирање на OFX датотека',

    // WePay
    'wepay' => 'WePay',
    'sign_up_with_wepay' => 'Регистрирај се на WePay',
    'use_another_provider' => 'Користи друг провајдер',
    'company_name' => 'Име на компанија',
    'wepay_company_name_help' => 'Ова ќе се појави на изјавите на кредитните картички од клиентите',
    'wepay_description_help' => 'Целта на оваа сметка.',
    'wepay_tos_agree' => 'Се согласувам со :link.',
    'wepay_tos_link_text' => 'WePay услови на услуга',
    'resend_confirmation_email' => 'Испрати повторно е-пошта за потврда',
    'manage_account' => 'Управувај со сметка',
    'action_required' => 'Потребна е акција',
    'finish_setup' => 'Заврши го поставувањето',
    'created_wepay_confirmation_required' => 'Ве молиме проверете ја вашата е-пошта и потврдете ја вашата ел. адреса со WePay.',
    'switch_to_wepay' => 'Префрли на WePay',
    'switch' => 'Префрли',
    'restore_account_gateway' => 'Поврати платен портал',
    'restored_account_gateway' => 'Успешно повратување на платниот портал',
    'united_states' => 'Соединетите Американски Држави',
    'canada' => 'Канада',
    'accept_debit_cards' => 'Прифати дебитни картички',
    'debit_cards' => 'Дебитни картички',

    'warn_start_date_changed' => 'Следната фактура ќе биде испратена на новиот датум на почеток.',
    'warn_start_date_changed_not_sent' => 'Следната фактура ќе биде креирана на новиот датум на почеток.',
    'original_start_date' => 'Оригинален датум на почеток',
    'new_start_date' => 'Нов датум на почеток',
    'security' => 'Осигурување',
    'see_whats_new' => 'Види што има ново во v:version',
    'wait_for_upload' => 'Ве молиме почекајте да заврши прикачувањето на документот.',
    'upgrade_for_permissions' => 'Надградете на план за претпријатие за да овозможите дозволи.',
    'enable_second_tax_rate' => 'Овозможи одредување на  <b> втора рата на данок </b>',
    'payment_file' => 'Датотека на плаќање',
    'expense_file' => 'Датотека на трошок',
    'product_file' => 'Датотека на продукт',
    'import_products' => 'Внеси продукти',
    'products_will_create' => 'продуктите ќе бидат креирани',
    'product_key' => 'Продукт',
    'created_products' => 'Успешно креиран/ажуриран :count продукт(и)',
    'export_help' => 'Користи JSON ако планираш да ги внесеш информациите во Invoice Ninja. <br/> Датотеката содржи клиенти, продукти, фактури, понуди и плаќања.',
    'selfhost_export_help' => '<br/> Препорачуваме користење на mysqldump за креирање на целосен бекап.',
    'JSON_file' => 'JSON датотека',

    'view_dashboard' => 'Погледни контролна табла',
    'client_session_expired' => 'Сесијата истече',
    'client_session_expired_message' => 'Вашата сесија истече. Ве молиме кликнете на линкот во вашата е-пошта повторно.',

    'auto_bill_notification' => 'Оваа фактура ќе биде автоматски наплатена на вашиот :payment_method на датотеката на :due_date.',
    'auto_bill_payment_method_bank_transfer' => 'банкарска сметка',
    'auto_bill_payment_method_credit_card' => 'кредитна картичка',
    'auto_bill_payment_method_paypal' => 'PayPal сметка',
    'auto_bill_notification_placeholder' => 'Оваа фактура автоматски ќе биде наплатена од вашата кредитна картичка на датотеката на датумот на достасување.',
    'payment_settings' => 'Подесувања за плаќање',

    'on_send_date' => 'На датум на праќање',
    'on_due_date' => 'На датум на достасување ',
    'auto_bill_ach_date_help' => 'ACH секогаш ќе наплаќа автоматски на датумот на достасување.',
    'warn_change_auto_bill' => 'Поради NACHA правилата, промените направени на оваа фактура можат да го спречат ACH во автоматската наплата.',

    'bank_account' => 'Банкарска сметка',
    'payment_processed_through_wepay' => 'ACH плаќањата ќе бидат процесирани преку WePay.',
    'wepay_payment_tos_agree' => 'Се согласувам на WePay :terms и :privacy_policy.',
    'privacy_policy' => 'Полиса за приватност',
    'wepay_payment_tos_agree_required' => 'Морате да се согласите со WePay условите за услуга и полисата за приватност.',
    'ach_email_prompt' => 'Ве молиме внесете ја вашата адреса на е-пошта:',
    'verification_pending' => 'Верификацијата е во тек',

    'update_font_cache' => 'Ве молиме насилно освежете ја страната за да ја ажурирате кеш меморијата за фонт.',
    'more_options' => 'Повеќе опции',
    'credit_card' => 'Кредитна картичка',
    'bank_transfer' => 'Банкарски трансфер',
    'no_transaction_reference' => 'Не е добиена референца за трансакција од порталот за плаќање.',
    'use_bank_on_file' => 'Користи банка на датотека',
    'auto_bill_email_message' => 'Оваа фактура ќе биде автоматски наплатена според начинот на плаќање на датотеката на датумот на достасување.',
    'bitcoin' => 'Bitcoin',
    'gocardless' => 'GoCardless',
    'added_on' => 'Додадено :date',
    'failed_remove_payment_method' => 'Неуспешно отстранување на начинот на плаќање',
    'gateway_exists' => 'Овој платен портал веќе постои',
    'manual_entry' => 'Рачен влез',
    'start_of_week' => 'Прв ден од неделата',

    // Frequencies
    'freq_inactive' => 'Неактивно',
    'freq_daily' => 'Дневно',
    'freq_weekly' => 'Неделно',
    'freq_biweekly' => 'Двонеделно',
    'freq_two_weeks' => 'Две недели',
    'freq_four_weeks' => 'Четири недели',
    'freq_monthly' => 'Месечно',
    'freq_three_months' => 'Три месеци',
    'freq_four_months' => 'Четири месеци',
    'freq_six_months' => 'Шест месеци',
    'freq_annually' => 'Годишно',
    'freq_two_years' => 'Две години',

    // Payment types
    'payment_type_Apply Credit' => 'Поднеси кредит',
    'payment_type_Bank Transfer' => 'Банкарски трансфер',
    'payment_type_Cash' => 'Кеш',
    'payment_type_Debit' => 'Дебит',
    'payment_type_ACH' => 'ACH',
    'payment_type_Visa Card' => 'Visa Card',
    'payment_type_MasterCard' => 'MasterCard',
    'payment_type_American Express' => 'American Express',
    'payment_type_Discover Card' => 'Discover картичка',
    'payment_type_Diners Card' => 'Diners картичка',
    'payment_type_EuroCard' => 'EuroCard',
    'payment_type_Nova' => 'Nova',
    'payment_type_Credit Card Other' => 'Останати кредитни картички',
    'payment_type_PayPal' => 'PayPal',
    'payment_type_Google Wallet' => 'Google Wallet',
    'payment_type_Check' => 'Провери',
    'payment_type_Carte Blanche' => 'Бланко карта',
    'payment_type_UnionPay' => 'UnionPay',
    'payment_type_JCB' => 'JCB',
    'payment_type_Laser' => 'Laser',
    'payment_type_Maestro' => 'Maestro',
    'payment_type_Solo' => 'Solo',
    'payment_type_Switch' => 'Префри',
    'payment_type_iZettle' => 'iZettle',
    'payment_type_Swish' => 'Swish',
    'payment_type_Alipay' => 'Alipay',
    'payment_type_Sofort' => 'Sofort',
    'payment_type_SEPA' => 'SEPA Direct Debit',
    'payment_type_Bitcoin' => 'Bitcoin',
    'payment_type_GoCardless' => 'GoCardless',
    'payment_type_Zelle' => 'Zelle',

    // Industries
    'industry_Accounting & Legal' => 'Сметководство и право',
    'industry_Advertising' => 'Рекламирање',
    'industry_Aerospace' => 'Воздухопловство',
    'industry_Agriculture' => 'Агрокултура',
    'industry_Automotive' => 'Автомобилство',
    'industry_Banking & Finance' => 'Банкарство и финансии',
    'industry_Biotechnology' => 'Биотехнологија',
    'industry_Broadcasting' => 'Радиодифузија',
    'industry_Business Services' => 'Бизнис услуги ',
    'industry_Commodities & Chemicals' => 'Стоки и хемикалии',
    'industry_Communications' => 'Комуникации',
    'industry_Computers & Hightech' => 'Компјутери и висока технологија',
    'industry_Defense' => 'Одбрана',
    'industry_Energy' => 'Енергија',
    'industry_Entertainment' => 'Забава',
    'industry_Government' => 'Влада',
    'industry_Healthcare & Life Sciences' => 'Здравствени и животни науки',
    'industry_Insurance' => 'Осигурување',
    'industry_Manufacturing' => 'Производство',
    'industry_Marketing' => 'Маркетинг',
    'industry_Media' => 'Медиа',
    'industry_Nonprofit & Higher Ed' => 'Непрофитни организации и Високо образование',
    'industry_Pharmaceuticals' => 'Фармацевтски производи',
    'industry_Professional Services & Consulting' => 'Професионални услуги и советување',
    'industry_Real Estate' => 'Недвижен имот',
    'industry_Restaurant & Catering' => 'Ресторан и кетеринг',
    'industry_Retail & Wholesale' => 'Малопродажба и трговија на големо',
    'industry_Sports' => 'Спорт',
    'industry_Transportation' => 'Транспорт',
    'industry_Travel & Luxury' => 'Патување и луксуз',
    'industry_Other' => 'Друго',
    'industry_Photography' => 'Фотографија',

    // Countries
    'country_Afghanistan' => 'Авганистан',
    'country_Albania' => 'Албанија',
    'country_Antarctica' => 'Антартик',
    'country_Algeria' => 'Алжир',
    'country_American Samoa' => 'Американска Самоа',
    'country_Andorra' => 'Андора',
    'country_Angola' => 'Ангола',
    'country_Antigua and Barbuda' => 'Антигва и Барбуда',
    'country_Azerbaijan' => 'Азербејџан',
    'country_Argentina' => 'Аргентина',
    'country_Australia' => 'Австралија',
    'country_Austria' => 'Австрија',
    'country_Bahamas' => 'Бахами',
    'country_Bahrain' => 'Бахреин',
    'country_Bangladesh' => 'Бангладеш',
    'country_Armenia' => 'Ерменија',
    'country_Barbados' => 'Барбадос',
    'country_Belgium' => 'Белгија',
    'country_Bermuda' => 'Бермуда',
    'country_Bhutan' => 'Бутан',
    'country_Bolivia, Plurinational State of' => 'Плурационална Држава Боливија',
    'country_Bosnia and Herzegovina' => 'Босна и Херцеговина',
    'country_Botswana' => 'Боцвана',
    'country_Bouvet Island' => 'Буве Oстров',
    'country_Brazil' => 'Бразил',
    'country_Belize' => 'Белизе',
    'country_British Indian Ocean Territory' => 'Британска територија на Индискиот Океан',
    'country_Solomon Islands' => 'Соломонови Oстрови',
    'country_Virgin Islands, British' => 'Виргински Острови, Британија',
    'country_Brunei Darussalam' => 'Брунеј Дерусалам',
    'country_Bulgaria' => 'Бугарија',
    'country_Myanmar' => 'Мјанмар',
    'country_Burundi' => 'Бурунди',
    'country_Belarus' => 'Белорусија',
    'country_Cambodia' => 'Кембоџа',
    'country_Cameroon' => 'Камерун',
    'country_Canada' => 'Канада',
    'country_Cape Verde' => 'Зеленортски Острови',
    'country_Cayman Islands' => 'Кајмански Острови',
    'country_Central African Republic' => 'Централна Африканска Република',
    'country_Sri Lanka' => 'Шри Ланка',
    'country_Chad' => 'Чад',
    'country_Chile' => 'Чиле',
    'country_China' => 'Кина',
    'country_Taiwan, Province of China' => 'Тајван, Кинеска Провинција',
    'country_Christmas Island' => 'Божиќен Остров',
    'country_Cocos (Keeling) Islands' => 'Кокос (Килинг) Острови',
    'country_Colombia' => 'Колумбија',
    'country_Comoros' => 'Коморос',
    'country_Mayotte' => 'Мајоте',
    'country_Congo' => 'Конго',
    'country_Congo, the Democratic Republic of the' => 'Демократска Република Конго',
    'country_Cook Islands' => 'Кук Острови',
    'country_Costa Rica' => 'Костарика',
    'country_Croatia' => 'Хрватска',
    'country_Cuba' => 'Куба',
    'country_Cyprus' => 'Кипар',
    'country_Czech Republic' => 'Чешка Република',
    'country_Benin' => 'Бенин',
    'country_Denmark' => 'Данска',
    'country_Dominica' => 'Доминика',
    'country_Dominican Republic' => 'Доминиканска Република',
    'country_Ecuador' => 'Еквадор',
    'country_El Salvador' => 'Ел Салвадор',
    'country_Equatorial Guinea' => 'Екваторска Гвинеја',
    'country_Ethiopia' => 'Етиопија',
    'country_Eritrea' => 'Еритреја',
    'country_Estonia' => 'Естонија',
    'country_Faroe Islands' => 'Фарски Острови',
    'country_Falkland Islands (Malvinas)' => 'Фалкландски Острови (Малвини)',
    'country_South Georgia and the South Sandwich Islands' => 'Јужна Грузија и Јужно Сендвички острови',
    'country_Fiji' => 'Фиџи',
    'country_Finland' => 'Финска',
    'country_Åland Islands' => 'Оланд Острови',
    'country_France' => 'Франција',
    'country_French Guiana' => 'Француска Гвајана',
    'country_French Polynesia' => 'Француска Полинезија',
    'country_French Southern Territories' => 'Јужно Француски Територии',
    'country_Djibouti' => 'Џибути',
    'country_Gabon' => 'Габон',
    'country_Georgia' => 'Грузија',
    'country_Gambia' => 'Гамбија',
    'country_Palestinian Territory, Occupied' => 'Палестинска Територија, Окупирана',
    'country_Germany' => 'Германија',
    'country_Ghana' => 'Гана',
    'country_Gibraltar' => 'Гибралтар',
    'country_Kiribati' => 'Кирибати',
    'country_Greece' => 'Грција',
    'country_Greenland' => 'Гренланд',
    'country_Grenada' => 'Гренада',
    'country_Guadeloupe' => 'Гвадалупе',
    'country_Guam' => 'Гуам',
    'country_Guatemala' => 'Гватемала',
    'country_Guinea' => 'Гвинеа',
    'country_Guyana' => 'Гвајана',
    'country_Haiti' => 'Хаити',
    'country_Heard Island and McDonald Islands' => 'Херд Остров и Мекдоналд Острови',
    'country_Holy See (Vatican City State)' => 'Свето Море (Ватикан)',
    'country_Honduras' => 'Хондурас',
    'country_Hong Kong' => 'Хонг Конг',
    'country_Hungary' => 'Унгарија',
    'country_Iceland' => 'Исланд',
    'country_India' => 'Индија',
    'country_Indonesia' => 'Индонезија',
    'country_Iran, Islamic Republic of' => 'Исламска Република Иран',
    'country_Iraq' => 'Ирак',
    'country_Ireland' => 'Ирска',
    'country_Israel' => 'Израел',
    'country_Italy' => 'Италија',
    'country_Côte d\'Ivoire' => 'Брегот на Слоновата Коска',
    'country_Jamaica' => 'Јамајка',
    'country_Japan' => 'Јапонија',
    'country_Kazakhstan' => 'Казахстан',
    'country_Jordan' => 'Јордан',
    'country_Kenya' => 'Кенија',
    'country_Korea, Democratic People\'s Republic of' => 'Демокатска Народна Република Кореа',
    'country_Korea, Republic of' => 'Република Кореа',
    'country_Kuwait' => 'Кувајт',
    'country_Kyrgyzstan' => 'Киргистан',
    'country_Lao People\'s Democratic Republic' => 'Народна Деморатска Република Лао',
    'country_Lebanon' => 'Либан',
    'country_Lesotho' => 'Лесото',
    'country_Latvia' => 'Латвија',
    'country_Liberia' => 'Либерија',
    'country_Libya' => 'Либија',
    'country_Liechtenstein' => 'Лихтенштајн',
    'country_Lithuania' => 'Литванија',
    'country_Luxembourg' => 'Луксембург',
    'country_Macao' => 'Макао',
    'country_Madagascar' => 'Мадагаскар',
    'country_Malawi' => 'Малави',
    'country_Malaysia' => 'Малазија',
    'country_Maldives' => 'Малдиви',
    'country_Mali' => 'Мали',
    'country_Malta' => 'Малта',
    'country_Martinique' => 'Мартиник',
    'country_Mauritania' => 'Мавританија',
    'country_Mauritius' => 'Маурициус',
    'country_Mexico' => 'Мексико',
    'country_Monaco' => 'Монако',
    'country_Mongolia' => 'Монголија',
    'country_Moldova, Republic of' => 'Република Молдавија',
    'country_Montenegro' => 'Црна Гора',
    'country_Montserrat' => 'Монсерат',
    'country_Morocco' => 'Мароко',
    'country_Mozambique' => 'Мозамбик',
    'country_Oman' => 'Оман',
    'country_Namibia' => 'Намибија',
    'country_Nauru' => 'Науру',
    'country_Nepal' => 'Непал',
    'country_Netherlands' => 'Холандија',
    'country_Curaçao' => 'Курасао',
    'country_Aruba' => 'Аруба',
    'country_Sint Maarten (Dutch part)' => 'Синт Мартен (Холандски дел)',
    'country_Bonaire, Sint Eustatius and Saba' => 'Бонаер, Синт Еустатиус и Саба',
    'country_New Caledonia' => 'Нова Каледонија',
    'country_Vanuatu' => 'Вануату',
    'country_New Zealand' => 'Нов Зеланд',
    'country_Nicaragua' => 'Никарагва',
    'country_Niger' => 'Нигер',
    'country_Nigeria' => 'Нигерија',
    'country_Niue' => 'Ниуе',
    'country_Norfolk Island' => 'Островот Норфолк',
    'country_Norway' => 'Норвешка',
    'country_Northern Mariana Islands' => 'Северни Маријански Острови',
    'country_United States Minor Outlying Islands' => 'Мали далечни острови во САД',
    'country_Micronesia, Federated States of' => 'Федерална Држава Микронезија',
    'country_Marshall Islands' => 'Маршалски Острови',
    'country_Palau' => 'Палау',
    'country_Pakistan' => 'Пакистан',
    'country_Panama' => 'Панама',
    'country_Papua New Guinea' => 'Папуа Нова Гвинеја',
    'country_Paraguay' => 'Парагвај',
    'country_Peru' => 'Перу',
    'country_Philippines' => 'Филипини',
    'country_Pitcairn' => 'Питкерн',
    'country_Poland' => 'Полска',
    'country_Portugal' => 'Португалија',
    'country_Guinea-Bissau' => 'Гвинеја-Бисао',
    'country_Timor-Leste' => 'Тимор-Лесте',
    'country_Puerto Rico' => 'Порторико',
    'country_Qatar' => 'Катар',
    'country_Réunion' => 'Реунион',
    'country_Romania' => 'Романија',
    'country_Russian Federation' => 'Руска Федерација',
    'country_Rwanda' => 'Руанда',
    'country_Saint Barthélemy' => 'Свери Бартелеми',
    'country_Saint Helena, Ascension and Tristan da Cunha' => 'Света Елена, Асенсион и Тристан да Кунха',
    'country_Saint Kitts and Nevis' => 'Сент Китс и Невис',
    'country_Anguilla' => 'Ангвила',
    'country_Saint Lucia' => 'Сент Луција',
    'country_Saint Martin (French part)' => 'Сент Мартин (Француски дел)',
    'country_Saint Pierre and Miquelon' => 'Сент Пиер и Микелон',
    'country_Saint Vincent and the Grenadines' => 'Сент Винсент и Гренадините',
    'country_San Marino' => 'Сан Марино',
    'country_Sao Tome and Principe' => 'Сао Томе и Принсипе',
    'country_Saudi Arabia' => 'Саудиска Арабија',
    'country_Senegal' => 'Сенегал',
    'country_Serbia' => 'Србија',
    'country_Seychelles' => 'Сејшели',
    'country_Sierra Leone' => 'Сиера Леоне',
    'country_Singapore' => 'Сингапур',
    'country_Slovakia' => 'Словачка',
    'country_Viet Nam' => 'Виетнам',
    'country_Slovenia' => 'Словенија',
    'country_Somalia' => 'Сомалија',
    'country_South Africa' => 'Јужна Африка',
    'country_Zimbabwe' => 'Зимбабве',
    'country_Spain' => 'Шпанија',
    'country_South Sudan' => 'Јужен Судан',
    'country_Sudan' => 'Судан',
    'country_Western Sahara' => 'Западна Сахара',
    'country_Suriname' => 'Суринам',
    'country_Svalbard and Jan Mayen' => 'Свалбард и Јан Мајен',
    'country_Swaziland' => 'Свазиленд',
    'country_Sweden' => 'Шведска',
    'country_Switzerland' => 'Швајцарија',
    'country_Syrian Arab Republic' => 'Сириска Арапска Република',
    'country_Tajikistan' => 'Таџикистан',
    'country_Thailand' => 'Тајланд',
    'country_Togo' => 'Того',
    'country_Tokelau' => 'Токелау',
    'country_Tonga' => 'Тонга',
    'country_Trinidad and Tobago' => 'Тринидад и Тобаго',
    'country_United Arab Emirates' => 'Обединети Арапски Емирати',
    'country_Tunisia' => 'Тунис',
    'country_Turkey' => 'Турција',
    'country_Turkmenistan' => 'Туркменистан',
    'country_Turks and Caicos Islands' => 'Турк и Каикос Острови',
    'country_Tuvalu' => 'Тувалу',
    'country_Uganda' => 'Уганда',
    'country_Ukraine' => 'Украина',
    'country_Macedonia, the former Yugoslav Republic of' => 'Република Северна Македонија',
    'country_Egypt' => 'Египет',
    'country_United Kingdom' => 'Обединето Кралство',
    'country_Guernsey' => 'Гернзи',
    'country_Jersey' => 'Џерси',
    'country_Isle of Man' => 'Остров на Човекот',
    'country_Tanzania, United Republic of' => 'Обединета Република Танзанија',
    'country_United States' => 'Соединети Американски Држави',
    'country_Virgin Islands, U.S.' => 'Виргински Острови, САД',
    'country_Burkina Faso' => 'Буркина Фасо',
    'country_Uruguay' => 'Уругвај',
    'country_Uzbekistan' => 'Узбекистан',
    'country_Venezuela, Bolivarian Republic of' => 'Боливарска Република Венецуела',
    'country_Wallis and Futuna' => 'Валис и Футуна',
    'country_Samoa' => 'Самоа',
    'country_Yemen' => 'Јемен',
    'country_Zambia' => 'Замбиа',

    // Languages
    'lang_Brazilian Portuguese' => 'Бразилско Португалски',
    'lang_Croatian' => 'Хрватски',
    'lang_Czech' => 'Чешки',
    'lang_Danish' => 'Дански',
    'lang_Dutch' => 'Холандски',
    'lang_English' => 'Англиски',
    'lang_French' => 'Француски',
    'lang_French - Canada' => 'Француско-Канадски',
    'lang_German' => 'Германски',
    'lang_Italian' => 'Италијански',
    'lang_Japanese' => 'Јапонски',
    'lang_Lithuanian' => 'Литвански',
    'lang_Norwegian' => 'Норвешки',
    'lang_Polish' => 'Полски',
    'lang_Spanish' => 'Шпански',
    'lang_Spanish - Spain' => 'Шпански - Шпанија',
    'lang_Swedish' => 'Шведски',
    'lang_Albanian' => 'Албански',
    'lang_Greek' => 'Грчки',
    'lang_English - United Kingdom' => 'Англиски - Обединето Кралство',
    'lang_English - Australia' => 'English - Australia',
    'lang_Slovenian' => 'Словенски',
    'lang_Finnish' => 'Фински',
    'lang_Romanian' => 'Романски',
    'lang_Turkish - Turkey' => 'Турски - Турција',
    'lang_Portuguese - Brazilian' => 'Португалски - Бразилски',
    'lang_Portuguese - Portugal' => 'Португалски - Португалија',
    'lang_Thai' => 'Тајландски',
    'lang_Macedonian' => 'Македонски',
    'lang_Chinese - Taiwan' => 'Chinese - Taiwan',
    'lang_Serbian' => 'Српски',
    'lang_Bulgarian' => 'Бугарски',
    'lang_Russian' => 'Russian',

    // Industries
    'industry_Accounting & Legal' => 'Сметководство и право',
    'industry_Advertising' => 'Рекламирање',
    'industry_Aerospace' => 'Воздухопловство',
    'industry_Agriculture' => 'Агрокултура',
    'industry_Automotive' => 'Автомобилство',
    'industry_Banking & Finance' => 'Банкарство и финансии',
    'industry_Biotechnology' => 'Биотехнологија',
    'industry_Broadcasting' => 'Радиодифузија',
    'industry_Business Services' => 'Бизнис услуги ',
    'industry_Commodities & Chemicals' => 'Стоки и хемикалии',
    'industry_Communications' => 'Комуникации',
    'industry_Computers & Hightech' => 'Компјутери и висока технологија',
    'industry_Defense' => 'Одбрана',
    'industry_Energy' => 'Енергија',
    'industry_Entertainment' => 'Забава',
    'industry_Government' => 'Влада',
    'industry_Healthcare & Life Sciences' => 'Здравствени и животни науки',
    'industry_Insurance' => 'Осигурување',
    'industry_Manufacturing' => 'Производство',
    'industry_Marketing' => 'Маркетинг',
    'industry_Media' => 'Медиа',
    'industry_Nonprofit & Higher Ed' => 'Непрофитни организации и Високо образование',
    'industry_Pharmaceuticals' => 'Фармацевтски производи',
    'industry_Professional Services & Consulting' => 'Професионални услуги и советување',
    'industry_Real Estate' => 'Недвижен имот',
    'industry_Retail & Wholesale' => 'Малопродажба и трговија на големо',
    'industry_Sports' => 'Спорт',
    'industry_Transportation' => 'Транспорт',
    'industry_Travel & Luxury' => 'Патување и луксуз',
    'industry_Other' => 'Друго',
    'industry_Photography' => 'Фотографија',

    'view_client_portal' => 'Прегледај портал на клиент',
    'view_portal' => 'Прегледај портал',
    'vendor_contacts' => 'Контакти на продавач',
    'all' => 'Сите',
    'selected' => 'Избрано',
    'category' => 'Категорија',
    'categories' => 'Категории',
    'new_expense_category' => 'Категорија на нов трошок',
    'edit_category' => 'Измени категорија',
    'archive_expense_category' => 'Архивирај категорија',
    'expense_categories' => 'Категории на трошоци',
    'list_expense_categories' => 'Листа на категории на трошоци',
    'updated_expense_category' => 'Успешно ажурирана категорија на трошоци',
    'created_expense_category' => 'Успешно креирана категорија на трошоци',
    'archived_expense_category' => 'Успешно архивирана категорија на трошоци',
    'archived_expense_categories' => 'Успешно архивирани :count категории на трошоци',
    'restore_expense_category' => 'Поврати категорија на трошоци',
    'restored_expense_category' => 'Успешно повратена категорија на трошоци',
    'apply_taxes' => 'Поднеси даноци',
    'min_to_max_users' => ':min до :max корисници',
    'max_users_reached' => 'Достигнат е максималниот број на корисници',
    'buy_now_buttons' => 'Купи сега копчиња',
    'landing_page' => 'Целна страница',
    'payment_type' => 'Тип на плаќање',
    'form' => 'Форма',
    'link' => 'Линк',
    'fields' => 'Полиња',
    'dwolla' => 'Dwolla',
    'buy_now_buttons_warning' => 'Забелешка: клиентот и фактурата се креирани иако трансакцијата не е завршена',
    'buy_now_buttons_disabled' => 'Оваа функција бара продуктот да е креиран и порталот за плаќање конфигуриран.',
    'enable_buy_now_buttons_help' => 'Овозможи поддршка за купи сега копчиња',
    'changes_take_effect_immediately' => 'Забелешка: промените се ефективни веднаш',
    'wepay_account_description' => 'Платен портал за Invoice Ninja',
    'payment_error_code' => 'Имаше грешка при поцесирањето на плаќањето [:code]. Ве молиме обидете се повторно подоцна.',
    'standard_fees_apply' => 'Провизија 2.9%/1.2% [Credit Card/Bank Transfer] + $0.30 за успешна наплата.',
    'limit_import_rows' => 'Податоците мораат да бидат внесени во серии од :count редови или помалку',
    'error_title' => 'Нешто тргна наопаку',
    'error_contact_text' => 'Ако ви треба помош, ве молиме пратете е-пошта на :mailaddress',
    'no_undo' => 'Предупредување: ова не може да се врати назад.',
    'no_contact_selected' => 'Ве молиме изберете контакт',
    'no_client_selected' => 'Ве молиме изберете клиент',

    'gateway_config_error' => 'Би помогнало ако поставите нови лозинки или да генерирате нови API клучеви.',
    'payment_type_on_file' => ':type на датотека',
    'invoice_for_client' => 'Фактура :invoice за :client',
    'intent_not_found' => 'Извинете, не сум сигурен што ме прашувате.',
    'intent_not_supported' => 'Извинете, не можам да го направам тоа.',
    'client_not_found' => 'Не можев да го најдам клиентот.',
    'not_allowed' => 'Извинете, ги немате потребните дозволи',
    'bot_emailed_invoice' => 'Вашата фактура е испратена.',
    'bot_emailed_notify_viewed' => 'Ќе ви испратам е-пошта кога ќе биде видено.',
    'bot_emailed_notify_paid' => 'Ќе ви испратам е-пошта кога ќе биде платено.',
    'add_product_to_invoice' => 'Додај 1 :product',
    'not_authorized' => 'Не сте овластени',
    'bot_get_email' => 'Здраво! (wave) <br/> Ви благодарам што го пробавте Invoice Ninja ботот. <br/> Треба да креирате бесплатна сметка за да го користите овој бот. <br/> Испратете ми ја адресата на вашата е-пошта со која е поврзана сметката за да започнеме.',
    'bot_get_code' => 'Благодарам! Ви испратив е-пошта со вашиот сигурносен код.',
    'bot_welcome' => 'Тоа е тоа, вашата сметка е овластена. <br/>',
    'email_not_found' => 'Не можев да најдам слободна сметка за :email',
    'invalid_code' => 'Кодот не е точен',
    'security_code_email_subject' => 'Сигурносен код за Invoice Ninja ботот',
    'security_code_email_line1' => 'Ова е вашиот Invoice Ninja Bot сигурносен код.',
    'security_code_email_line2' => 'Забелешка: ќе истече за 10 минути.',
    'bot_help_message' => 'Моментално поддржувам: <br/> Креирај\ажурирај/испрати по е-пошта фактура <br/> • Листа на продукти <br/> На пример: <br/> <i> Испрати фактура на Боб за 2 карти, постави датум на достасување до следниот четврток и направи попуст од 10 проценти </i>',
    'list_products' => 'Листа на продукти',

    'include_item_taxes_inline' => 'Вклучи ги <b> даноците на ставките во линијата вкупно </b>',
    'created_quotes' => 'Успешно креирани :count понуди',
    'limited_gateways' => 'Забелешка: поддржуваме еден платен портал со кредитна картичка по компанија.',

    'warning' => 'Предупредување',
    'self-update' => 'Ажурирај',
    'update_invoiceninja_title' => 'Ажурирај Invoice Ninja',
    'update_invoiceninja_warning' => 'Пред за започнете со ажурирање на Invoice Ninja креирајте бекап на вашата датабаза и датотеки.',
    'update_invoiceninja_available' => 'Достапна е нова верзија на Invoice Ninja.',
    'update_invoiceninja_unavailable' => 'Нема достапна нова верзија на Invoice Ninja.',
    'update_invoiceninja_instructions' => 'Ве молиме инсталирајте ја новата верзија <strong> :version </strong> со кликнување на <em> Ажурирај сега </em> копчето подоле. Потоа ќе бидете пренасочени кон контролната табла.',
    'update_invoiceninja_update_start' => 'Ажурирај сега',
    'update_invoiceninja_download_start' => 'Превземена :version',
    'create_new' => 'Креирај сега',

    'toggle_navigation' => 'Toggle навигација',
    'toggle_history' => 'Toggle историја',
    'unassigned' => 'Неназначено',
    'task' => 'Задача',
    'contact_name' => 'Име на контакт',
    'city_state_postal' => 'Град/Држава/Поштенски број',
    'custom_field' => 'Прилагодено поле',
    'account_fields' => 'Поле за компанија',
    'facebook_and_twitter' => 'Facebook и Twitter',
    'facebook_and_twitter_help' => 'Следете ги нашите новости за да помогнете во поддршката на нашиот проект',
    'reseller_text' => 'Забелешка: лиценцата за брендирање е наменета за лична употреба, ве молиме пратете ни е-пошта на :email ако би сакале да ја препродадете апликацијата.',
    'unnamed_client' => 'Неименуван клиент',

    'day' => 'Ден',
    'week' => 'Недела',
    'month' => 'Месец',
    'inactive_logout' => 'Бевте одјавени поради неактивност',
    'reports' => 'Извештаи',
    'total_profit' => 'Вкупен профит',
    'total_expenses' => 'Вкупно трошоци',
    'quote_to' => 'Понуди на',

    // Limits
    'limit' => 'Ограничување',
    'min_limit' => 'Мин: :min',
    'max_limit' => 'Макс: :max',
    'no_limit' => 'Нема ограничувања',
    'set_limits' => 'Постави :gateway_type граници',
    'enable_min' => 'Овозможи мин.',
    'enable_max' => 'Овозможи макс.',
    'min' => 'Мин',
    'max' => 'Макс',
    'limits_not_met' => 'Фактурата не ги достигнува ограничувањата за тој тип на плаќање.',

    'date_range' => 'Опсег на датуми',
    'raw' => 'Необработено',
    'raw_html' => 'Необработен HTML',
    'update' => 'Ажурирај',
    'invoice_fields_help' => 'Повлечи ги и спушти ги полињата за менување на нивниот распоред и локација',
    'new_category' => 'Нова категорија',
    'restore_product' => 'Поврати продукт',
    'blank' => 'Бланко',
    'invoice_save_error' => 'Имаше грешка при зачувување на вашата фактура',
    'enable_recurring' => 'Овозможи повторување',
    'disable_recurring' => 'Оневозможи повторување',
    'text' => 'Текст',
    'expense_will_create' => 'ќе биде креиран трошок',
    'expenses_will_create' => 'ќе бидат креирани трошоци',
    'created_expenses' => 'Успешно креирани :count трошоци ',

    'translate_app' => 'Помогнете ни да ги подобриме нашите преводи со :link',
    'expense_category' => 'Категорија на трошок',

    'go_ninja_pro' => 'Приклучи се на Ninja Про!',
    'go_enterprise' => 'Приклучи се на пакетот за претпријатија!',
    'upgrade_for_features' => 'Надгради за повеќе функции',
    'pay_annually_discount' => 'Плати годишно за 10 месеци + 2 бесплатно',
    'pro_upgrade_title' => 'Ninja Про',
    'pro_upgrade_feature1' => 'YourBrand.InvoiceNinja.com ',
    'pro_upgrade_feature2' => 'Прилагоди го секој аспект од твојата фактура!',
    'enterprise_upgrade_feature1' => 'Постави дозвола за повеќе корисници.',
    'enterprise_upgrade_feature2' => 'Прикачи датотеки од 3то лице на фактури и трошоци',
    'much_more' => 'Многу повеќе!',
    'all_pro_fetaures' => 'Плус сите Про функции!',

    'currency_symbol' => 'Симбол',
    'currency_code' => 'Код',

    'buy_license' => 'Купи лиценца',
    'apply_license' => 'Примени лиценца',
    'submit' => 'Поднеси',
    'white_label_license_key' => 'Клуч на лиценца',
    'invalid_white_label_license' => 'Лиценцата за брендирање е невалидна',
    'created_by' => 'Креирано по :name',
    'modules' => 'Модули',
    'financial_year_start' => 'Прв месец од годината',
    'authentication' => 'Автентикација',
    'checkbox' => 'Поле за избор',
    'invoice_signature' => 'Потпис',
    'show_accept_invoice_terms' => 'Поле за избор на услови за фактура',
    'show_accept_invoice_terms_help' => 'Побарај од клиентот да потврди дека ги прифаќа условите на фактурата.',
    'show_accept_quote_terms' => 'Поле за избор на услови за понуда',
    'show_accept_quote_terms_help' => 'Побарај од клиентот да потврди дека ги прифаќа условите на понудата.',
    'require_invoice_signature' => 'Потпис на фактура',
    'require_invoice_signature_help' => 'Побарај од клиентот да обезбеди потпис.',
    'require_quote_signature' => 'Потпис на понуда',
    'require_quote_signature_help' => 'Побарај од клиентот да обезбеди потпис.',
    'i_agree' => 'Се согласувам со условите',
    'sign_here' => 'Ве молиме потпишете тука: ',
    'authorization' => 'Овластување',
    'signed' => 'Потпишано',

    // BlueVine
    'bluevine_promo' => 'Добијте флексибилни бизнис линии на кредит и факторинг на фактури преку BlueVine.',
    'bluevine_modal_label' => 'Регистрирај се со BlueVine',
    'bluevine_modal_text' => '<h3> Брзо финансирање на вашиот бизнис. Без документи. </h3> 
 <ul> <li> Флексибилни бизнис линии на кредит и факторинг на фактури </li> </ul> ',
    'bluevine_create_account' => 'Креирај сметка',
    'quote_types' => 'Добиј понуда за',
    'invoice_factoring' => 'Факторинг на фактура',
    'line_of_credit' => 'Линија на кредит',
    'fico_score' => 'Вашиот FICO резултат',
    'business_inception' => 'Датум на започнување бизнис',
    'average_bank_balance' => 'Просечна состојба на банкарска сметка',
    'annual_revenue' => 'Годишен приход',
    'desired_credit_limit_factoring' => 'Посакувано ограничување на факторинг на фактура ',
    'desired_credit_limit_loc' => 'Посакувано ограничување на линија на кредит',
    'desired_credit_limit' => 'Посакувано ограничување на кредит',
    'bluevine_credit_line_type_required' => 'Мора да изберете баред едно',
    'bluevine_field_required' => 'Ова поле е задолжително',
    'bluevine_unexpected_error' => 'Се случи неочекувана грешка.',
    'bluevine_no_conditional_offer' => 'Потребни се повеќе информации пред да добиете понуда. Кликнете продолжи подоле.',
    'bluevine_invoice_factoring' => 'Факторинг на фактура',
    'bluevine_conditional_offer' => 'Доверлива понуда',
    'bluevine_credit_line_amount' => 'Кредитна линија',
    'bluevine_advance_rate' => 'Стапка на аванс',
    'bluevine_weekly_discount_rate' => 'Неделна стапка на попуст',
    'bluevine_minimum_fee_rate' => 'Минимална провизија',
    'bluevine_line_of_credit' => 'Линија на кредит',
    'bluevine_interest_rate' => 'Каматна стапка',
    'bluevine_weekly_draw_rate' => 'Неделна стапка на повлекување',
    'bluevine_continue' => 'Продолжи на BlueVine',
    'bluevine_completed' => 'Регистрирањето на BlueVine е завршено',

    'vendor_name' => 'Продавач',
    'entity_state' => 'Состојба',
    'client_created_at' => 'Дата на креирање',
    'postmark_error' => 'Имаше проблем со праќање на е-пошта преку Postmark :link',
    'project' => 'Проект',
    'projects' => 'Проекти',
    'new_project' => 'Нов проект',
    'edit_project' => 'Измени проект',
    'archive_project' => 'Архивирај проект',
    'list_projects' => 'Листа на проекти',
    'updated_project' => 'Успешно ажурирање на проект',
    'created_project' => 'Успешно креирање на проект',
    'archived_project' => 'Успешно архивирање на проект ',
    'archived_projects' => 'Успешно архивирани :count проекти',
    'restore_project' => 'Поврати проект',
    'restored_project' => 'Успешно повратување на проект',
    'delete_project' => 'Избриши проект',
    'deleted_project' => 'Успешно бришење на проект',
    'deleted_projects' => 'Успешно избришани :count проекти',
    'delete_expense_category' => 'Избриши категорија',
    'deleted_expense_category' => 'Успешно бришење на категорија',
    'delete_product' => 'Избриши продукт',
    'deleted_product' => 'Успешно бришење на продукт',
    'deleted_products' => 'Успешно бришење на :count продукти',
    'restored_product' => 'Успешно повратување на продукт',
    'update_credit' => 'Ажурирај кредит',
    'updated_credit' => 'Успешно ажурирање на кредит',
    'edit_credit' => 'Измени кредит',
    'realtime_preview' => 'Преглед во реално време',
    'realtime_preview_help' => 'Realtime refresh PDF preview on the invoice page when editing invoice.<br/>Disable this to improve performance when editing invoices.',
    'live_preview_help' => 'Display a live PDF preview on the invoice page.',
    'force_pdfjs_help' => 'Смени го вградениот PTF читач во :chrome_link и :firefox_link. Овозможи го ова ако вашиот пребарувач автоматски ја презема PDF датотеката.',
    'force_pdfjs' => 'Спречи преземање',
    'redirect_url' => 'Пренасочи URL',
    'redirect_url_help' => 'Опционално одреди URL да пренасочува по внесување на плаќањето.',
    'save_draft' => 'Зачувај нацрт',
    'refunded_credit_payment' => 'Рефундирај кредитно плаќање',
    'keyboard_shortcuts' => 'Кратенки на тастатура',
    'toggle_menu' => 'Toggle мени',
    'new_...' => 'Ново ...',
    'list_...' => 'Листирај ...',
    'created_at' => 'Датум на креирање',
    'contact_us' => 'Контактирајте не\'',
    'user_guide' => 'Упатство за корисникот',
    'promo_message' => 'Надгради пред :expires и добиј :amount попуст на првата година од користење на нашиот Про пакет и пакетот за претпријатие.',
    'discount_message' => ':amount попуст истекува :expires',
    'mark_paid' => 'Обележи платено',
    'marked_sent_invoice' => 'Успешно обележување на пратена фактура',
    'marked_sent_invoices' => 'Успешно обележување на пратени фактури',
    'invoice_name' => 'Фактура',
    'product_will_create' => 'продуктот ќе биде креиран',
    'contact_us_response' => 'Ви благодариме за вашата порака! Ќе се обидеме да ви одговориме што е можно поскоро.',
    'last_7_days' => 'Последни 7 дена',
    'last_30_days' => 'Последни 30 дена',
    'this_month' => 'Овој месец',
    'last_month' => 'Претходен месец',
    'current_quarter' => 'Тековен квартал',
    'last_quarter' => 'Последен квартал',
    'last_year' => 'Претходната година',
    'custom_range' => 'Прилагоден опсег',
    'url' => 'URL',
    'debug' => 'Дебагирај',
    'https' => 'HTTPS',
    'require' => 'Барање',
    'license_expiring' => 'Забелешка: Вашата лиценца ќе истече за :count дена, :link за да ја обновите.',
    'security_confirmation' => 'Вашата адреса на е-пошта е потврдена.',
    'white_label_expired' => 'Вашата лиценца за брендирање истече, ве молиме земете го во предвид нејзиното обновувае за да го поддржите нашиот проект.',
    'renew_license' => 'Обнови лиценца',
    'iphone_app_message' => 'Размислете за преземање на нашето :link',
    'iphone_app' => 'iPhone апликација',
    'android_app' => 'Android апликација',
    'logged_in' => 'Најавено',
    'switch_to_primary' => 'Сменете се на вашата примарна компанија (:name) за да управувате со вашиот план.',
    'inclusive' => 'Инклузивно',
    'exclusive' => 'Ексклузивно',
    'postal_city_state' => 'Поштенски број/Град/Држава',
    'phantomjs_help' => 'Во определени случаеви апликацијата користи :link_phantom за да ја генерира PDF датотеката, инсталирајте :link_docs за да генерирате локално.',
    'phantomjs_local' => 'Користи локално PhantomJS',
    'client_number' => 'Број на клиент',
    'client_number_help' => 'Одреди префикс или користи прилагодена шема за динамично поставувањец на бројот на клиентот.',
    'next_client_number' => 'Следниот број на клиент е :number.',
    'generated_numbers' => 'Генерирани броеви',
    'notes_reminder1' => 'Прв потсетник',
    'notes_reminder2' => 'Втор потсетник',
    'notes_reminder3' => 'Трет потсетник',
    'notes_reminder4' => 'Потсетник',
    'bcc_email' => 'BCC е-пошта',
    'tax_quote' => 'Даночна понуда',
    'tax_invoice' => 'Даночна фактура',
    'emailed_invoices' => 'Успешно пратени по е-пошта фактури',
    'emailed_quotes' => 'Успешно пратени по е-пошта понуди',
    'website_url' => 'URL на вебсајт',
    'domain' => 'Домен',
    'domain_help' => 'Користено во порталот на клиентот и при праќање на е-пошта.',
    'domain_help_website' => 'Користено при праќање на е-пошта.',
    'import_invoices' => 'Внеси фактури',
    'new_report' => 'Нов извештај',
    'edit_report' => 'Измени извештај',
    'columns' => 'Колони',
    'filters' => 'Филтери',
    'sort_by' => 'Сортирај по',
    'draft' => 'Нацрт',
    'unpaid' => 'Неплатено',
    'aging' => 'Застарено',
    'age' => 'Возраст',
    'days' => 'Денови',
    'age_group_0' => '0 - 30 дена',
    'age_group_30' => '30 - 60 дена',
    'age_group_60' => '60 - 90 дена',
    'age_group_90' => '90 - 120 дена',
    'age_group_120' => '120+ дена',
    'invoice_details' => 'Детали за фактура',
    'qty' => 'Количина',
    'profit_and_loss' => 'Профит и загуба',
    'revenue' => 'Приходи',
    'profit' => 'Профит',
    'group_when_sorted' => 'Групно сортирање',
    'group_dates_by' => 'Датуми на група по',
    'year' => 'Година',
    'view_statement' => 'Преглед на исказ',
    'statement' => 'Исказ',
    'statement_date' => 'Датум на исказ',
    'mark_active' => 'Обележи активно',
    'send_automatically' => 'Прати автоматски',
    'initial_email' => 'Почетна е-пошта',
    'invoice_not_emailed' => 'Оваа фактура не беше испратена по е-пошта',
    'quote_not_emailed' => 'Оваа понуда не беше испратена по е-пошта',
    'sent_by' => 'Испратено до :user',
    'recipients' => 'Приматели',
    'save_as_default' => 'Зачувај како стандард',
    'start_of_week_help' => 'Користено по <b> датуми </b> селектори',
    'financial_year_start_help' => 'Користено по <b> опсег на датуми </b> селектори',
    'reports_help' => 'Shift + клик за распределување по повеќе колони, Ctrl + клик за чистење на групирањето.',
    'this_year' => 'Оваа година',

    // Updated login screen
    'ninja_tagline' => 'Креирај. Прати. Биди платен.',
    'login_or_existing' => 'Или најави се со поврзана сметка.',
    'sign_up_now' => 'Регистрирај се сега',
    'not_a_member_yet' => 'Се уште не си член?',
    'login_create_an_account' => 'Креирај сметка!',

    // New Client Portal styling
    'invoice_from' => 'Фактури од:',
    'email_alias_message' => 'Бараме од секоја компанијада има уникатна адреса на е-пошта. <br/> Земете го во предвид користењето на псевдоним. На пр. email+label@example.com',
    'full_name' => 'Целосно име',
    'month_year' => 'МЕСЕЦ/ГОДИНА',
    'valid_thru' => 'Важи до',

    'product_fields' => 'Полиња на продукт',
    'custom_product_fields_help' => 'Додади поле при креирање на продукт или фактура и прикажи ја ознаката и вредноста на PDF.',
    'freq_two_months' => 'Два месеци',
    'freq_yearly' => 'Годишно',
    'profile' => 'Профил',
    'payment_type_help' => 'Постави стандарден <b> тип на рачно плаќање </b>',
    'industry_Construction' => 'Конструкција',
    'your_statement' => 'Вашиот исказ',
    'statement_issued_to' => 'Исказ назначен кон',
    'statement_to' => 'Исказ до',
    'customize_options' => 'Прилагоди опции',
    'created_payment_term' => 'Успешно креирање на услов за плаќање',
    'updated_payment_term' => 'Успешно ажурирање на услов на плаќање',
    'archived_payment_term' => 'Успешно архивирање на услов за плаќање',
    'resend_invite' => 'Повторно испраќање на покана',
    'credit_created_by' => 'Кредит креиран со плаќање :transaction_reference',
    'created_payment_and_credit' => 'Успешно креирано плаќање и кредит',
    'created_payment_and_credit_emailed_client' => 'Успешно креирано плаќање и кредит, и праќање по е-пошта на клиент',
    'create_project' => 'Креирај проект',
    'create_vendor' => 'Креирај продавач',
    'create_expense_category' => 'Креирај категорија',
    'pro_plan_reports' => ':link за овозможување на извештаи преку приклучување на Про планот',
    'mark_ready' => 'Одбележи подготвено',

    'limits' => 'Ограничувања',
    'fees' => 'Надоместоци',
    'fee' => 'Надоместок',
    'set_limits_fees' => 'Постави :gateway_type Ограничувања/Такси',
    'fees_tax_help' => 'Овозможи даноци во ставката за да поставите стапки на данок на надоместок.',
    'fees_sample' => 'Надоместокот за :amount фактура би бил :total.',
    'discount_sample' => 'Попустот за :amount фактура би бил :total.',
    'no_fees' => 'Без надоместоци',
    'gateway_fees_disclaimer' => 'Предупредување: не сите држави/портали за плаќање дозволуваат додавање на такси, ве молиме прегледајте ги локалните закони/услови на услугата.',
    'percent' => 'Процент',
    'location' => 'Локација',
    'line_item' => 'Ставка на линија',
    'surcharge' => 'Доплата',
    'location_first_surcharge' => 'Овозможено - прва доплата',
    'location_second_surcharge' => 'Овозможено - втора доплата',
    'location_line_item' => 'Овозможено - ставка на линија',
    'online_payment_surcharge' => 'Даплата за онлајн плаќање',
    'gateway_fees' => 'Такси на платниот портал',
    'fees_disabled' => 'Надоместоците се оневозможени',
    'gateway_fees_help' => 'Автоматски додај доплата/попуст на онлајн плаќање.',
    'gateway' => 'Платен портал',
    'gateway_fee_change_warning' => 'Ако има неплатени фактури со надоместоци тие треба да бидат ажурирани рачно.',
    'fees_surcharge_help' => 'Прилагоди доплата :link.',
    'label_and_taxes' => 'Дозвола и даноци',
    'billable' => 'Наплатливо',
    'logo_warning_too_large' => 'Датотеката со слика е преголема.',
    'logo_warning_fileinfo' => 'Предупредување: За поддршка на GIF треба да се одобри екстензија на fileInfo PHP.',
    'logo_warning_invalid' => 'Имаше проблем во читањето на датотеката со слика, ве молиме обидете се со друг формат.',

    'error_refresh_page' => 'Имаше грешка, ве молиме освежете ја страната и обидете се повторно.',
    'data' => 'Податоци',
    'imported_settings' => 'Успешно внесени поставки',
    'reset_counter' => 'Ресетирај бројач',
    'next_reset' => 'Следно ресетирање',
    'reset_counter_help' => 'Автоматски ресетирај ги бројачите на фактури и понуди.',
    'auto_bill_failed' => 'Автоматската наплата на фактура :invoice_number е неуспешно',
    'online_payment_discount' => 'Попуст за онлајн плаќање',
    'created_new_company' => 'Успешно креирана нова компанија',
    'fees_disabled_for_gateway' => 'Таксите се оневозможени за овој платен портал.',
    'logout_and_delete' => 'Одјава/Избриши сметка',
    'tax_rate_type_help' => 'Инклузивните стапки на данок ја приспособуваат цената на предметот кога се избрани. <br/> Само ексклузивните стапки на данок можат да се користат како стандардни.',
    'invoice_footer_help' => 'Користи $pageNumber и $pageCount за прикажување на информациите на страната. ',
    'credit_note' => 'Забелешка за кредит',
    'credit_issued_to' => 'Кредит издаден на',
    'credit_to' => 'Кредит на',
    'your_credit' => 'Вашиот кредит',
    'credit_number' => 'Број на кредит',
    'create_credit_note' => 'Креирај забелешка на кредит',
    'menu' => 'Мени',
    'error_incorrect_gateway_ids' => 'Грешка: Табелата на платниот портал има погрешни идентификации.',
    'purge_data' => 'Прочисти податоци',
    'delete_data' => 'Избриши податоци',
    'purge_data_help' => 'Трајно избриши ги сите податоци но зачувај ја сметката и поставките.',
    'cancel_account_help' => 'Трајно избриши ја сметката заедно со сите податоци и поставки.',
    'purge_successful' => 'Успешно прочистени податоци за компаанија',
    'forbidden' => 'Забрането',
    'purge_data_message' => 'Предупредување: Ова трајно ќе ги избрише вашите податоци, нема враќање назад.',
    'contact_phone' => 'Телефон за контакт',
    'contact_email' => 'Е-пошта за контакт',
    'reply_to_email' => 'Одговори-на е-пошта',
    'reply_to_email_help' => 'Одреди адреса на одговор за е-пошта на клиенти.',
    'bcc_email_help' => 'Приватно вклучи ја оваа адреса со е-пошта на клиент.',
    'import_complete' => 'Вашето внесување беше успешно завршено.',
    'confirm_account_to_import' => 'Ве молиме потврдете ја вашата сметка за да внесете информации.',
    'import_started' => 'Вашето внесување започна, ќе ви испратиме е-пошта штом заврши.',
    'listening' => 'Слушање...',
    'microphone_help' => 'Кажи "нова фактура за [client]" или "покажи ми ги архивираните плаќања на [client]"',
    'voice_commands' => 'Гласовни наредби',
    'sample_commands' => 'Пример наредби',
    'voice_commands_feedback' => 'Активно работиме на тоа да ја подобриме оваа функција, ако има наредба која би сакале да ја поддржиме ве молиме пратете ни е-пошта на :email.',
    'payment_type_Venmo' => 'Venmo',
    'payment_type_Money Order' => 'Нарачка на пари',
    'archived_products' => 'Успешно архивирање на :count продукти',
    'recommend_on' => 'Препорачуваме <b> овозможување </b> на ова подесување.',
    'recommend_off' => 'Препорачуваме <b> оневозможување </b> на ова подесување.',
    'notes_auto_billed' => 'Автоматски наплатено',
    'surcharge_label' => 'Назнака за доплата',
    'contact_fields' => 'Полиња за контакт',
    'custom_contact_fields_help' => 'Додади поле при креирање на контакт и опционално прикажување на назнаката и вредност на PDF датотеката.',
    'datatable_info' => 'Покажување :start до :end на :total записи',
    'credit_total' => 'Вкупно кредит',
    'mark_billable' => 'Означи наплатливо',
    'billed' => 'Наплатено',
    'company_variables' => 'Променливи на компанијата',
    'client_variables' => 'Променливи на клиентот',
    'invoice_variables' => 'Променливи на фактурата',
    'navigation_variables' => 'Променливи на навигацијата',
    'custom_variables' => 'Прилагодливи променливи',
    'invalid_file' => 'Невалиден тип на датотека',
    'add_documents_to_invoice' => 'Додај документи на фактура',
    'mark_expense_paid' => 'Означи платено',
    'white_label_license_error' => 'Неуспешна валидација на лиценца, проверете storage/logs/laravel-error.log за повеќе детали. ',
    'plan_price' => 'Планирај цена',
    'wrong_confirmation' => 'Неточен код за потврда',
    'oauth_taken' => 'Оваа сметка е веќе регистрирана',
    'emailed_payment' => 'Успешно пратено плаќање по е-пошта',
    'email_payment' => 'Прати плаќање по е-пошта',
    'invoiceplane_import' => 'Искористи :link за преместување на твоите податоци од InvoicePlane.',
    'duplicate_expense_warning' => 'Предупредување: Овој :link може да е дупликат.',
    'expense_link' => 'трошок',
    'resume_task' => 'Поврати задача',
    'resumed_task' => 'Успешно повратување на задача',
    'quote_design' => 'Дизајн на понуда',
    'default_design' => 'Стандарден дизајн',
    'custom_design1' => 'Прилагоден дизајн 1',
    'custom_design2' => 'Прилагоден дизајн 2',
    'custom_design3' => 'Прилагоден дизајн 3',
    'empty' => 'Празно',
    'load_design' => 'Вчитај дизајн',
    'accepted_card_logos' => 'Прифатени логоа на картичка',
    'phantomjs_local_and_cloud' => 'Користењето на локален PhantomJS ве враќа на phantomjscloud.com',
    'google_analytics' => 'Google Analytics',
    'analytics_key' => 'Analytics Key',
    'analytics_key_help' => 'Следи ги плаќањата користејќи :link',
    'start_date_required' => 'Датумот на почеток е задолжителен',
    'application_settings' => 'Поставки на апликација',
    'database_connection' => 'Конекција на датабаза',
    'driver' => 'Драјвер',
    'host' => 'Хост',
    'database' => 'Датабаза',
    'test_connection' => 'Тестирај конекција',
    'from_name' => 'Од име',
    'from_address' => 'Од адреса',
    'port' => 'Порта',
    'encryption' => 'Енкрипција',
    'mailgun_domain' => 'Mailgun домен',
    'mailgun_private_key' => 'Mailgun приватен клуч',
    'send_test_email' => 'Прати тест е-пошта',
    'select_label' => 'Избери назнака',
    'label' => 'Назнака',
    'service' => 'Услуга',
    'update_payment_details' => 'Ажурирај детали на плаќање',
    'updated_payment_details' => 'Успешно ажурирани детали на плаќање',
    'update_credit_card' => 'Ажурирај кредитна картичка',
    'recurring_expenses' => 'Повторувачки трошоци',
    'recurring_expense' => 'Повторувачки трошок',
    'new_recurring_expense' => 'Нов повторувачки трошок',
    'edit_recurring_expense' => 'Измени повторувачки трошок',
    'archive_recurring_expense' => 'Архивирај повторувачки трошок',
    'list_recurring_expense' => 'Листа на повторувачки трошоци',
    'updated_recurring_expense' => 'Успешно ажурирање на повторувачки трошок',
    'created_recurring_expense' => 'Успешно креирање на повторувачки трошок',
    'archived_recurring_expense' => 'Успешно архивирање на повторувачки трошок',
    'restore_recurring_expense' => 'Поврати повторувачки трошок',
    'restored_recurring_expense' => 'Успешно повраќање на повторувачки трошок ',
    'delete_recurring_expense' => 'Избриши повторувачки трошок',
    'deleted_recurring_expense' => 'Успешно бришење на проект',
    'view_recurring_expense' => 'Прегледај повторувачки трошок',
    'taxes_and_fees' => 'Даноци и надоместоци',
    'import_failed' => 'Внесувањето е неуспешно',
    'recurring_prefix' => 'Повторувачки префикс',
    'options' => 'Опции',
    'credit_number_help' => 'Одреди префикс или користи прилагодена шема за денамично одредување на бројот на кредит за негативни фактури.',
    'next_credit_number' => 'Следниот број на кредит е :number',
    'padding_help' => 'Бројот на нули кои се вметнати во бројот.',
    'import_warning_invalid_date' => 'Предупредување: Форматот на датумот е невалиден.',
    'product_notes' => 'Забелешки за продуктот',
    'app_version' => 'Верзија на апликација',
    'ofx_version' => 'Верзија на OFX',
    'gateway_help_23' => ':link за да ги добиете вашите Stripe API клучеви.',
    'error_app_key_set_to_default' => 'Грешка: APP_KEY е поставен на стандардна вредност, за да го ажурирате направете бекап на вашата датабаза и потоа вклучете <code> php artisan ninja:update-key </code> ',
    'charge_late_fee' => 'Наплати провизија за задоцнување',
    'late_fee_amount' => 'Износ на провизија за задоцнување',
    'late_fee_percent' => 'Процент на провизија за задоцнување',
    'late_fee_added' => 'Провизија за задоцнување додадена на :date',
    'download_invoice' => 'Преземи фактура',
    'download_quote' => 'Преземи понуда',
    'invoices_are_attached' => 'Вашите фактури во PDF се прикачени',
    'downloaded_invoice' => 'Ќе биде испратена е-пошта со PDF фактура',
    'downloaded_quote' => 'Ќе биде испратена е-пошта со PDF понуда',
    'downloaded_invoices' => 'Ќе биде испратена е-пошта со PDF фактури',
    'downloaded_quotes' => 'Ќе биде испратена е-пошта со PDF понуди',
    'clone_expense' => 'Клонирај трошок',
    'default_documents' => 'Стандардни документи',
    'send_email_to_client' => 'Испрати е-пошта на клиент',
    'refund_subject' => 'Рефундирањето е процесирано',
    'refund_body' => 'Процесирано ви е рефундирање од :amount за фактура :invoice_number.',

    'currency_us_dollar' => 'Американски Долар',
    'currency_british_pound' => 'Британска Фунта',
    'currency_euro' => 'Евро',
    'currency_south_african_rand' => 'Јужноафрикански Ранд',
    'currency_danish_krone' => 'Данскa Круна',
    'currency_israeli_shekel' => 'Израелски Шекел',
    'currency_swedish_krona' => 'Шведска Круна',
    'currency_kenyan_shilling' => 'Кенијски Шилинг',
    'currency_canadian_dollar' => 'Канадски Долар',
    'currency_philippine_peso' => 'Филипински Пезос',
    'currency_indian_rupee' => 'Индијски Рупи',
    'currency_australian_dollar' => 'Австралиски Долар',
    'currency_singapore_dollar' => 'Сингапурски Долар',
    'currency_norske_kroner' => 'Норвешка Круна',
    'currency_new_zealand_dollar' => 'Новозеландски Долар',
    'currency_vietnamese_dong' => 'Виетнамски Донг',
    'currency_swiss_franc' => 'Швајцарски Франк',
    'currency_guatemalan_quetzal' => 'Гватемалски Кецал',
    'currency_malaysian_ringgit' => 'Малезиски Рингит',
    'currency_brazilian_real' => 'Бразилски Реал',
    'currency_thai_baht' => 'Тајландски Бах',
    'currency_nigerian_naira' => 'Нигериска Наира',
    'currency_argentine_peso' => 'Аргентински Пезос',
    'currency_bangladeshi_taka' => 'Бангладешка Така',
    'currency_united_arab_emirates_dirham' => 'Арапски Дирхам',
    'currency_hong_kong_dollar' => 'Хонг Конг Долар',
    'currency_indonesian_rupiah' => 'Индонезиски Рупии',
    'currency_mexican_peso' => 'Мексикански Пезос',
    'currency_egyptian_pound' => 'Египетска Фунта',
    'currency_colombian_peso' => 'Колумбиски Пезос',
    'currency_west_african_franc' => 'Западноафрикански Франк',
    'currency_chinese_renminbi' => 'Кинески Ренминби',
    'currency_rwandan_franc' => 'Руандски Франк',
    'currency_tanzanian_shilling' => 'Танзаниски Шилинг',
    'currency_netherlands_antillean_guilder' => 'Холандски Антилеански Гилдер',
    'currency_trinidad_and_tobago_dollar' => 'Тринидад и Тобаго Долар',
    'currency_east_caribbean_dollar' => 'Источно Карибски Долар',
    'currency_ghanaian_cedi' => 'Гански Цеди',
    'currency_bulgarian_lev' => 'Бугарски Лев',
    'currency_aruban_florin' => 'Арубиски Флорин',
    'currency_turkish_lira' => 'Турска Лира',
    'currency_romanian_new_leu' => 'Романски Нов Леу',
    'currency_croatian_kuna' => 'Хрватска Куна',
    'currency_saudi_riyal' => 'Саудиски Ријал',
    'currency_japanese_yen' => 'Јапонски Јен',
    'currency_maldivian_rufiyaa' => 'Малдивиска Рифлија',
    'currency_costa_rican_colon' => 'Костарикански Колон',
    'currency_pakistani_rupee' => 'Пакистански Рупии',
    'currency_polish_zloty' => 'Полска Злота',
    'currency_sri_lankan_rupee' => 'Шри Ланкански Рупии',
    'currency_czech_koruna' => 'Чешка Корона',
    'currency_uruguayan_peso' => 'Уругвајски Пезос ',
    'currency_namibian_dollar' => 'Намибиски Долар',
    'currency_tunisian_dinar' => 'Туниски Динар',
    'currency_russian_ruble' => 'Руска Рубла',
    'currency_mozambican_metical' => 'Мозамбиски Метикал',
    'currency_omani_rial' => 'Омански Риал',
    'currency_ukrainian_hryvnia' => 'Украинска Хривнија',
    'currency_macanese_pataca' => 'Маканска Патака',
    'currency_taiwan_new_dollar' => 'Тајвански Нов Долар',
    'currency_dominican_peso' => 'Доминикански Пезос',
    'currency_chilean_peso' => 'Чилеански Пезос',
    'currency_icelandic_krona' => 'Исландска Круна',
    'currency_papua_new_guinean_kina' => 'Гвинејска Кина',
    'currency_jordanian_dinar' => 'Јордански Динар',
    'currency_myanmar_kyat' => 'Мјанмарски Киат',
    'currency_peruvian_sol' => 'Перуански Сол',
    'currency_botswana_pula' => 'Боцванска Пула',
    'currency_hungarian_forint' => 'Унгарски Форинт',
    'currency_ugandan_shilling' => 'Угандски Шилинг',
    'currency_barbadian_dollar' => 'Барбадоски Долар',
    'currency_brunei_dollar' => 'Брунејски Долар',
    'currency_georgian_lari' => 'Грузијски Лари',
    'currency_qatari_riyal' => 'Катарска Риал',
    'currency_honduran_lempira' => 'Хондурска Лемпира',
    'currency_surinamese_dollar' => 'Суринамски Долар',
    'currency_bahraini_dinar' => 'Бахреински Динар',
    'currency_venezuelan_bolivars' => 'Venezuelan Bolivars',
    'currency_south_korean_won' => 'South Korean Won',
    'currency_moroccan_dirham' => 'Moroccan Dirham',
    'currency_jamaican_dollar' => 'Jamaican Dollar',
    'currency_angolan_kwanza' => 'Angolan Kwanza',
    'currency_haitian_gourde' => 'Haitian Gourde',
    'currency_zambian_kwacha' => 'Zambian Kwacha',
    'currency_nepalese_rupee' => 'Nepalese Rupee',
    'currency_cfp_franc' => 'CFP Franc',
    'currency_mauritian_rupee' => 'Mauritian Rupee',
    'currency_cape_verdean_escudo' => 'Cape Verdean Escudo',
    'currency_kuwaiti_dinar' => 'Kuwaiti Dinar',
    'currency_algerian_dinar' => 'Algerian Dinar',
    'currency_macedonian_denar' => 'Македонски Денар',
    'currency_fijian_dollar' => 'Fijian Dollar',
    'currency_bolivian_boliviano' => 'Bolivian Boliviano',
    'currency_albanian_lek' => 'Albanian Lek',
    'currency_serbian_dinar' => 'Serbian Dinar',
    'currency_lebanese_pound' => 'Lebanese Pound',
    'currency_armenian_dram' => 'Armenian Dram',
    'currency_azerbaijan_manat' => 'Azerbaijan Manat',
    'currency_bosnia_and_herzegovina_convertible_mark' => 'Bosnia and Herzegovina Convertible Mark',
    'currency_belarusian_ruble' => 'Belarusian Ruble',
    'currency_moldovan_leu' => 'Moldovan Leu',
    'currency_kazakhstani_tenge' => 'Kazakhstani Tenge',
    'currency_gibraltar_pound' => 'Gibraltar Pound',

    'review_app_help' => 'Се надеваме дека уживате во користењето на апликацијата. <br/> Ако го земете во предвид :link многу би ни значело!',
    'writing_a_review' => 'пишување рецензија',

    'use_english_version' => 'Погрижете се да користите англиска верзија на датотеките. <br/> Ние ги користиме заглавијата на колоните за да се вклопат со полињата.',
    'tax1' => 'Прв данок',
    'tax2' => 'Втор Данок',
    'fee_help' => 'Такса за платниот портал е износот кој се наплаќа за пристап до финансиската мрежа која се бави со процесирање на онлан плаќања.',
    'format_export' => 'Формат за експортирање',
    'custom1' => 'Прво прилагодено',
    'custom2' => 'Второ прилагодено',
    'contact_first_name' => 'Контакт Име',
    'contact_last_name' => 'Контакт Презиме',
    'contact_custom1' => 'Контактирај прво прилагодено',
    'contact_custom2' => 'Контактирај второ прилагодено',
    'currency' => ' Валута',
    'ofx_help' => 'За решавање на проблеми проверете за коментари на :ofxhome_link и тестирајте на :ofxget_link.',
    'comments' => 'коментари',

    'item_product' => 'Предмет на продукт',
    'item_notes' => 'Забелешки за предмет',
    'item_cost' => 'Цена на предмет',
    'item_quantity' => 'Количина на предмет',
    'item_tax_rate' => 'Даночна стапка на предмет',
    'item_tax_name' => 'Име на данок на предмет',
    'item_tax1' => 'Данок на предмет1',
    'item_tax2' => 'Данок на предмет2',

    'delete_company' => 'Избриши компанија',
    'delete_company_help' => 'Трајно избриши компанија заедно со сите податоци и поставки.',
    'delete_company_message' => 'Предупредување: Ова трајно ќе ја избрише вашата компанија, нема враќање назад.',

    'applied_discount' => 'Купонот е применет, цената на планот е намалена за :discount%.',
    'applied_free_year' => 'Купонот е применет, вашата сметка е надградена на Про за една година.',

    'contact_us_help' => 'Ако пријавувате грешка ве молиме вклучете било какви податоци од storage/logs/laravel-error.log',
    'include_errors' => 'Вкличи грешки',
    'include_errors_help' => 'Вклучи :link од storage/logs/laravel-error.log',
    'recent_errors' => 'неодамнешни грешки',
    'customer' => 'Клиент',
    'customers' => 'Клиенти',
    'created_customer' => 'Успешно креиран клиент',
    'created_customers' => 'Успешно креирани :count клиенти',

    'purge_details' => 'Податоците на вашата компанија (:account) се успешно прочистени.',
    'deleted_company' => 'Успешно избришана компанија',
    'deleted_account' => 'Успешно откажана сметка',
    'deleted_company_details' => 'Вашата компанија (:account) е успешно избришана.',
    'deleted_account_details' => 'Вашата сметка (:account) е успешно избришана.',

    'alipay' => 'Alipay',
    'sofort' => 'Sofort',
    'sepa' => 'SEPA Direct Debit',
    'enable_alipay' => 'Прифати Allpay',
    'enable_sofort' => 'Прифати трансфери од Европски банки',
    'stripe_alipay_help' => 'Овие платни портали исто така мораат да бидат активирани во :link.',
    'calendar' => 'Календар',
    'pro_plan_calendar' => ':link за овозможување на календар преку приклучување на Про планот',

    'what_are_you_working_on' => 'На што работите?',
    'time_tracker' => 'Следач на време',
    'refresh' => 'Освежи',
    'filter_sort' => 'Филтрирај/Сортирај',
    'no_description' => 'Нема опис',
    'time_tracker_login' => 'Најава на следач на време',
    'save_or_discard' => 'Зачувај ги или отфрли ги промените',
    'discard_changes' => 'Отфрли промени',
    'tasks_not_enabled' => 'Задачите не се овозможени.',
    'started_task' => 'Успешно започната задача',
    'create_client' => 'Креирај клиент',

    'download_desktop_app' => 'Преземете ја десктоп апликацијата',
    'download_iphone_app' => 'Преземете ја iPhone апликацијата',
    'download_android_app' => 'Преземете ја Android апликацијата',
    'time_tracker_mobile_help' => 'Двоен допир на задачата за означување',
    'stopped' => 'Престана',
    'ascending' => 'Растечки',
    'descending' => 'Опаѓачки',
    'sort_field' => 'Сортирај по',
    'sort_direction' => 'Насока',
    'discard' => 'Откажи',
    'time_am' => 'Предпладне',
    'time_pm' => 'Попладне',
    'time_mins' => 'мин',
    'time_hr' => 'ч',
    'time_hrs' => 'ч',
    'clear' => 'Исчисти',
    'warn_payment_gateway' => 'Забелешка: прифаќањето на онлајн плаќања бара платен портал, :link за да додадете.',
    'task_rate' => 'Стапка на задача',
    'task_rate_help' => 'Постави стандардна стапка за фактурирани задачи.',
    'past_due' => 'Минато достасување',
    'document' => 'Документ',
    'invoice_or_expense' => 'Фактура/Трошок',
    'invoice_pdfs' => 'PDF фактури',
    'enable_sepa' => 'Прифати SEPA',
    'enable_bitcoin' => 'Прифати Bitcoin',
    'iban' => 'IBAN',
    'sepa_authorization' => 'Преку обезбедување на вашиот IBAN и потврдување на ова плаќање, вие ја авторизирате :company и Stripe, нашиот сервис провајдер за плаќања, да праќа инструкции на вашата банка за да ја дебитира вашата сметка и вашата банка да ја дебитира вашата сметка според тие инструкции. Имате право на поврат на средствата од вашата банка според правилата и условите на вашиот договор со банката. Повратот мора да се бара во рок од 8 недели, почнувајќи од датумот на кој вашата дебитна сметка била задолжена.',
    'recover_license' => 'Поврати лиценца',
    'purchase' => 'Купи',
    'recover' => 'Поврати',
    'apply' => 'Примени',
    'recover_white_label_header' => 'Поврати лиценца за брендирање',
    'apply_white_label_header' => 'Примени лиценца за брендирање',
    'videos' => 'Видеа',
    'video' => 'Видео',
    'return_to_invoice' => 'Врати на фактура',
    'gateway_help_13' => 'За да користите ITN оставете го полето за PDT Клуч празно.',
    'partial_due_date' => 'Делумен датум на достасување',
    'task_fields' => 'Полиња за задачи',
    'product_fields_help' => 'Повлечете ги и спуштете ги полињата за го измените нивниот распоред ',
    'custom_value1' => 'Подесена вредност',
    'custom_value2' => 'Подесена вредност',
    'enable_two_factor' => 'Автентификација преку два фактори',
    'enable_two_factor_help' => 'Користете го вашиот телефон за да го потврдите вашиот идентитет при најава',
    'two_factor_setup' => 'Поставување преку два фактори',
    'two_factor_setup_help' => 'Скенирај го бар кодот со :link компатибилна апликација.',
    'one_time_password' => 'Еднократна лозинка',
    'set_phone_for_two_factor' => 'Поставете го вашиот телефонски број како бекап за вклучување.',
    'enabled_two_factor' => 'Успешно овозможена автентификација преку два фактори',
    'add_product' => 'Додај продукт',
    'email_will_be_sent_on' => 'Забелешка: е-поштата ќе биде испратена на :date',
    'invoice_product' => 'Фактурирај продукт',
    'self_host_login' => 'Самохостирана најава',
    'set_self_hoat_url' => 'Самохостиран URL',
    'local_storage_required' => 'Грешка: локалното складирање не е достапно.',
    'your_password_reset_link' => 'Вашиот линк за ресетирање на лозинка',
    'subdomain_taken' => 'Поддоменот е веќе во употреба',
    'client_login' => 'Најава на клиент',
    'converted_amount' => 'Конвертиран износ',
    'default' => 'Стандард',
    'shipping_address' => 'Адреса за достава',
    'bllling_address' => 'Адреса за наплата',
    'billing_address1' => 'Улица за наплата',
    'billing_address2' => 'Апартман за наплата',
    'billing_city' => 'Град за наплата',
    'billing_state' => 'Држава/Провинција за наплата',
    'billing_postal_code' => 'Поштенски број за наплата',
    'billing_country' => 'Држава за наплата',
    'shipping_address1' => 'Улица за достава',
    'shipping_address2' => 'Апартман за достава',
    'shipping_city' => 'Град за достава',
    'shipping_state' => 'Држава/Провинција за достава',
    'shipping_postal_code' => 'Поштенски број за достава',
    'shipping_country' => 'Држава за достава',
    'classify' => 'Класифицирај',
    'show_shipping_address_help' => 'Побарај од клиентот да ја обезбеди адресата на достава',
    'ship_to_billing_address' => 'Достави на адреса за наплата',
    'delivery_note' => 'Забелешка за испорака',
    'show_tasks_in_portal' => 'Прикажи задачи на порталот на клиентот',
    'cancel_schedule' => 'Откажи закажување',
    'scheduled_report' => 'Закажан извештај',
    'scheduled_report_help' => 'Прати го извештајот :report по е-пошта како :format на :email',
    'created_scheduled_report' => 'Успешно закажан извештај',
    'deleted_scheduled_report' => 'Успешно откажување на закажаниот извештај',
    'scheduled_report_attached' => 'Вашиот закажан :type извештај е прикачен.',
    'scheduled_report_error' => 'Неуспешно креирање на закажан извештај',
    'invalid_one_time_password' => 'Невалидна еднократна лозинка',
    'apple_pay' => 'Apple/Google Pay',
    'enable_apple_pay' => 'Прифати Apple Pay и Pay with Google',
    'requires_subdomain' => 'Овој начин на плаќање бара :link.',
    'subdomain_is_set' => 'поставен е поддомен',
    'verification_file' => 'Датотека на верификација',
    'verification_file_missing' => 'Оваа датотека на верификација е потребна за да се прифатат плаќањата.',
    'apple_pay_domain' => 'Користи <code> :domain </code> како домен во :link.',
    'apple_pay_not_supported' => 'Извинете, Apple/Google Pay не е поддржан од вашиот пребарувач',
    'optional_payment_methods' => 'Опционални методи на плаќање',
    'add_subscription' => 'Додај претплата',
    'target_url' => 'Цел',
    'target_url_help' => 'Кога ќе се случи избраниот настан, апликацијата ќе го објавува ентитетот на целниот URL. ',
    'event' => 'Настан',
    'subscription_event_1' => 'Креиран клиент',
    'subscription_event_2' => 'Креирана фактура',
    'subscription_event_3' => 'Креирана понуда',
    'subscription_event_4' => 'Креирано плаќање',
    'subscription_event_5' => 'Креиран продавач',
    'subscription_event_6' => 'Ажурирана понуда',
    'subscription_event_7' => 'Избришана понуда',
    'subscription_event_8' => 'Ажурирана фактура',
    'subscription_event_9' => 'Избришана фактура',
    'subscription_event_10' => 'Ажуриран клиент',
    'subscription_event_11' => 'Избришан клиент',
    'subscription_event_12' => 'Избришано плаќање',
    'subscription_event_13' => 'Ажуриран продавач',
    'subscription_event_14' => 'Избришан продавач',
    'subscription_event_15' => 'Креиран трошок',
    'subscription_event_16' => 'Ажуриран трошок',
    'subscription_event_17' => 'Избришан трошок',
    'subscription_event_18' => 'Креирана задача',
    'subscription_event_19' => 'Ажурирана задача',
    'subscription_event_20' => 'Избришана задача',
    'subscription_event_21' => 'Одобрена понуда',
    'subscriptions' => 'Претплати',
    'updated_subscription' => 'Успешно ажурирана претплата',
    'created_subscription' => 'Успешно креирана претплата',
    'edit_subscription' => 'Измени претплата',
    'archive_subscription' => 'Архивирај претплата',
    'archived_subscription' => 'Успешно архивирана претплата',
    'project_error_multiple_clients' => 'Проектите не можат да припаѓаат на различни клиенти',
    'invoice_project' => 'Фактурирај проект',
    'module_recurring_invoice' => 'Повторувачки фактури',
    'module_credit' => 'Кредити',
    'module_quote' => 'Понуди и предлози',
    'module_task' => 'Задачи и проекти',
    'module_expense' => 'Трошоци и продавачи',
    'module_ticket' => 'Tickets',
    'reminders' => 'Потсетници',
    'send_client_reminders' => 'Прати потсетници по е-пошта',
    'can_view_tasks' => 'Задачите се видливи на порталот',
    'is_not_sent_reminders' => 'Потсетниците не се пратени',
    'promotion_footer' => 'Вашата промоција ќе истече набрзо, :link за да ја надградите сега.',
    'unable_to_delete_primary' => 'Забелешка: за да ја избришете оваа компанија прво избришете ги сите поврзани компании/',
    'please_register' => 'Ве молиме регистрирајте ја вашата сметка.',
    'processing_request' => 'Барањето се процесира',
    'mcrypt_warning' => 'Предупредување: Mcrypt е застарен, покрени :command за да се ажурира шифрата.',
    'edit_times' => 'Измени Време',
    'inclusive_taxes_help' => 'Вклучи <b> даноци во цената </b>',
    'inclusive_taxes_notice' => 'Ова подесување не може да се измени откако е креирана фактура.',
    'inclusive_taxes_warning' => 'Предупредување: постоечките фактури ќе мораат да бидат повторно зачувани',
    'copy_shipping' => 'Копирај достава',
    'copy_billing' => 'Копирај наплата',
    'quote_has_expired' => 'Понудата е истечена, ве молиме контактирајте го трговецот. ',
    'empty_table_footer' => 'Прикажување на 0 до 0 од 0 записи',
    'do_not_trust' => 'Не го памти овој уред',
    'trust_for_30_days' => 'Доверба 30 дена',
    'trust_forever' => 'Доверба засекогаш',
    'kanban' => 'Kanban',
    'backlog' => 'Backlog',
    'ready_to_do' => 'Подготвено за да се направи',
    'in_progress' => 'Во тек',
    'add_status' => 'Додај статус',
    'archive_status' => 'Архивирај статус',
    'new_status' => 'Нов статус',
    'convert_products' => 'Конвертирај продукти',
    'convert_products_help' => 'Автоматски конвертирај ги цените на продуктите по валутите на клиентите',
    'improve_client_portal_link' => 'Постави поддомен за да се скрати линкот на порталот на клиентот.',
    'budgeted_hours' => 'Буџетирани часови',
    'progress' => 'Напредок',
    'view_project' => 'Прегледај проект',
    'summary' => 'Резиме',
    'endless_reminder' => 'Бескраен потсетник',
    'signature_on_invoice_help' => 'Додај го претстојниот код за да се прикаже потписот на клиентот на PDF документот.',
    'signature_on_pdf' => 'Прикажи на PDF',
    'signature_on_pdf_help' => 'Прикажи го потписот на клиентот на PDF фактура/понуда.',
    'expired_white_label' => 'Лиценцата за брендирање истече',
    'return_to_login' => 'Врати се на најава',
    'convert_products_tip' => 'Забелешка: додај :link со име :name за да се види девизниот курс.',
    'amount_greater_than_balance' => 'Износот е поголем од сумата на фактурата, со останатиот износ ќе биде креиран кредит.',
    'custom_fields_tip' => 'Користи <code> Label|Option1,Option2 </code> за да се прикаже избраното поле.',
    'client_information' => 'Информации за клиентот',
    'updated_client_details' => 'Успешно ажурирани детали на клиентот',
    'auto' => 'Автоматски',
    'tax_amount' => 'Износ на данок',
    'tax_paid' => 'Платен данок',
    'none' => 'Нема',
    'proposal_message_button' => 'За да го видите вашиот предлог за :amount, кликнете на копчето подоле.',
    'proposal' => 'Предлог',
    'proposals' => 'Предлози',
    'list_proposals' => 'Листа на предлози',
    'new_proposal' => 'Нов предлог',
    'edit_proposal' => 'Измени предлог',
    'archive_proposal' => 'Архивирај предлог',
    'delete_proposal' => 'Избриши предлог',
    'created_proposal' => 'Успешно креиран предлог',
    'updated_proposal' => 'Успешно ажуриран предлог',
    'archived_proposal' => 'Успешно архивиран предлог',
    'deleted_proposal' => 'Успешно архивиран предлог',
    'archived_proposals' => 'Успешно архивирани :count предлози',
    'deleted_proposals' => 'Успешно архивирани :count предлози',
    'restored_proposal' => 'Успешно повратен предлог',
    'restore_proposal' => 'Поврати предлог',
    'snippet' => 'Фрагмент',
    'snippets' => 'Фрагменти',
    'proposal_snippet' => 'Фрагмент',
    'proposal_snippets' => 'Фрагменти',
    'new_proposal_snippet' => 'Нов фрагмент',
    'edit_proposal_snippet' => 'Измени фрагмент',
    'archive_proposal_snippet' => 'Архивирај фрагмент',
    'delete_proposal_snippet' => 'Избриши фрагмент',
    'created_proposal_snippet' => 'Успешно креиран фрагмент',
    'updated_proposal_snippet' => 'Успешно ажуриран фрагмент',
    'archived_proposal_snippet' => 'Успешно архивиран фрагмент',
    'deleted_proposal_snippet' => 'Успешно архивиран фрагмент',
    'archived_proposal_snippets' => 'Успешно архивирани :count фрагменти',
    'deleted_proposal_snippets' => 'Успешно архивирани :count фрагменти',
    'restored_proposal_snippet' => 'Успешно повратен фрагмент',
    'restore_proposal_snippet' => 'Поврати фрагмент',
    'template' => 'Шаблон',
    'templates' => 'Шаблони',
    'proposal_template' => 'Шаблон',
    'proposal_templates' => 'Шаблони',
    'new_proposal_template' => 'Нов шаблон',
    'edit_proposal_template' => 'Измени шаблон',
    'archive_proposal_template' => 'Архивирај шаблон',
    'delete_proposal_template' => 'Избриши шаблон',
    'created_proposal_template' => 'Успешно креиран шаблон',
    'updated_proposal_template' => 'Успешно ажуриран шаблон',
    'archived_proposal_template' => 'Успешно архивиран шаблон',
    'deleted_proposal_template' => 'Успешно архивиран шаблон',
    'archived_proposal_templates' => 'Успешно архивирани :count шаблони',
    'deleted_proposal_templates' => 'Успешно архивирани :count шаблони',
    'restored_proposal_template' => 'Успешно повратен шаблон',
    'restore_proposal_template' => 'Поврати шаблон',
    'proposal_category' => 'Категорија',
    'proposal_categories' => 'Категории',
    'new_proposal_category' => 'Нова категорија',
    'edit_proposal_category' => 'Измени категорија',
    'archive_proposal_category' => 'Архивирај категорија',
    'delete_proposal_category' => 'Избриши категорија',
    'created_proposal_category' => 'Успешно креирана категорија',
    'updated_proposal_category' => 'Успешно ажурирана категорија',
    'archived_proposal_category' => 'Успешно архивирана категорија',
    'deleted_proposal_category' => 'Успешно архивирана категорија',
    'archived_proposal_categories' => 'Успешно архивирани :count категории',
    'deleted_proposal_categories' => 'Успешно архивирани :count категории',
    'restored_proposal_category' => 'Успешно повратување на категорија',
    'restore_proposal_category' => 'Поврати категорија',
    'delete_status' => 'Избриши статус',
    'standard' => 'Стандард',
    'icon' => 'Икона',
    'proposal_not_found' => 'Бараниот предлог не е достапен ',
    'create_proposal_category' => 'Креирај категорија',
    'clone_proposal_template' => 'Клонирај шаблон',
    'proposal_email' => 'Е-пошта за предлог',
    'proposal_subject' => 'Нов предлог :number од :account',
    'proposal_message' => 'За да го видите вашиот предлог за :amount, кликнете на линкот подоле. ',
    'emailed_proposal' => 'Успешно пратен предлог по е-пошта',
    'load_template' => 'Вчитај шаблон',
    'no_assets' => 'Нема слики, повлечи за прикачување',
    'add_image' => 'Додај слика',
    'select_image' => 'Избери слика',
    'upgrade_to_upload_images' => 'Надградете ја сметката на план за претпријатие за да можете да прикачувате слики',
    'delete_image' => 'Избриши слика',
    'delete_image_help' => 'Предупредување: со бришење на сликата таа ќе биде отстранета од сите предлози.',
    'amount_variable_help' => 'Забелешка: полето за $износ на фактурата ќе го користи полето за делумно/депозит а ако е поставено поинаку, ќе го користи сумата по фактурата.',
    'taxes_are_included_help' => 'Забелешка: инклузивните даноци се овозможени.',
    'taxes_are_not_included_help' => 'Забелешка: инклузивните даноци се оневозможени.',
    'change_requires_purge' => 'За да се смени ова подесување треба :link податоците на сметката.',
    'purging' => 'прочистување',
    'warning_local_refund' => 'Повратот на средства ќе биде запишан во апликацијата но НЕМА да биде испроцесиран преку платниот портал.',
    'email_address_changed' => 'Адресата на е-пошта е сменета',
    'email_address_changed_message' => 'Адресата на е-пошта на вашата сметка е сменета од :old_email во :new_email.',
    'test' => 'Тест',
    'beta' => 'Бета',
    'gmp_required' => 'Експортирањето во ZIP бара GMP екстензија',
    'email_history' => 'Историја на е-пошта',
    'loading' => 'Вчитување',
    'no_messages_found' => 'Нема пораки',
    'processing' => 'Се процесира',
    'reactivate' => 'Реактивирај',
    'reactivated_email' => 'Адресата на е-пошта е реактивирана',
    'emails' => 'Е-пошта',
    'opened' => 'Отворено',
    'bounced' => 'Отфрлено',
    'total_sent' => 'Вкупно пратено',
    'total_opened' => 'Вкупно отворено',
    'total_bounced' => 'Вкупно отфрлено',
    'total_spam' => 'Вкупно спам',
    'platforms' => 'Вкупно клиенти',
    'email_clients' => 'Прати е-пошта на клиенти',
    'mobile' => 'Мобилен',
    'desktop' => 'Десктоп',
    'webmail' => 'Webmail',
    'group' => 'Група',
    'subgroup' => 'Подгрупа',
    'unset' => 'Отстрани',
    'received_new_payment' => 'Добивте ново плаќање!',
    'slack_webhook_help' => 'Добивајте известувања за плаќањата преку :link.',
    'slack_incoming_webhooks' => 'Slack дојдовни webhooks',
    'accept' => 'Прифати',
    'accepted_terms' => 'Најновите услови на услугата беа успешно прифатени',
    'invalid_url' => 'Невалиден URL',
    'workflow_settings' => 'Подесувања на текот на работа',
    'auto_email_invoice' => 'Автоматска е-пошта',
    'auto_email_invoice_help' => 'Автоматски испрати повторувачки фактури по е-пошта кога ќе бидат креирани.',
    'auto_archive_invoice' => 'Автоматско архивирање',
    'auto_archive_invoice_help' => 'Автоматски архивирај фактури кога ќе бидат платени.',
    'auto_archive_quote' => 'Автоматско архивирање',
    'auto_archive_quote_help' => 'Автоматски архивирај фактури кога ќе бидат конвертирани.',
    'require_approve_quote' => 'Require approve quote',
    'require_approve_quote_help' => 'Require clients to approve quotes.',
    'allow_approve_expired_quote' => 'Овозможи одобрување на истечена понуда',
    'allow_approve_expired_quote_help' => 'Овозможи им на клиентите да одобруваат истечени понуди.',
    'invoice_workflow' => 'Работен циклус на фактура',
    'quote_workflow' => 'Работен циклус на понуда',
    'client_must_be_active' => 'Грешка: клиентот мора да биде активен',
    'purge_client' => 'Прочисти клиент',
    'purged_client' => 'Успешно прочистување на клиент',
    'purge_client_warning' => 'Сите поврзани записи (фактури, задачи, трошоци, документи, итн.) исто така ќе бидат избришани.',
    'clone_product' => 'Клонирај продукт',
    'item_details' => 'Детали на предмет',
    'send_item_details_help' => 'Испратете ги деталите за ставката на платниот портал.',
    'view_proposal' => 'Прегледај предлог',
    'view_in_portal' => 'Прегледај во портал',
    'cookie_message' => 'Оваа веб-страница користи колачиња за да ви го обезбеди најдоброто искуство на нашата веб-страница.',
    'got_it' => 'Разбрав!',
    'vendor_will_create' => 'ќе биде креиран продавач',
    'vendors_will_create' => 'ќе бидат креирани продавачи',
    'created_vendors' => 'Успешно креирани :count продавач(и)',
    'import_vendors' => 'Внеси продавачи',
    'company' => 'Компанија',
    'client_field' => 'Поле за клиент',
    'contact_field' => 'Поле за контакт',
    'product_field' => 'Поле за продукт',
    'task_field' => 'Поле за задача',
    'project_field' => 'Поле за проект',
    'expense_field' => 'Поле за трошок',
    'vendor_field' => 'Поле за продавач',
    'company_field' => 'Поле за компанија',
    'invoice_field' => 'Поле за фактура',
    'invoice_surcharge' => 'Доплата за фактура',
    'custom_task_fields_help' => 'Додај поле при креирање на задача.',
    'custom_project_fields_help' => 'Додај поле при креирање на проект.',
    'custom_expense_fields_help' => 'Додај поле при креирање на трошок.',
    'custom_vendor_fields_help' => 'Додај поле при креирање на продавач.',
    'messages' => 'Пораки',
    'unpaid_invoice' => 'Неплатена фактура',
    'paid_invoice' => 'Платена фактура',
    'unapproved_quote' => 'Неодобрена понуда',
    'unapproved_proposal' => 'Неодобрен предлог',
    'autofills_city_state' => 'Автоматско пополнување на град/држава',
    'no_match_found' => 'Не се пронајде совпаѓање',
    'password_strength' => 'Сила на лозинка',
    'strength_weak' => 'Слаба',
    'strength_good' => 'Добра',
    'strength_strong' => 'Силна',
    'mark' => 'Обележано',
    'updated_task_status' => 'Успешно ажуриран статус на задача',
    'background_image' => 'Позадинска слика',
    'background_image_help' => 'Користете го :link за да управувате со сите слики, ние препорачуваме користење на мала датотека.',
    'proposal_editor' => 'уредник на предлог',
    'background' => 'Позадина',
    'guide' => 'Водич',
    'gateway_fee_item' => 'Ставка на провизија на платниот портал.',
    'gateway_fee_description' => 'Провизија за надоместок на платниот портал.',
    'gateway_fee_discount_description' => 'Gateway Fee Discount',
    'show_payments' => 'Прикажи плаќања',
    'show_aging' => 'Прикажи застарени',
    'reference' => 'Референца',
    'amount_paid' => 'Платен износ',
    'send_notifications_for' => 'Испрати известувања за',
    'all_invoices' => 'Сите фактури',
    'my_invoices' => 'Мои фактури',
    'payment_reference' => 'Payment Reference',
    'maximum' => 'Максимум',
    'sort' => 'Подреди',
    'refresh_complete' => 'Refresh Complete',
    'please_enter_your_email' => 'Ве молиме внесете ја вашата е-пошта',
    'please_enter_your_password' => 'Ве молиме внесете ја вашата лозинка',
    'please_enter_your_url' => 'Ве молиме внесете ја вашата URL',
    'please_enter_a_product_key' => 'Please enter a product key',
    'an_error_occurred' => 'Настана грешка',
    'overview' => 'Overview',
    'copied_to_clipboard' => 'Copied :value to the clipboard',
    'error' => 'Грешка',
    'could_not_launch' => 'Could not launch',
    'additional' => 'Additional',
    'ok' => 'Ok',
    'email_is_invalid' => 'Email is invalid',
    'items' => 'Items',
    'partial_deposit' => 'Partial/Deposit',
    'add_item' => 'Add Item',
    'total_amount' => 'Total Amount',
    'pdf' => 'PDF',
    'invoice_status_id' => 'Invoice Status',
    'click_plus_to_add_item' => 'Click + to add an item',
    'count_selected' => ':count selected',
    'dismiss' => 'Dismiss',
    'please_select_a_date' => 'Please select a date',
    'please_select_a_client' => 'Please select a client',
    'language' => 'Language',
    'updated_at' => 'Updated',
    'please_enter_an_invoice_number' => 'Please enter an invoice number',
    'please_enter_a_quote_number' => 'Please enter a quote number',
    'clients_invoices' => ':client\'s invoices',
    'viewed' => 'Viewed',
    'approved' => 'Approved',
    'invoice_status_1' => 'Draft',
    'invoice_status_2' => 'Sent',
    'invoice_status_3' => 'Viewed',
    'invoice_status_4' => 'Approved',
    'invoice_status_5' => 'Partial',
    'invoice_status_6' => 'Paid',
    'marked_invoice_as_sent' => 'Successfully marked invoice as sent',
    'please_enter_a_client_or_contact_name' => 'Please enter a client or contact name',
    'restart_app_to_apply_change' => 'Restart the app to apply the change',
    'refresh_data' => 'Refresh Data',
    'blank_contact' => 'Blank Contact',
    'no_records_found' => 'No records found',
    'industry' => 'Industry',
    'size' => 'Size',
    'net' => 'Net',
    'show_tasks' => 'Show tasks',
    'email_reminders' => 'Email Reminders',
    'reminder1' => 'First Reminder',
    'reminder2' => 'Second Reminder',
    'reminder3' => 'Third Reminder',
    'send' => 'Send',
    'auto_billing' => 'Auto billing',
    'button' => 'Button',
    'more' => 'More',
    'edit_recurring_invoice' => 'Измени Повторувачка Фактура',
    'edit_recurring_quote' => 'Измени Повторувачка Понуда',
    'quote_status' => 'Quote Status',
    'please_select_an_invoice' => 'Please select an invoice',
    'filtered_by' => 'Filtered by',
    'payment_status' => 'Payment Status',
    'payment_status_1' => 'Pending',
    'payment_status_2' => 'Voided',
    'payment_status_3' => 'Failed',
    'payment_status_4' => 'Completed',
    'payment_status_5' => 'Partially Refunded',
    'payment_status_6' => 'Refunded',
    'send_receipt_to_client' => 'Send receipt to the client',
    'refunded' => 'Refunded',
    'marked_quote_as_sent' => 'Successfully marked quote as sent',
    'custom_module_settings' => 'Custom Module Settings',
    'ticket' => 'Ticket',
    'tickets' => 'Tickets',
    'ticket_number' => 'Ticket #',
    'new_ticket' => 'New Ticket',
    'edit_ticket' => 'Edit Ticket',
    'view_ticket' => 'View Ticket',
    'archive_ticket' => 'Archive Ticket',
    'restore_ticket' => 'Restore Ticket',
    'delete_ticket' => 'Delete Ticket',
    'archived_ticket' => 'Successfully archived ticket',
    'archived_tickets' => 'Successfully archived tickets',
    'restored_ticket' => 'Successfully restored ticket',
    'deleted_ticket' => 'Successfully deleted ticket',
    'open' => 'Open',
    'new' => 'New',
    'closed' => 'Closed',
    'reopened' => 'Reopened',
    'priority' => 'Priority',
    'last_updated' => 'Last Updated',
    'comment' => 'Comments',
    'tags' => 'Tags',
    'linked_objects' => 'Linked Objects',
    'low' => 'Low',
    'medium' => 'Medium',
    'high' => 'High',
    'no_due_date' => 'No due date set',
    'assigned_to' => 'Assigned to',
    'reply' => 'Reply',
    'awaiting_reply' => 'Awaiting reply',
    'ticket_close' => 'Close Ticket',
    'ticket_reopen' => 'Reopen Ticket',
    'ticket_open' => 'Open Ticket',
    'ticket_split' => 'Split Ticket',
    'ticket_merge' => 'Merge Ticket',
    'ticket_update' => 'Update Ticket',
    'ticket_settings' => 'Ticket Settings',
    'updated_ticket' => 'Ticket Updated',
    'mark_spam' => 'Mark as Spam',
    'local_part' => 'Local Part',
    'local_part_unavailable' => 'Name taken',
    'local_part_available' => 'Name available',
    'local_part_invalid' => 'Invalid name (alpha numeric only, no spaces',
    'local_part_help' => 'Customize the local part of your inbound support email, ie. YOUR_NAME@support.invoiceninja.com',
    'from_name_help' => 'From name is the recognizable sender which is displayed instead of the email address, ie Support Center',
    'local_part_placeholder' => 'YOUR_NAME',
    'from_name_placeholder' => 'Support Center',
    'attachments' => 'Attachments',
    'client_upload' => 'Client uploads',
    'enable_client_upload_help' => 'Allow clients to upload documents/attachments',
    'max_file_size_help' => 'Maximum file size (KB) is limited by your post_max_size and upload_max_filesize variables as set in your PHP.INI',
    'max_file_size' => 'Maximum file size',
    'mime_types' => 'Mime types',
    'mime_types_placeholder' => '.pdf , .docx, .jpg',
    'mime_types_help' => 'Comma separated list of allowed mime types, leave blank for all',
    'ticket_number_start_help' => 'Ticket number must be greater than the current ticket number',
    'new_ticket_template_id' => 'New ticket',
    'new_ticket_autoresponder_help' => 'Selecting a template will send an auto response to a client/contact when a new ticket is created',
    'update_ticket_template_id' => 'Updated ticket',
    'update_ticket_autoresponder_help' => 'Selecting a template will send an auto response to a client/contact when a ticket is updated',
    'close_ticket_template_id' => 'Closed ticket',
    'close_ticket_autoresponder_help' => 'Selecting a template will send an auto response to a client/contact when a ticket is closed',
    'default_priority' => 'Default priority',
    'alert_new_comment_id' => 'New comment',
    'alert_comment_ticket_help' => 'Selecting a template will send a notification (to agent) when a comment is made.',
    'alert_comment_ticket_email_help' => 'Comma separated emails to bcc on new comment.',
    'new_ticket_notification_list' => 'Additional new ticket notifications',
    'update_ticket_notification_list' => 'Additional new comment notifications',
    'comma_separated_values' => 'admin@example.com, supervisor@example.com',
    'alert_ticket_assign_agent_id' => 'Ticket assignment',
    'alert_ticket_assign_agent_id_hel' => 'Selecting a template will send a notification (to agent) when a ticket is assigned.',
    'alert_ticket_assign_agent_id_notifications' => 'Additional ticket assigned notifications',
    'alert_ticket_assign_agent_id_help' => 'Comma separated emails to bcc on ticket assignment.',
    'alert_ticket_transfer_email_help' => 'Comma separated emails to bcc on ticket transfer.',
    'alert_ticket_overdue_agent_id' => 'Ticket overdue',
    'alert_ticket_overdue_email' => 'Additional overdue ticket notifications',
    'alert_ticket_overdue_email_help' => 'Comma separated emails to bcc on ticket overdue.',
    'alert_ticket_overdue_agent_id_help' => 'Selecting a template will send a notification (to agent) when a ticket becomes overdue.',
    'ticket_master' => 'Ticket Master',
    'ticket_master_help' => 'Has the ability to assign and transfer tickets. Assigned as the default agent for all tickets.',
    'default_agent' => 'Default Agent',
    'default_agent_help' => 'If selected will automatically be assigned to all inbound tickets',
    'show_agent_details' => 'Show agent details on responses',
    'avatar' => 'Avatar',
    'remove_avatar' => 'Remove avatar',
    'ticket_not_found' => 'Ticket not found',
    'add_template' => 'Add Template',
    'ticket_template' => 'Ticket Template',
    'ticket_templates' => 'Ticket Templates',
    'updated_ticket_template' => 'Updated Ticket Template',
    'created_ticket_template' => 'Created Ticket Template',
    'archive_ticket_template' => 'Archive Template',
    'restore_ticket_template' => 'Restore Template',
    'archived_ticket_template' => 'Successfully archived template',
    'restored_ticket_template' => 'Successfully restored template',
    'close_reason' => 'Let us know why you are closing this ticket',
    'reopen_reason' => 'Let us know why you are reopening this ticket',
    'enter_ticket_message' => 'Please enter a message to update the ticket',
    'show_hide_all' => 'Show / Hide all',
    'subject_required' => 'Subject required',
    'mobile_refresh_warning' => 'Ако ја користите мобилната апликација можеби ќе треба да направите целосно освежување.',
    'enable_proposals_for_background' => 'За да прикажите позадинска слика :link за овозможување на модулот за предлози.',
    'ticket_assignment' => 'Ticket :ticket_number has been assigned to :agent',
    'ticket_contact_reply' => 'Ticket :ticket_number has been updated by client :contact',
    'ticket_new_template_subject' => 'Ticket :ticket_number has been created.',
    'ticket_updated_template_subject' => 'Ticket :ticket_number has been updated.',
    'ticket_closed_template_subject' => 'Ticket :ticket_number has been closed.',
    'ticket_overdue_template_subject' => 'Ticket :ticket_number is now overdue',
    'merge' => 'Merge',
    'merged' => 'Merged',
    'agent' => 'Agent',
    'parent_ticket' => 'Parent Ticket',
    'linked_tickets' => 'Linked Tickets',
    'merge_prompt' => 'Enter ticket number to merge into',
    'merge_from_to' => 'Ticket #:old_ticket merged into Ticket #:new_ticket',
    'merge_closed_ticket_text' => 'Ticket #:old_ticket was closed and merged into Ticket#:new_ticket - :subject',
    'merge_updated_ticket_text' => 'Ticket #:old_ticket was closed and merged into this ticket',
    'merge_placeholder' => 'Merge ticket #:ticket into the following ticket',
    'select_ticket' => 'Select Ticket',
    'new_internal_ticket' => 'New internal ticket',
    'internal_ticket' => 'Internal ticket',
    'create_ticket' => 'Create ticket',
    'allow_inbound_email_tickets_external' => 'New Tickets by email (Client)',
    'allow_inbound_email_tickets_external_help' => 'Allow clients to create new tickets by email',
    'include_in_filter' => 'Include in filter',
    'custom_client1' => ':VALUE',
    'custom_client2' => ':VALUE',
    'compare' => 'Compare',
    'hosted_login' => 'Hosted Login',
    'selfhost_login' => 'Selfhost Login',
    'google_login' => 'Google Login',
    'thanks_for_patience' => 'Thank for your patience while we work to implement these features.\n\nWe hope to have them completed in the next few months.\n\nUntil then we\'ll continue to support the',
    'legacy_mobile_app' => 'legacy mobile app',
    'today' => 'Today',
    'current' => 'Current',
    'previous' => 'Previous',
    'current_period' => 'Current Period',
    'comparison_period' => 'Comparison Period',
    'previous_period' => 'Previous Period',
    'previous_year' => 'Previous Year',
    'compare_to' => 'Compare to',
    'last_week' => 'Last Week',
    'clone_to_invoice' => 'Clone to Invoice',
    'clone_to_quote' => 'Clone to Quote',
    'convert' => 'Convert',
    'last7_days' => 'Last 7 Days',
    'last30_days' => 'Last 30 Days',
    'custom_js' => 'Custom JS',
    'adjust_fee_percent_help' => 'Adjust percent to account for fee',
    'show_product_notes' => 'Show product details',
    'show_product_notes_help' => 'Include the <b>description and cost</b> in the product dropdown',
    'important' => 'Important',
    'thank_you_for_using_our_app' => 'Thank you for using our app!',
    'if_you_like_it' => 'If you like it please',
    'to_rate_it' => 'to rate it.',
    'average' => 'Average',
    'unapproved' => 'Unapproved',
    'authenticate_to_change_setting' => 'Please authenticate to change this setting',
    'locked' => 'Locked',
    'authenticate' => 'Authenticate',
    'please_authenticate' => 'Please authenticate',
    'biometric_authentication' => 'Biometric Authentication',
    'auto_start_tasks' => 'Auto Start Tasks',
    'budgeted' => 'Budgeted',
    'please_enter_a_name' => 'Please enter a name',
    'click_plus_to_add_time' => 'Click + to add time',
    'design' => 'Design',
    'password_is_too_short' => 'Password is too short',
    'failed_to_find_record' => 'Failed to find record',
    'valid_until_days' => 'Valid Until',
    'valid_until_days_help' => 'Automatically sets the <b>Valid Until</b> value on quotes to this many days in the future.  Leave blank to disable.',
    'usually_pays_in_days' => 'Days',
    'requires_an_enterprise_plan' => 'Requires an enterprise plan',
    'take_picture' => 'Take Picture',
    'upload_file' => 'Upload File',
    'new_document' => 'New Document',
    'edit_document' => 'Edit Document',
    'uploaded_document' => 'Successfully uploaded document',
    'updated_document' => 'Successfully updated document',
    'archived_document' => 'Successfully archived document',
    'deleted_document' => 'Successfully deleted document',
    'restored_document' => 'Successfully restored document',
    'no_history' => 'No History',
    'expense_status_1' => 'Logged',
    'expense_status_2' => 'Pending',
    'expense_status_3' => 'Invoiced',
    'no_record_selected' => 'No record selected',
    'error_unsaved_changes' => 'Please save or cancel your changes',
    'thank_you_for_your_purchase' => 'Thank you for your purchase!',
    'redeem' => 'Redeem',
    'back' => 'Back',
    'past_purchases' => 'Past Purchases',
    'annual_subscription' => 'Annual Subscription',
    'pro_plan' => 'Pro Plan',
    'enterprise_plan' => 'Enterprise Plan',
    'count_users' => ':count users',
    'upgrade' => 'Upgrade',
    'please_enter_a_first_name' => 'Please enter a first name',
    'please_enter_a_last_name' => 'Please enter a last name',
    'please_agree_to_terms_and_privacy' => 'Please agree to the terms of service and privacy policy to create an account.',
    'i_agree_to_the' => 'I agree to the',
    'terms_of_service_link' => 'terms of service',
    'privacy_policy_link' => 'privacy policy',
    'view_website' => 'View Website',
    'create_account' => 'Create Account',
    'email_login' => 'Email Login',
    'late_fees' => 'Late Fees',
    'payment_number' => 'Payment Number',
    'before_due_date' => 'Before the due date',
    'after_due_date' => 'After the due date',
    'after_invoice_date' => 'After the invoice date',
    'filtered_by_user' => 'Filtered by User',
    'created_user' => 'Successfully created user',
    'primary_font' => 'Primary Font',
    'secondary_font' => 'Secondary Font',
    'number_padding' => 'Number Padding',
    'general' => 'General',
    'surcharge_field' => 'Surcharge Field',
    'company_value' => 'Company Value',
    'credit_field' => 'Credit Field',
    'payment_field' => 'Payment Field',
    'group_field' => 'Group Field',
    'number_counter' => 'Number Counter',
    'number_pattern' => 'Number Pattern',
    'custom_javascript' => 'Custom JavaScript',
    'portal_mode' => 'Portal Mode',
    'attach_pdf' => 'Attach PDF',
    'attach_documents' => 'Attach Documents',
    'attach_ubl' => 'Attach UBL',
    'email_style' => 'Email Style',
    'processed' => 'Processed',
    'fee_amount' => 'Fee Amount',
    'fee_percent' => 'Fee Percent',
    'fee_cap' => 'Fee Cap',
    'limits_and_fees' => 'Limits/Fees',
    'credentials' => 'Credentials',
    'require_billing_address_help' => 'Require client to provide their billing address',
    'require_shipping_address_help' => 'Require client to provide their shipping address',
    'deleted_tax_rate' => 'Successfully deleted tax rate',
    'restored_tax_rate' => 'Successfully restored tax rate',
    'provider' => 'Provider',
    'company_gateway' => 'Payment Gateway',
    'company_gateways' => 'Payment Gateways',
    'new_company_gateway' => 'New Gateway',
    'edit_company_gateway' => 'Edit Gateway',
    'created_company_gateway' => 'Successfully created gateway',
    'updated_company_gateway' => 'Successfully updated gateway',
    'archived_company_gateway' => 'Successfully archived gateway',
    'deleted_company_gateway' => 'Successfully deleted gateway',
    'restored_company_gateway' => 'Successfully restored gateway',
    'continue_editing' => 'Continue Editing',
    'default_value' => 'Default value',
    'currency_format' => 'Currency Format',
    'first_day_of_the_week' => 'First Day of the Week',
    'first_month_of_the_year' => 'First Month of the Year',
    'symbol' => 'Симбол',
    'ocde' => 'Code',
    'date_format' => 'Date Format',
    'datetime_format' => 'Datetime Format',
    'send_reminders' => 'Send Reminders',
    'timezone' => 'Timezone',
    'filtered_by_group' => 'Filtered by Group',
    'filtered_by_invoice' => 'Filtered by Invoice',
    'filtered_by_client' => 'Filtered by Client',
    'filtered_by_vendor' => 'Filtered by Vendor',
    'group_settings' => 'Group Settings',
    'groups' => 'Groups',
    'new_group' => 'New Group',
    'edit_group' => 'Edit Group',
    'created_group' => 'Successfully created group',
    'updated_group' => 'Successfully updated group',
    'archived_group' => 'Successfully archived group',
    'deleted_group' => 'Successfully deleted group',
    'restored_group' => 'Successfully restored group',
    'upload_logo' => 'Upload Logo',
    'uploaded_logo' => 'Successfully uploaded logo',
    'saved_settings' => 'Successfully saved settings',
    'device_settings' => 'Device Settings',
    'credit_cards_and_banks' => 'Credit Cards & Banks',
    'price' => 'Price',
    'email_sign_up' => 'Email Sign Up',
    'google_sign_up' => 'Google Sign Up',
    'sign_up_with_google' => 'Sign Up With Google',
    'long_press_multiselect' => 'Long-press Multiselect',
    'migrate_to_next_version' => 'Migrate to the next version of Invoice Ninja',
    'migrate_intro_text' => 'We\'ve been working on next version of Invoice Ninja. Click the button bellow to start the migration.',
    'start_the_migration' => 'Start the migration',
    'migration' => 'Migration',
    'welcome_to_the_new_version' => 'Welcome to the new version of Invoice Ninja',
    'next_step_data_download' => 'At the next step, we\'ll let you download your data for the migration.',
    'download_data' => 'Press button below to download the data.',
    'migration_import' => 'Awesome! Now you are ready to import your migration. Go to your new installation to import your data',
    'continue' => 'Continue',
    'company1' => 'Custom Company 1',
    'company2' => 'Custom Company 2',
    'company3' => 'Custom Company 3',
    'company4' => 'Custom Company 4',
    'product1' => 'Custom Product 1',
    'product2' => 'Custom Product 2',
    'product3' => 'Custom Product 3',
    'product4' => 'Custom Product 4',
    'client1' => 'Custom Client 1',
    'client2' => 'Custom Client 2',
    'client3' => 'Custom Client 3',
    'client4' => 'Custom Client 4',
    'contact1' => 'Custom Contact 1',
    'contact2' => 'Custom Contact 2',
    'contact3' => 'Custom Contact 3',
    'contact4' => 'Custom Contact 4',
    'task1' => 'Custom Task 1',
    'task2' => 'Custom Task 2',
    'task3' => 'Custom Task 3',
    'task4' => 'Custom Task 4',
    'project1' => 'Custom Project 1',
    'project2' => 'Custom Project 2',
    'project3' => 'Custom Project 3',
    'project4' => 'Custom Project 4',
    'expense1' => 'Custom Expense 1',
    'expense2' => 'Custom Expense 2',
    'expense3' => 'Custom Expense 3',
    'expense4' => 'Custom Expense 4',
    'vendor1' => 'Custom Vendor 1',
    'vendor2' => 'Custom Vendor 2',
    'vendor3' => 'Custom Vendor 3',
    'vendor4' => 'Custom Vendor 4',
    'invoice1' => 'Custom Invoice 1',
    'invoice2' => 'Custom Invoice 2',
    'invoice3' => 'Custom Invoice 3',
    'invoice4' => 'Custom Invoice 4',
    'payment1' => 'Custom Payment 1',
    'payment2' => 'Custom Payment 2',
    'payment3' => 'Custom Payment 3',
    'payment4' => 'Custom Payment 4',
    'surcharge1' => 'Custom Surcharge 1',
    'surcharge2' => 'Custom Surcharge 2',
    'surcharge3' => 'Custom Surcharge 3',
    'surcharge4' => 'Custom Surcharge 4',
    'group1' => 'Custom Group 1',
    'group2' => 'Custom Group 2',
    'group3' => 'Custom Group 3',
    'group4' => 'Custom Group 4',
    'number' => 'Number',
    'count' => 'Count',
    'is_active' => 'Is Active',
    'contact_last_login' => 'Contact Last Login',
    'contact_full_name' => 'Contact Full Name',
    'contact_custom_value1' => 'Contact Custom Value 1',
    'contact_custom_value2' => 'Contact Custom Value 2',
    'contact_custom_value3' => 'Contact Custom Value 3',
    'contact_custom_value4' => 'Contact Custom Value 4',
    'assigned_to_id' => 'Assigned To Id',
    'created_by_id' => 'Created By Id',
    'add_column' => 'Add Column',
    'edit_columns' => 'Edit Columns',
    'to_learn_about_gogle_fonts' => 'to learn about Google Fonts',
    'refund_date' => 'Refund Date',
    'multiselect' => 'Multiselect',
    'verify_password' => 'Verify Password',
    'applied' => 'Applied',
    'include_recent_errors' => 'Include recent errors from the logs',
    'your_message_has_been_received' => 'We have received your message and will try to respond promptly.',
    'show_product_details' => 'Show Product Details',
    'show_product_details_help' => 'Include the description and cost in the product dropdown',
    'pdf_min_requirements' => 'The PDF renderer requires :version',
    'adjust_fee_percent' => 'Adjust Fee Percent',
    'configure_settings' => 'Configure Settings',
    'about' => 'About',
    'credit_email' => 'Credit Email',
    'domain_url' => 'Domain URL',
    'password_is_too_easy' => 'Password must contain an upper case character and a number',
    'client_portal_tasks' => 'Client Portal Tasks',
    'client_portal_dashboard' => 'Client Portal Dashboard',
    'please_enter_a_value' => 'Please enter a value',
    'deleted_logo' => 'Successfully deleted logo',
    'generate_number' => 'Generate Number',
    'when_saved' => 'When Saved',
    'when_sent' => 'When Sent',
    'select_company' => 'Select Company',
    'float' => 'Float',
    'collapse' => 'Collapse',
    'show_or_hide' => 'Show/hide',
    'menu_sidebar' => 'Menu Sidebar',
    'history_sidebar' => 'History Sidebar',
    'tablet' => 'Tablet',
    'layout' => 'Layout',
    'module' => 'Module',
    'first_custom' => 'First Custom',
    'second_custom' => 'Second Custom',
    'third_custom' => 'Third Custom',
    'show_cost' => 'Show Cost',
    'show_cost_help' => 'Display a product cost field to track the markup/profit',
    'show_product_quantity' => 'Show Product Quantity',
    'show_product_quantity_help' => 'Display a product quantity field, otherwise default to one',
    'show_invoice_quantity' => 'Show Invoice Quantity',
    'show_invoice_quantity_help' => 'Display a line item quantity field, otherwise default to one',
    'default_quantity' => 'Default Quantity',
    'default_quantity_help' => 'Automatically set the line item quantity to one',
    'one_tax_rate' => 'One Tax Rate',
    'two_tax_rates' => 'Two Tax Rates',
    'three_tax_rates' => 'Three Tax Rates',
    'default_tax_rate' => 'Default Tax Rate',
    'invoice_tax' => 'Invoice Tax',
    'line_item_tax' => 'Line Item Tax',
    'inclusive_taxes' => 'Inclusive Taxes',
    'invoice_tax_rates' => 'Invoice Tax Rates',
    'item_tax_rates' => 'Item Tax Rates',
    'configure_rates' => 'Configure rates',
    'tax_settings_rates' => 'Tax Rates',
    'accent_color' => 'Accent Color',
    'comma_sparated_list' => 'Comma separated list',
    'single_line_text' => 'Single-line text',
    'multi_line_text' => 'Multi-line text',
    'dropdown' => 'Dropdown',
    'field_type' => 'Field Type',
    'recover_password_email_sent' => 'A password recovery email has been sent',
    'removed_user' => 'Successfully removed user',
    'freq_three_years' => 'Three Years',
    'military_time_help' => '24 Hour Display',
    'click_here_capital' => 'Click here',
    'marked_invoice_as_paid' => 'Successfully marked invoice as sent',
    'marked_invoices_as_sent' => 'Successfully marked invoices as sent',
    'marked_invoices_as_paid' => 'Successfully marked invoices as sent',
    'activity_57' => 'System failed to email invoice :invoice',
    'custom_value3' => 'Custom Value 3',
    'custom_value4' => 'Custom Value 4',
    'email_style_custom' => 'Custom Email Style',
    'custom_message_dashboard' => 'Custom Dashboard Message',
    'custom_message_unpaid_invoice' => 'Custom Unpaid Invoice Message',
    'custom_message_paid_invoice' => 'Custom Paid Invoice Message',
    'custom_message_unapproved_quote' => 'Custom Unapproved Quote Message',
    'lock_sent_invoices' => 'Lock Sent Invoices',
    'translations' => 'Translations',
    'task_number_pattern' => 'Task Number Pattern',
    'task_number_counter' => 'Task Number Counter',
    'expense_number_pattern' => 'Expense Number Pattern',
    'expense_number_counter' => 'Expense Number Counter',
    'vendor_number_pattern' => 'Vendor Number Pattern',
    'vendor_number_counter' => 'Vendor Number Counter',
    'ticket_number_pattern' => 'Ticket Number Pattern',
    'ticket_number_counter' => 'Ticket Number Counter',
    'payment_number_pattern' => 'Payment Number Pattern',
    'payment_number_counter' => 'Payment Number Counter',
    'invoice_number_pattern' => 'Invoice Number Pattern',
    'quote_number_pattern' => 'Quote Number Pattern',
    'client_number_pattern' => 'Credit Number Pattern',
    'client_number_counter' => 'Credit Number Counter',
    'credit_number_pattern' => 'Credit Number Pattern',
    'credit_number_counter' => 'Credit Number Counter',
    'reset_counter_date' => 'Reset Counter Date',
    'counter_padding' => 'Counter Padding',
    'shared_invoice_quote_counter' => 'Shared Invoice Quote Counter',
    'default_tax_name_1' => 'Default Tax Name 1',
    'default_tax_rate_1' => 'Default Tax Rate 1',
    'default_tax_name_2' => 'Default Tax Name 2',
    'default_tax_rate_2' => 'Default Tax Rate 2',
    'default_tax_name_3' => 'Default Tax Name 3',
    'default_tax_rate_3' => 'Default Tax Rate 3',
    'email_subject_invoice' => 'Email Invoice Subject',
    'email_subject_quote' => 'Email Quote Subject',
    'email_subject_payment' => 'Email Payment Subject',
    'switch_list_table' => 'Switch List Table',
    'client_city' => 'Client City',
    'client_state' => 'Client State',
    'client_country' => 'Client Country',
    'client_is_active' => 'Client is Active',
    'client_balance' => 'Состојба на клиент',
    'client_address1' => 'Client Street',
    'client_address2' => 'Client Apt/Suite',
    'client_shipping_address1' => 'Client Shipping Street',
    'client_shipping_address2' => 'Client Shipping Apt/Suite',
    'tax_rate1' => 'Tax Rate 1',
    'tax_rate2' => 'Tax Rate 2',
    'tax_rate3' => 'Tax Rate 3',
    'archived_at' => 'Archived At',
    'has_expenses' => 'Has Expenses',
    'custom_taxes1' => 'Custom Taxes 1',
    'custom_taxes2' => 'Custom Taxes 2',
    'custom_taxes3' => 'Custom Taxes 3',
    'custom_taxes4' => 'Custom Taxes 4',
    'custom_surcharge1' => 'Custom Surcharge 1',
    'custom_surcharge2' => 'Custom Surcharge 2',
    'custom_surcharge3' => 'Custom Surcharge 3',
    'custom_surcharge4' => 'Custom Surcharge 4',
    'is_deleted' => 'Is Deleted',
    'vendor_city' => 'Vendor City',
    'vendor_state' => 'Vendor State',
    'vendor_country' => 'Vendor Country',
    'credit_footer' => 'Credit Footer',
    'credit_terms' => 'Credit Terms',
    'untitled_company' => 'Untitled Company',
    'added_company' => 'Successfully added company',
    'supported_events' => 'Supported Events',
    'custom3' => 'Third Custom',
    'custom4' => 'Fourth Custom',
    'optional' => 'Optional',
    'license' => 'License',
    'invoice_balance' => 'Состојба по Фактура',
    'saved_design' => 'Successfully saved design',
    'client_details' => 'Client Details',
    'company_address' => 'Company Address',
    'quote_details' => 'Quote Details',
    'credit_details' => 'Credit Details',
    'product_columns' => 'Product Columns',
    'task_columns' => 'Task Columns',
    'add_field' => 'Add Field',
    'all_events' => 'All Events',
    'owned' => 'Owned',
    'payment_success' => 'Payment Success',
    'payment_failure' => 'Payment Failure',
    'quote_sent' => 'Quote Sent',
    'credit_sent' => 'Credit Sent',
    'invoice_viewed' => 'Invoice Viewed',
    'quote_viewed' => 'Quote Viewed',
    'credit_viewed' => 'Credit Viewed',
    'quote_approved' => 'Quote Approved',
    'receive_all_notifications' => 'Receive All Notifications',
    'purchase_license' => 'Purchase License',
    'enable_modules' => 'Enable Modules',
    'converted_quote' => 'Successfully converted quote',
    'credit_design' => 'Credit Design',
    'includes' => 'Includes',
    'css_framework' => 'CSS Framework',
    'custom_designs' => 'Custom Designs',
    'designs' => 'Designs',
    'new_design' => 'New Design',
    'edit_design' => 'Edit Design',
    'created_design' => 'Successfully created design',
    'updated_design' => 'Successfully updated design',
    'archived_design' => 'Successfully archived design',
    'deleted_design' => 'Successfully deleted design',
    'removed_design' => 'Successfully removed design',
    'restored_design' => 'Successfully restored design',
    'recurring_tasks' => 'Повторувачки Задачи',
    'removed_credit' => 'Successfully removed credit',
    'latest_version' => 'Latest Version',
    'update_now' => 'Update Now',
    'a_new_version_is_available' => 'A new version of the web app is available',
    'update_available' => 'Update Available',
    'app_updated' => 'Update successfully completed',
    'integrations' => 'Integrations',
    'tracking_id' => 'Tracking Id',
    'slack_webhook_url' => 'Slack Webhook URL',
    'partial_payment' => 'Partial Payment',
    'partial_payment_email' => 'Partial Payment Email',
    'clone_to_credit' => 'Clone to Credit',
    'emailed_credit' => 'Successfully emailed credit',
    'marked_credit_as_sent' => 'Successfully marked credit as sent',
    'email_subject_payment_partial' => 'Email Partial Payment Subject',
    'is_approved' => 'Is Approved',
    'migration_went_wrong' => 'Oops, something went wrong! Please make sure you have setup an Invoice Ninja v5 instance before starting the migration.',
    'cross_migration_message' => 'Cross account migration is not allowed. Please read more about it here: <a href="https://invoiceninja.github.io/docs/migration/#troubleshooting">https://invoiceninja.github.io/docs/migration/#troubleshooting</a>',
    'email_credit' => 'Email Credit',
    'client_email_not_set' => 'Client does not have an email address set',
    'ledger' => 'Ledger',
    'view_pdf' => 'View PDF',
    'all_records' => 'All records',
    'owned_by_user' => 'Owned by user',
    'credit_remaining' => 'Credit Remaining',
    'use_default' => 'Use default',
    'reminder_endless' => 'Endless Reminders',
    'number_of_days' => 'Number of days',
    'configure_payment_terms' => 'Configure Payment Terms',
    'payment_term' => 'Payment Term',
    'new_payment_term' => 'New Payment Term',
    'deleted_payment_term' => 'Successfully deleted payment term',
    'removed_payment_term' => 'Successfully removed payment term',
    'restored_payment_term' => 'Successfully restored payment term',
    'full_width_editor' => 'Full Width Editor',
    'full_height_filter' => 'Full Height Filter',
    'email_sign_in' => 'Sign in with email',
    'change' => 'Change',
    'change_to_mobile_layout' => 'Change to the mobile layout?',
    'change_to_desktop_layout' => 'Change to the desktop layout?',
    'send_from_gmail' => 'Send from Gmail',
    'reversed' => 'Reversed',
    'cancelled' => 'Cancelled',
    'quote_amount' => 'Quote Amount',
    'hosted' => 'Hosted',
    'selfhosted' => 'Self-Hosted',
    'hide_menu' => 'Hide Menu',
    'show_menu' => 'Show Menu',
    'partially_refunded' => 'Partially Refunded',
    'search_documents' => 'Search Documents',
    'search_designs' => 'Search Designs',
    'search_invoices' => 'Search Invoices',
    'search_clients' => 'Search Clients',
    'search_products' => 'Search Products',
    'search_quotes' => 'Search Quotes',
    'search_credits' => 'Search Credits',
    'search_vendors' => 'Search Vendors',
    'search_users' => 'Search Users',
    'search_tax_rates' => 'Search Tax Rates',
    'search_tasks' => 'Search Tasks',
    'search_settings' => 'Search Settings',
    'search_projects' => 'Search Projects',
    'search_expenses' => 'Search Expenses',
    'search_payments' => 'Search Payments',
    'search_groups' => 'Search Groups',
    'search_company' => 'Search Company',
    'cancelled_invoice' => 'Successfully cancelled invoice',
    'cancelled_invoices' => 'Successfully cancelled invoices',
    'reversed_invoice' => 'Successfully reversed invoice',
    'reversed_invoices' => 'Successfully reversed invoices',
    'reverse' => 'Reverse',
    'filtered_by_project' => 'Filtered by Project',
    'google_sign_in' => 'Sign in with Google',
    'activity_58' => ':user reversed invoice :invoice',
    'activity_59' => ':user cancelled invoice :invoice',
    'payment_reconciliation_failure' => 'Reconciliation Failure',
    'payment_reconciliation_success' => 'Reconciliation Success',
    'gateway_success' => 'Gateway Success',
    'gateway_failure' => 'Gateway Failure',
    'gateway_error' => 'Gateway Error',
    'email_send' => 'Email Send',
    'email_retry_queue' => 'Email Retry Queue',
    'failure' => 'Failure',
    'quota_exceeded' => 'Quota Exceeded',
    'upstream_failure' => 'Upstream Failure',
    'system_logs' => 'System Logs',
    'copy_link' => 'Copy Link',
    'welcome_to_invoice_ninja' => 'Welcome to Invoice Ninja',
    'optin' => 'Opt-In',
    'optout' => 'Opt-Out',
    'auto_convert' => 'Auto Convert',
    'reminder1_sent' => 'Reminder 1 Sent',
    'reminder2_sent' => 'Reminder 2 Sent',
    'reminder3_sent' => 'Reminder 3 Sent',
    'reminder_last_sent' => 'Reminder Last Sent',
    'pdf_page_info' => 'Page :current of :total',
    'emailed_credits' => 'Successfully emailed credits',
    'view_in_stripe' => 'View in Stripe',
    'rows_per_page' => 'Rows Per Page',
    'apply_payment' => 'Apply Payment',
    'unapplied' => 'Unapplied',
    'custom_labels' => 'Custom Labels',
    'record_type' => 'Record Type',
    'record_name' => 'Record Name',
    'file_type' => 'File Type',
    'height' => 'Height',
    'width' => 'Width',
    'health_check' => 'Health Check',
    'last_login_at' => 'Last Login At',
    'company_key' => 'Company Key',
    'storefront' => 'Storefront',
    'storefront_help' => 'Enable third-party apps to create invoices',
    'count_records_selected' => ':count records selected',
    'count_record_selected' => ':count record selected',
    'client_created' => 'Client Created',
    'online_payment_email' => 'Online Payment Email',
    'manual_payment_email' => 'Manual Payment Email',
    'completed' => 'Completed',
    'gross' => 'Gross',
    'net_amount' => 'Net Amount',
    'net_balance' => 'Net Balance',
    'client_settings' => 'Client Settings',
    'selected_invoices' => 'Selected Invoices',
    'selected_payments' => 'Selected Payments',
    'selected_quotes' => 'Selected Quotes',
    'selected_tasks' => 'Selected Tasks',
    'selected_expenses' => 'Selected Expenses',
    'past_due_invoices' => 'Past Due Invoices',
    'create_payment' => 'Create Payment',
    'update_quote' => 'Update Quote',
    'update_invoice' => 'Update Invoice',
    'update_client' => 'Update Client',
    'update_vendor' => 'Update Vendor',
    'create_expense' => 'Create Expense',
    'update_expense' => 'Update Expense',
    'update_task' => 'Update Task',
    'approve_quote' => 'Approve Quote',
    'when_paid' => 'When Paid',
    'expires_on' => 'Expires On',
    'show_sidebar' => 'Show Sidebar',
    'hide_sidebar' => 'Hide Sidebar',
    'event_type' => 'Event Type',
    'copy' => 'Copy',
    'must_be_online' => 'Please restart the app once connected to the internet',
    'crons_not_enabled' => 'The crons need to be enabled',
    'api_webhooks' => 'API Webhooks',
    'search_webhooks' => 'Search :count Webhooks',
    'search_webhook' => 'Search 1 Webhook',
    'webhook' => 'Webhook',
    'webhooks' => 'Webhooks',
    'new_webhook' => 'New Webhook',
    'edit_webhook' => 'Edit Webhook',
    'created_webhook' => 'Successfully created webhook',
    'updated_webhook' => 'Successfully updated webhook',
    'archived_webhook' => 'Successfully archived webhook',
    'deleted_webhook' => 'Successfully deleted webhook',
    'removed_webhook' => 'Successfully removed webhook',
    'restored_webhook' => 'Successfully restored webhook',
    'search_tokens' => 'Search :count Tokens',
    'search_token' => 'Search 1 Token',
    'new_token' => 'New Token',
    'removed_token' => 'Successfully removed token',
    'restored_token' => 'Successfully restored token',
    'client_registration' => 'Client Registration',
    'client_registration_help' => 'Enable clients to self register in the portal',
    'customize_and_preview' => 'Customize & Preview',
    'search_document' => 'Search 1 Document',
    'search_design' => 'Search 1 Design',
    'search_invoice' => 'Search 1 Invoice',
    'search_client' => 'Search 1 Client',
    'search_product' => 'Search 1 Product',
    'search_quote' => 'Search 1 Quote',
    'search_credit' => 'Search 1 Credit',
    'search_vendor' => 'Search 1 Vendor',
    'search_user' => 'Search 1 User',
    'search_tax_rate' => 'Search 1 Tax Rate',
    'search_task' => 'Search 1 Tasks',
    'search_project' => 'Search 1 Project',
    'search_expense' => 'Search 1 Expense',
    'search_payment' => 'Search 1 Payment',
    'search_group' => 'Search 1 Group',
    'created_on' => 'Created On',
    'payment_status_-1' => 'Unapplied',
    'lock_invoices' => 'Lock Invoices',
    'show_table' => 'Show Table',
    'show_list' => 'Show List',
    'view_changes' => 'View Changes',
    'force_update' => 'Force Update',
    'force_update_help' => 'You are running the latest version but there may be pending fixes available.',
    'mark_paid_help' => 'Track the expense has been paid',
    'mark_invoiceable_help' => 'Enable the expense to be invoiced',
    'add_documents_to_invoice_help' => 'Make the documents visible',
    'convert_currency_help' => 'Set an exchange rate',
    'expense_settings' => 'Expense Settings',
    'clone_to_recurring' => 'Clone to Recurring',
    'crypto' => 'Crypto',
    'user_field' => 'User Field',
    'variables' => 'Variables',
    'show_password' => 'Show Password',
    'hide_password' => 'Hide Password',
    'copy_error' => 'Copy Error',
    'capture_card' => 'Capture Card',
    'auto_bill_enabled' => 'Auto Bill Enabled',
    'total_taxes' => 'Total Taxes',
    'line_taxes' => 'Line Taxes',
    'total_fields' => 'Total Fields',
    'stopped_recurring_invoice' => 'Successfully stopped recurring invoice',
    'started_recurring_invoice' => 'Successfully started recurring invoice',
    'resumed_recurring_invoice' => 'Successfully resumed recurring invoice',
    'gateway_refund' => 'Gateway Refund',
    'gateway_refund_help' => 'Process the refund with the payment gateway',
    'due_date_days' => 'Due Date',
    'paused' => 'Paused',
    'day_count' => 'Day :count',
    'first_day_of_the_month' => 'First Day of the Month',
    'last_day_of_the_month' => 'Last Day of the Month',
    'use_payment_terms' => 'Use Payment Terms',
    'endless' => 'Endless',
    'next_send_date' => 'Next Send Date',
    'remaining_cycles' => 'Remaining Cycles',
    'created_recurring_invoice' => 'Successfully created recurring invoice',
    'updated_recurring_invoice' => 'Successfully updated recurring invoice',
    'removed_recurring_invoice' => 'Successfully removed recurring invoice',
    'search_recurring_invoice' => 'Search 1 Recurring Invoice',
    'search_recurring_invoices' => 'Search :count Recurring Invoices',
    'send_date' => 'Send Date',
    'auto_bill_on' => 'Auto Bill On',
    'minimum_under_payment_amount' => 'Minimum Under Payment Amount',
    'allow_over_payment' => 'Allow Over Payment',
    'allow_over_payment_help' => 'Support paying extra to accept tips',
    'allow_under_payment' => 'Allow Under Payment',
    'allow_under_payment_help' => 'Support paying at minimum the partial/deposit amount',
    'test_mode' => 'Test Mode',
    'calculated_rate' => 'Calculated Rate',
    'default_task_rate' => 'Default Task Rate',
    'clear_cache' => 'Clear Cache',
    'sort_order' => 'Sort Order',
    'task_status' => 'Status',
    'task_statuses' => 'Task Statuses',
    'new_task_status' => 'New Task Status',
    'edit_task_status' => 'Edit Task Status',
    'created_task_status' => 'Successfully created task status',
    'archived_task_status' => 'Successfully archived task status',
    'deleted_task_status' => 'Successfully deleted task status',
    'removed_task_status' => 'Successfully removed task status',
    'restored_task_status' => 'Successfully restored task status',
    'search_task_status' => 'Search 1 Task Status',
    'search_task_statuses' => 'Search :count Task Statuses',
    'show_tasks_table' => 'Show Tasks Table',
    'show_tasks_table_help' => 'Always show the tasks section when creating invoices',
    'invoice_task_timelog' => 'Invoice Task Timelog',
    'invoice_task_timelog_help' => 'Add time details to the invoice line items',
    'auto_start_tasks_help' => 'Start tasks before saving',
    'configure_statuses' => 'Configure Statuses',
    'task_settings' => 'Task Settings',
    'configure_categories' => 'Configure Categories',
    'edit_expense_category' => 'Edit Expense Category',
    'removed_expense_category' => 'Successfully removed expense category',
    'search_expense_category' => 'Search 1 Expense Category',
    'search_expense_categories' => 'Search :count Expense Categories',
    'use_available_credits' => 'Use Available Credits',
    'show_option' => 'Show Option',
    'negative_payment_error' => 'The credit amount cannot exceed the payment amount',
    'should_be_invoiced_help' => 'Enable the expense to be invoiced',
    'configure_gateways' => 'Configure Gateways',
    'payment_partial' => 'Partial Payment',
    'is_running' => 'Is Running',
    'invoice_currency_id' => 'Invoice Currency ID',
    'tax_name1' => 'Tax Name 1',
    'tax_name2' => 'Tax Name 2',
    'transaction_id' => 'Transaction ID',
    'invoice_late' => 'Invoice Late',
    'quote_expired' => 'Quote Expired',
    'recurring_invoice_total' => 'Invoice Total',
    'actions' => 'Actions',
    'expense_number' => 'Expense Number',
    'task_number' => 'Task Number',
    'project_number' => 'Project Number',
    'view_settings' => 'View Settings',
    'company_disabled_warning' => 'Warning: this company has not yet been activated',
    'late_invoice' => 'Late Invoice',
    'expired_quote' => 'Expired Quote',
    'remind_invoice' => 'Remind Invoice',
    'client_phone' => 'Client Phone',
    'required_fields' => 'Required Fields',
    'enabled_modules' => 'Enabled Modules',
    'activity_60' => ':contact viewed quote :quote',
    'activity_61' => ':user updated client :client',
    'activity_62' => ':user updated vendor :vendor',
    'activity_63' => ':user emailed first reminder for invoice :invoice to :contact',
    'activity_64' => ':user emailed second reminder for invoice :invoice to :contact',
    'activity_65' => ':user emailed third reminder for invoice :invoice to :contact',
    'activity_66' => ':user emailed endless reminder for invoice :invoice to :contact',
    'expense_category_id' => 'Expense Category ID',
    'view_licenses' => 'View Licenses',
    'fullscreen_editor' => 'Fullscreen Editor',
    'sidebar_editor' => 'Sidebar Editor',
    'please_type_to_confirm' => 'Please type ":value" to confirm',
    'purge' => 'Purge',
    'clone_to' => 'Clone To',
    'clone_to_other' => 'Clone to Other',
    'labels' => 'Labels',
    'add_custom' => 'Add Custom',
    'payment_tax' => 'Payment Tax',
    'white_label' => 'White Label',
    'sent_invoices_are_locked' => 'Sent invoices are locked',
    'paid_invoices_are_locked' => 'Paid invoices are locked',
    'source_code' => 'Source Code',
    'app_platforms' => 'App Platforms',
    'archived_task_statuses' => 'Successfully archived :value task statuses',
    'deleted_task_statuses' => 'Successfully deleted :value task statuses',
    'restored_task_statuses' => 'Successfully restored :value task statuses',
    'deleted_expense_categories' => 'Successfully deleted expense :value categories',
    'restored_expense_categories' => 'Successfully restored expense :value categories',
    'archived_recurring_invoices' => 'Successfully archived recurring :value invoices',
    'deleted_recurring_invoices' => 'Successfully deleted recurring :value invoices',
    'restored_recurring_invoices' => 'Successfully restored recurring :value invoices',
    'archived_webhooks' => 'Successfully archived :value webhooks',
    'deleted_webhooks' => 'Successfully deleted :value webhooks',
    'removed_webhooks' => 'Successfully removed :value webhooks',
    'restored_webhooks' => 'Successfully restored :value webhooks',
    'api_docs' => 'API Docs',
    'archived_tokens' => 'Successfully archived :value tokens',
    'deleted_tokens' => 'Successfully deleted :value tokens',
    'restored_tokens' => 'Successfully restored :value tokens',
    'archived_payment_terms' => 'Successfully archived :value payment terms',
    'deleted_payment_terms' => 'Successfully deleted :value payment terms',
    'restored_payment_terms' => 'Successfully restored :value payment terms',
    'archived_designs' => 'Successfully archived :value designs',
    'deleted_designs' => 'Successfully deleted :value designs',
    'restored_designs' => 'Successfully restored :value designs',
    'restored_credits' => 'Successfully restored :value credits',
    'archived_users' => 'Successfully archived :value users',
    'deleted_users' => 'Successfully deleted :value users',
    'removed_users' => 'Successfully removed :value users',
    'restored_users' => 'Successfully restored :value users',
    'archived_tax_rates' => 'Successfully archived :value tax rates',
    'deleted_tax_rates' => 'Successfully deleted :value tax rates',
    'restored_tax_rates' => 'Successfully restored :value tax rates',
    'archived_company_gateways' => 'Successfully archived :value gateways',
    'deleted_company_gateways' => 'Successfully deleted :value gateways',
    'restored_company_gateways' => 'Successfully restored :value gateways',
    'archived_groups' => 'Successfully archived :value groups',
    'deleted_groups' => 'Successfully deleted :value groups',
    'restored_groups' => 'Successfully restored :value groups',
    'archived_documents' => 'Successfully archived :value documents',
    'deleted_documents' => 'Successfully deleted :value documents',
    'restored_documents' => 'Successfully restored :value documents',
    'restored_vendors' => 'Successfully restored :value vendors',
    'restored_expenses' => 'Successfully restored :value expenses',
    'restored_tasks' => 'Successfully restored :value tasks',
    'restored_projects' => 'Successfully restored :value projects',
    'restored_products' => 'Successfully restored :value products',
    'restored_clients' => 'Successfully restored :value clients',
    'restored_invoices' => 'Successfully restored :value invoices',
    'restored_payments' => 'Successfully restored :value payments',
    'restored_quotes' => 'Successfully restored :value quotes',
    'update_app' => 'Update App',
    'started_import' => 'Successfully started import',
    'duplicate_column_mapping' => 'Duplicate column mapping',
    'uses_inclusive_taxes' => 'Uses Inclusive Taxes',
    'is_amount_discount' => 'Is Amount Discount',
    'map_to' => 'Map To',
    'first_row_as_column_names' => 'Use first row as column names',
    'no_file_selected' => 'No File Selected',
    'import_type' => 'Import Type',
    'draft_mode' => 'Draft Mode',
    'draft_mode_help' => 'Preview updates faster but is less accurate',
    'show_product_discount' => 'Show Product Discount',
    'show_product_discount_help' => 'Display a line item discount field',
    'tax_name3' => 'Tax Name 3',
    'debug_mode_is_enabled' => 'Debug mode is enabled',
    'debug_mode_is_enabled_help' => 'Warning: it is intended for use on local machines, it can leak credentials. Click to learn more.',
    'running_tasks' => 'Running Tasks',
    'recent_tasks' => 'Recent Tasks',
    'recent_expenses' => 'Recent Expenses',
    'upcoming_expenses' => 'Upcoming Expenses',
    'search_payment_term' => 'Search 1 Payment Term',
    'search_payment_terms' => 'Search :count Payment Terms',
    'save_and_preview' => 'Save and Preview',
    'save_and_email' => 'Save and Email',
    'converted_balance' => 'Converted Balance',
    'is_sent' => 'Is Sent',
    'document_upload' => 'Document Upload',
    'document_upload_help' => 'Enable clients to upload documents',
    'expense_total' => 'Expense Total',
    'enter_taxes' => 'Enter Taxes',
    'by_rate' => 'By Rate',
    'by_amount' => 'By Amount',
    'enter_amount' => 'Enter Amount',
    'before_taxes' => 'Before Taxes',
    'after_taxes' => 'After Taxes',
    'color' => 'Color',
    'show' => 'Show',
    'empty_columns' => 'Empty Columns',
    'project_name' => 'Project Name',
    'counter_pattern_error' => 'To use :client_counter please add either :client_number or :client_id_number to prevent conflicts',
    'this_quarter' => 'This Quarter',
    'to_update_run' => 'To update run',
    'registration_url' => 'Registration URL',
    'show_product_cost' => 'Show Product Cost',
    'complete' => 'Complete',
     'next' => 'Next',
     'next_step' => 'Next step',
     'notification_credit_sent_subject' => 'Credit :invoice was sent to :client',
     'notification_credit_viewed_subject' => 'Credit :invoice was viewed by :client',
     'notification_credit_sent' => 'The following client :client was emailed Credit :invoice for :amount.',
     'notification_credit_viewed' => 'The following client :client viewed Credit :credit for :amount.',
     'reset_password_text' => 'Enter your email to reset your password.',
     'password_reset' => 'Password reset',
     'account_login_text' => 'Welcome back! Glad to see you.',
     'request_cancellation' => 'Request cancellation',
     'delete_payment_method' => 'Delete Payment Method',
     'about_to_delete_payment_method' => 'You are about to delete the payment method.',
     'action_cant_be_reversed' => 'Action can\'t be reversed',
     'profile_updated_successfully' => 'The profile has been updated successfully.',
     'currency_ethiopian_birr' => 'Ethiopian Birr',
     'client_information_text' => 'Use a permanent address where you can receive mail.',
     'status_id' => 'Invoice Status',
     'email_already_register' => 'This email is already linked to an account',
     'locations' => 'Locations',
     'freq_indefinitely' => 'Indefinitely',
     'cycles_remaining' => 'Cycles remaining',
     'i_understand_delete' => 'I understand, delete',
     'download_files' => 'Download Files',
     'download_timeframe' => 'Use this link to download your files, the link will expire in 1 hour.',
     'new_signup' => 'New Signup',
     'new_signup_text' => 'A new account has been created by :user - :email - from IP address: :ip',
     'notification_payment_paid_subject' => 'Payment was made by :client',
     'notification_partial_payment_paid_subject' => 'Partial payment was made by :client',
     'notification_payment_paid' => 'A payment of :amount was made by client :client towards :invoice',
     'notification_partial_payment_paid' => 'A partial payment of :amount was made by client :client towards :invoice',
     'notification_bot' => 'Notification Bot',
     'invoice_number_placeholder' => 'Invoice # :invoice',
     'entity_number_placeholder' => ':entity # :entity_number',
     'email_link_not_working' => 'If the button above isn\'t working for you, please click on the link',
     'display_log' => 'Display Log',
     'send_fail_logs_to_our_server' => 'Report errors in realtime',
     'setup' => 'Setup',
     'quick_overview_statistics' => 'Quick overview & statistics',
     'update_your_personal_info' => 'Update your personal information',
     'name_website_logo' => 'Name, website & logo',
     'make_sure_use_full_link' => 'Make sure you use full link to your site',
     'personal_address' => 'Personal address',
     'enter_your_personal_address' => 'Enter your personal address',
     'enter_your_shipping_address' => 'Enter your shipping address',
     'list_of_invoices' => 'List of invoices',
     'with_selected' => 'With selected',
     'invoice_still_unpaid' => 'This invoice is still not paid. Click the button to complete the payment',
     'list_of_recurring_invoices' => 'List of recurring invoices',
     'details_of_recurring_invoice' => 'Here are some details about recurring invoice',
     'cancellation' => 'Cancellation',
     'about_cancellation' => 'In case you want to stop the recurring invoice,\n please click the request the cancellation.',
     'cancellation_warning' => 'Warning! You are requesting a cancellation of this service.\n Your service may be cancelled with no further notification to you.',
     'cancellation_pending' => 'Cancellation pending, we\'ll be in touch!',
     'list_of_payments' => 'List of payments',
     'payment_details' => 'Details of the payment',
     'list_of_payment_invoices' => 'List of invoices affected by the payment',
     'list_of_payment_methods' => 'List of payment methods',
     'payment_method_details' => 'Details of payment method',
     'permanently_remove_payment_method' => 'Permanently remove this payment method.',
     'warning_action_cannot_be_reversed' => 'Warning! This action can not be reversed!',
     'confirmation' => 'Confirmation',
     'list_of_quotes' => 'Quotes',
     'waiting_for_approval' => 'Waiting for approval',
     'quote_still_not_approved' => 'This quote is still not approved',
     'list_of_credits' => 'Credits',
     'required_extensions' => 'Required extensions',
     'php_version' => 'PHP version',
     'writable_env_file' => 'Writable .env file',
     'env_not_writable' => '.env file is not writable by the current user.',
     'minumum_php_version' => 'Minimum PHP version',
     'satisfy_requirements' => 'Make sure all requirements are satisfied.',
     'oops_issues' => 'Oops, something does not look right!',
     'open_in_new_tab' => 'Open in new tab',
     'complete_your_payment' => 'Complete payment',
     'authorize_for_future_use' => 'Authorize payment method for future use',
     'page' => 'Page',
     'per_page' => 'Per page',
     'of' => 'Of',
     'view_credit' => 'View Credit',
     'to_view_entity_password' => 'To view the :entity you need to enter password.',
     'showing_x_of' => 'Showing :first to :last out of :total results',
     'no_results' => 'No results found.',
     'payment_failed_subject' => 'Payment failed for Client :client',
     'payment_failed_body' => 'A payment made by client :client failed with message :message',
     'register' => 'Register',
     'register_label' => 'Create your account in seconds',
     'password_confirmation' => 'Confirm your password',
     'verification' => 'Verification',
     'complete_your_bank_account_verification' => 'Before using a bank account it must be verified.',
     'checkout_com' => 'Checkout.com',
     'footer_label' => 'Copyright © :year :company.',
     'credit_card_invalid' => 'Provided credit card number is not valid.',
     'month_invalid' => 'Provided month is not valid.',
     'year_invalid' => 'Provided year is not valid.',
     'https_required' => 'HTTPS is required, form will fail',
     'if_you_need_help' => 'If you need help you can post to our',
     'update_password_on_confirm' => 'After updating password, your account will be confirmed.',
     'bank_account_not_linked' => 'To pay with a bank account, first you have to add it as payment method.',
     'application_settings_label' => 'Let\'s store basic information about your Invoice Ninja!',
     'recommended_in_production' => 'Highly recommended in production',
     'enable_only_for_development' => 'Enable only for development',
     'test_pdf' => 'Test PDF',
     'checkout_authorize_label' => 'Checkout.com can be can saved as payment method for future use, once you complete your first transaction. Don\'t forget to check "Store credit card details" during payment process.',
     'sofort_authorize_label' => 'Bank account (SOFORT) can be can saved as payment method for future use, once you complete your first transaction. Don\'t forget to check "Store payment details" during payment process.',
     'node_status' => 'Node status',
     'npm_status' => 'NPM status',
     'node_status_not_found' => 'I could not find Node anywhere. Is it installed?',
     'npm_status_not_found' => 'I could not find NPM anywhere. Is it installed?',
     'locked_invoice' => 'This invoice is locked and unable to be modified',
     'downloads' => 'Downloads',
     'resource' => 'Resource',
     'document_details' => 'Details about the document',
     'hash' => 'Hash',
     'resources' => 'Resources',
     'allowed_file_types' => 'Allowed file types:',
     'common_codes' => 'Common codes and their meanings',
     'payment_error_code_20087' => '20087: Bad Track Data (invalid CVV and/or expiry date)',
     'download_selected' => 'Download selected',
     'to_pay_invoices' => 'To pay invoices, you have to',
     'add_payment_method_first' => 'add payment method',
     'no_items_selected' => 'No items selected.',
     'payment_due' => 'Payment due',
     'account_balance' => 'Account balance',
     'thanks' => 'Thanks',
     'minimum_required_payment' => 'Minimum required payment is :amount',
     'under_payments_disabled' => 'Company doesn\'t support under payments.',
     'over_payments_disabled' => 'Company doesn\'t support over payments.',
     'saved_at' => 'Saved at :time',
     'credit_payment' => 'Credit applied to Invoice :invoice_number',
     'credit_subject' => 'New credit :number from :account',
     'credit_message' => 'To view your credit for :amount, click the link below.',
     'payment_type_Crypto' => 'Cryptocurrency',
     'payment_type_Credit' => 'Credit',
     'store_for_future_use' => 'Store for future use',
     'pay_with_credit' => 'Pay with credit',
     'payment_method_saving_failed' => 'Payment method can\'t be saved for future use.',
     'pay_with' => 'Pay with',
     'n/a' => 'N/A',
     'by_clicking_next_you_accept_terms' => 'By clicking "Next step" you accept terms.',
     'not_specified' => 'Not specified',
     'before_proceeding_with_payment_warning' => 'Before proceeding with payment, you have to fill following fields',
     'after_completing_go_back_to_previous_page' => 'After completing, go back to previous page.',
     'pay' => 'Pay',
     'instructions' => 'Instructions',
     'notification_invoice_reminder1_sent_subject' => 'Reminder 1 for Invoice :invoice was sent to :client',
     'notification_invoice_reminder2_sent_subject' => 'Reminder 2 for Invoice :invoice was sent to :client',
     'notification_invoice_reminder3_sent_subject' => 'Reminder 3 for Invoice :invoice was sent to :client',
     'notification_invoice_reminder_endless_sent_subject' => 'Endless reminder for Invoice :invoice was sent to :client',
     'assigned_user' => 'Assigned User',
     'setup_steps_notice' => 'To proceed to next step, make sure you test each section.',
     'setup_phantomjs_note' => 'Note about Phantom JS. Read more.',
     'minimum_payment' => 'Minimum Payment',
     'no_action_provided' => 'No action provided. If you believe this is wrong, please contact the support.',
     'no_payable_invoices_selected' => 'No payable invoices selected. Make sure you are not trying to pay draft invoice or invoice with zero balance due.',
     'required_payment_information' => 'Required payment details',
     'required_payment_information_more' => 'To complete a payment we need more details about you.',
     'required_client_info_save_label' => 'We will save this, so you don\'t have to enter it next time.',
     'notification_credit_bounced' => 'We were unable to deliver Credit :invoice to :contact. \n :error',
     'notification_credit_bounced_subject' => 'Unable to deliver Credit :invoice',
     'save_payment_method_details' => 'Save payment method details',
     'new_card' => 'New card',
     'new_bank_account' => 'New bank account',
     'company_limit_reached' => 'Limit of 10 companies per account.',
     'credits_applied_validation' => 'Total credits applied cannot be MORE than total of invoices',
     'credit_number_taken' => 'Credit number already taken',
     'credit_not_found' => 'Credit not found',
     'invoices_dont_match_client' => 'Selected invoices are not from a single client',
     'duplicate_credits_submitted' => 'Duplicate credits submitted.',
     'duplicate_invoices_submitted' => 'Duplicate invoices submitted.',
     'credit_with_no_invoice' => 'You must have an invoice set when using a credit in a payment',
     'client_id_required' => 'Client id is required',
     'expense_number_taken' => 'Expense number already taken',
     'invoice_number_taken' => 'Invoice number already taken',
     'payment_id_required' => 'Payment `id` required.',
     'unable_to_retrieve_payment' => 'Unable to retrieve specified payment',
     'invoice_not_related_to_payment' => 'Invoice id :invoice is not related to this payment',
     'credit_not_related_to_payment' => 'Credit id :credit is not related to this payment',
     'max_refundable_invoice' => 'Attempting to refund more than allowed for invoice id :invoice, maximum refundable amount is :amount',
     'refund_without_invoices' => 'Attempting to refund a payment with invoices attached, please specify valid invoice/s to be refunded.',
     'refund_without_credits' => 'Attempting to refund a payment with credits attached, please specify valid credits/s to be refunded.',
     'max_refundable_credit' => 'Attempting to refund more than allowed for credit :credit, maximum refundable amount is :amount',
     'project_client_do_not_match' => 'Project client does not match entity client',
     'quote_number_taken' => 'Quote number already taken',
     'recurring_invoice_number_taken' => 'Recurring Invoice number :number already taken',
     'user_not_associated_with_account' => 'User not associated with this account',
     'amounts_do_not_balance' => 'Amounts do not balance correctly.',
     'insufficient_applied_amount_remaining' => 'Insufficient applied amount remaining to cover payment.',
     'insufficient_credit_balance' => 'Insufficient balance on credit.',
     'one_or_more_invoices_paid' => 'One or more of these invoices have been paid',
     'invoice_cannot_be_refunded' => 'Invoice id :number cannot be refunded',
     'attempted_refund_failed' => 'Attempting to refund :amount only :refundable_amount available for refund',
     'user_not_associated_with_this_account' => 'This user is unable to be attached to this company. Perhaps they have already registered a user on another account?',
     'migration_completed' => 'Migration completed',
     'migration_completed_description' => 'Your migration has completed, please review your data after logging in.',
     'api_404' => '404 | Nothing to see here!',
     'large_account_update_parameter' => 'Cannot load a large account without a updated_at parameter',
     'no_backup_exists' => 'No backup exists for this activity',
     'company_user_not_found' => 'Company User record not found',
     'no_credits_found' => 'No credits found.',
     'action_unavailable' => 'The requested action :action is not available.',
     'no_documents_found' => 'No Documents Found',
     'no_group_settings_found' => 'No group settings found',
     'access_denied' => 'Insufficient privileges to access/modify this resource',
     'invoice_cannot_be_marked_paid' => 'Invoice cannot be marked as paid',
     'invoice_license_or_environment' => 'Invalid license, or invalid environment :environment',
     'route_not_available' => 'Route not available',
     'invalid_design_object' => 'Invalid custom design object',
     'quote_not_found' => 'Quote/s not found',
     'quote_unapprovable' => 'Unable to approve this quote as it has expired.',
     'scheduler_has_run' => 'Scheduler has run',
     'scheduler_has_never_run' => 'Scheduler has never run',
     'self_update_not_available' => 'Self update not available on this system.',
     'user_detached' => 'User detached from company',
     'create_webhook_failure' => 'Failed to create Webhook',
     'payment_message_extended' => 'Thank you for your payment of :amount for :invoice',
     'online_payments_minimum_note' => 'Note: Online payments are supported only if amount is bigger than $1 or currency equivalent.',
     'payment_token_not_found' => 'Payment token not found, please try again. If an issue still persist, try with another payment method',
     'vendor_address1' => 'Vendor Street',
     'vendor_address2' => 'Vendor Apt/Suite',
     'partially_unapplied' => 'Partially Unapplied',
     'select_a_gmail_user' => 'Please select a user authenticated with Gmail',
     'list_long_press' => 'List Long Press',
     'show_actions' => 'Show Actions',
     'start_multiselect' => 'Start Multiselect',
     'email_sent_to_confirm_email' => 'An email has been sent to confirm the email address',
     'converted_paid_to_date' => 'Converted Paid to Date',
     'converted_credit_balance' => 'Converted Credit Balance',
     'converted_total' => 'Converted Total',
     'reply_to_name' => 'Reply-To Name',
     'payment_status_-2' => 'Partially Unapplied',
     'color_theme' => 'Color Theme',
     'start_migration' => 'Start Migration',
     'recurring_cancellation_request' => 'Request for recurring invoice cancellation from :contact',
     'recurring_cancellation_request_body' => ':contact from Client :client requested to cancel Recurring Invoice :invoice',
     'hello' => 'Hello',
     'group_documents' => 'Group documents',
     'quote_approval_confirmation_label' => 'Are you sure you want to approve this quote?',
     'migration_select_company_label' => 'Select companies to migrate',
     'force_migration' => 'Force migration',
     'require_password_with_social_login' => 'Require Password with Social Login',
     'stay_logged_in' => 'Stay Logged In',
     'session_about_to_expire' => 'Warning: Your session is about to expire',
     'count_hours' => ':count Hours',
     'count_day' => '1 Day',
     'count_days' => ':count Days',
     'web_session_timeout' => 'Web Session Timeout',
     'security_settings' => 'Security Settings',
     'resend_email' => 'Resend Email',
     'confirm_your_email_address' => 'Please confirm your email address',
     'freshbooks' => 'FreshBooks',
     'invoice2go' => 'Invoice2go',
     'invoicely' => 'Invoicely',
     'waveaccounting' => 'Wave Accounting',
     'zoho' => 'Zoho',
     'accounting' => 'Accounting',
     'required_files_missing' => 'Please provide all CSVs.',
     'migration_auth_label' => 'Let\'s continue by authenticating. (These credentials should be identical across systems)',
     'api_secret' => 'API secret',
     'migration_api_secret_notice' => 'You can find API_SECRET in the .env file or Invoice Ninja v5. If property is missing, leave field blank.',
     'billing_coupon_notice' => 'Your discount will be applied on the checkout.',
     'use_last_email' => 'Use last email',
     'activate_company' => 'Activate Company',
     'activate_company_help' => 'Enable emails, recurring invoices and notifications',
     'an_error_occurred_try_again' => 'An error occurred, please try again',
     'please_first_set_a_password' => 'Please first set a password',
     'changing_phone_disables_two_factor' => 'Warning: Changing your phone number will disable 2FA',
     'help_translate' => 'Help Translate',
     'please_select_a_country' => 'Please select a country',
     'disabled_two_factor' => 'Successfully disabled 2FA',
     'connected_google' => 'Successfully connected account',
     'disconnected_google' => 'Successfully disconnected account',
     'delivered' => 'Delivered',
     'spam' => 'Spam',
     'view_docs' => 'View Docs',
     'enter_phone_to_enable_two_factor' => 'Please provide a mobile phone number to enable two factor authentication',
     'send_sms' => 'Send SMS',
     'sms_code' => 'SMS Code',
     'connect_google' => 'Connect Google',
     'disconnect_google' => 'Disconnect Google',
     'disable_two_factor' => 'Disable Two Factor',
     'invoice_task_datelog' => 'Invoice Task Datelog',
     'invoice_task_datelog_help' => 'Add date details to the invoice line items',
     'promo_code' => 'Promo code',
     'recurring_invoice_issued_to' => 'Recurring invoice issued to',
     'amount_greater_than_balance_v5' => 'The amount is greater than the invoice balance. You cannot overpay an invoice.',
     'move_top' => 'Move Top',
     'move_up' => 'Move Up',
     'move_down' => 'Move Down',
     'move_bottom' => 'Move Bottom',
     'body_variable_missing' => 'Error: the custom email must include a :body variable',
     'add_body_variable_message' => 'Make sure to include a :body variable',
     'view_date_formats' => 'View Date Formats',
     'is_viewed' => 'Is Viewed',
     'letter' => 'Letter',
     'legal' => 'Legal',
     'page_layout' => 'Page Layout',
     'portrait' => 'Portrait',
     'landscape' => 'Landscape',
     'upgrade_to_paid_plan' => 'Upgrade to a paid plan to enable the advanded settings',
     'invoice_payment_terms' => 'Invoice Payment Terms',
     'quote_valid_until' => 'Quote Valid Until',
     'no_headers' => 'No Headers',
     'add_header' => 'Add Header',
     'remove_header' => 'Remove Header',
     'return_url' => 'Return URL',
     'rest_method' => 'REST Method',
     'header_key' => 'Header Key',
     'header_value' => 'Header Value',
     'recurring_products' => 'Recurring Products',
     'promo_discount' => 'Promo Discount',
     'allow_cancellation' => 'Allow Cancellation',
     'per_seat_enabled' => 'Per Seat Enabled',
     'max_seats_limit' => 'Max Seats Limit',
     'trial_enabled' => 'Trial Enabled',
     'trial_duration' => 'Trial Duration',
     'allow_query_overrides' => 'Allow Query Overrides',
     'allow_plan_changes' => 'Allow Plan Changes',
     'plan_map' => 'Plan Map',
     'refund_period' => 'Refund Period',
     'webhook_configuration' => 'Webhook Configuration',
     'purchase_page' => 'Purchase Page',
     'email_bounced' => 'Email Bounced',
     'email_spam_complaint' => 'Spam Complaint',
     'email_delivery' => 'Email Delivery',
     'webhook_response' => 'Webhook Response',
     'pdf_response' => 'PDF Response',
     'authentication_failure' => 'Authentication Failure',
     'pdf_failed' => 'PDF Failed',
     'pdf_success' => 'PDF Success',
     'modified' => 'Modified',
     'subscription' => 'Subscription',
     'new_subscription' => 'New Subscription',
     'deleted_subscription' => 'Successfully deleted subscription',
     'removed_subscription' => 'Successfully removed subscription',
     'restored_subscription' => 'Successfully restored subscription',
     'search_subscription' => 'Search 1 Subscription',
     'search_subscriptions' => 'Search :count Subscriptions',
     'subdomain_is_not_available' => 'Subdomain is not available',
     'connect_gmail' => 'Connect Gmail',
     'disconnect_gmail' => 'Disconnect Gmail',
     'connected_gmail' => 'Successfully connected Gmail',
     'disconnected_gmail' => 'Successfully disconnected Gmail',
     'update_fail_help' => 'Changes to the codebase may be blocking the update, you can run this command to discard the changes:',
     'client_id_number' => 'Client ID Number',
     'count_minutes' => ':count Minutes',
     'password_timeout' => 'Password Timeout',
     'shared_invoice_credit_counter' => 'Shared Invoice/Credit Counter',
    'activity_80' => ':user created subscription :subscription',
    'activity_81' => ':user updated subscription :subscription',
    'activity_82' => ':user archived subscription :subscription',
    'activity_83' => ':user deleted subscription :subscription',
    'activity_84' => ':user restored subscription :subscription',

    'amount_greater_than_balance_v5' => 'The amount is greater than the invoice balance. You cannot overpay an invoice.',
    'click_to_continue' => 'Click to continue',

    'notification_invoice_created_subject' => 'Invoice :invoice was created to :client',
    'notification_invoice_created_subject' => 'Invoice :invoice was created to :client',
    'notification_quote_created_subject' => 'Quote :invoice was created to :client',
    'notification_quote_created_subject' => 'Quote :invoice was created to :client',
    'notification_credit_created_subject' => 'Credit :invoice was created to :client',
    'notification_credit_created_subject' => 'Credit :invoice was created to :client',
    'migration_create_account_notice' => 'Please ensure you have created an account on the new platform first <a href="https://invoicing.co">here</a> , please ensure that the credentials are <b>identical</b> to your v4 credentials. Once the account has been created, you can start the migration process here.',
    'auth' => 'Authentication',
    'companies' => 'Select companies for migration',
    'activity_100' => ':user created recurring invoice :recurring_invoice',
    'activity_101' => ':user updated recurring invoice :recurring_invoice',
    'activity_102' => ':user archived recurring invoice :recurring_invoice',
    'activity_103' => ':user deleted recurring invoice :recurring_invoice',
    'activity_104' => ':user restored recurring invoice :recurring_invoice',

    'import_settings' => 'Import Settings',
    'json_file_missing' => 'Please provide the JSON file',
    'json_option_missing' => 'Please select to import the settings and/or data',
    'json' => 'JSON',
    'no_payment_types_enabled' => 'No payment types enabled',
    'wait_for_data' => 'Please wait for the data to finish loading',
    'net_total' => 'Net Total',
    'has_taxes' => 'Has Taxes',
    'import_customers' => 'Import Customers',
    'imported_customers' => 'Successfully started importing customers',
    'login_success' => 'Successful Login',
    'login_failure' => 'Failed Login',
    'exported_data' => 'Once the file is ready you"ll receive an email with a download link',
    'include_deleted_clients' => 'Include Deleted Clients',
    'include_deleted_clients_help' => 'Load records belonging to deleted clients',
    'step_1_sign_in' => 'Step 1: Sign In',
    'step_2_authorize' => 'Step 2: Authorize',
    'account_id' => 'Account ID',
    'migration_not_yet_completed' => 'The migration has not yet completed',
    'wizard_warning' => 'If you are migrating from the legacy version stop here and begin the migration. Once the migration completes click "Refesh" and use the dropdown in the top left corner to switch companies.',
    'show_task_end_date' => 'Show Task End Date',
    'show_task_end_date_help' => 'Enable specifying the task end date',
    'gateway_setup' => 'Gateway Setup',
    'preview_sidebar' => 'Preview Sidebar',
    'years_data_shown' => 'Years Data Shown',
    'ended_all_sessions' => 'Successfully ended all sessions',
    'end_all_sessions' => 'End All Sessions',
    'count_session' => '1 Session',
    'count_sessions' => ':count Sessions',
    'invoice_created' => 'Invoice Created',
    'quote_created' => 'Quote Created',
    'credit_created' => 'Credit Created',
    'enterprise' => 'Enterprise',
    'invoice_item' => 'Invoice Item',
    'quote_item' => 'Quote Item',
    'order' => 'Order',
    'search_kanban' => 'Search Kanban',
    'search_kanbans' => 'Search Kanban',
    'owner_upgrade_to_paid_plan' => 'The account owner can upgrade to a paid plan to enable the advanced advanced settings',
    'html_mode' => 'HTML Mode',
    'html_mode_help' => 'Preview updates faster but is less accurate',

);

return $LANG;

?>
